from __future__ import annotations
from tssm.utils.seasons import Season
from tssm.utils.BDEW_day import BDEWDAY


class BDEWElectrical:
    def __init__(self):
        self.H0: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 70.8,
                    1: 68.2,
                    2: 65.9,
                    3: 63.3,
                    4: 59.5,
                    5: 55.0,
                    6: 50.5,
                    7: 46.6,
                    8: 43.9,
                    9: 42.3,
                    10: 41.4,
                    11: 40.8,
                    12: 40.3,
                    13: 39.9,
                    14: 39.5,
                    15: 39.1,
                    16: 38.8,
                    17: 38.5,
                    18: 38.3,
                    19: 38.3,
                    20: 38.5,
                    21: 39.1,
                    22: 40.3,
                    23: 42.4,
                    24: 45.6,
                    25: 49.9,
                    26: 55.3,
                    27: 61.6,
                    28: 68.9,
                    29: 77.1,
                    30: 86.1,
                    31: 95.7,
                    32: 105.8,
                    33: 115.8,
                    34: 124.9,
                    35: 132.3,
                    36: 137.6,
                    37: 141.1,
                    38: 143.3,
                    39: 144.8,
                    40: 146.0,
                    41: 147.2,
                    42: 148.4,
                    43: 149.8,
                    44: 151.5,
                    45: 153.5,
                    46: 156.0,
                    47: 159.0,
                    48: 162.4,
                    49: 165.8,
                    50: 168.4,
                    51: 169.8,
                    52: 169.4,
                    53: 167.6,
                    54: 164.8,
                    55: 161.5,
                    56: 158.1,
                    57: 154.9,
                    58: 151.8,
                    59: 149.0,
                    60: 146.5,
                    61: 144.4,
                    62: 142.7,
                    63: 141.5,
                    64: 140.9,
                    65: 141.7,
                    66: 144.9,
                    67: 151.5,
                    68: 161.9,
                    69: 174.6,
                    70: 187.4,
                    71: 198.1,
                    72: 205.2,
                    73: 209.1,
                    74: 211.1,
                    75: 212.2,
                    76: 213.2,
                    77: 213.0,
                    78: 210.4,
                    79: 203.9,
                    80: 192.9,
                    81: 179.0,
                    82: 164.4,
                    83: 151.5,
                    84: 141.9,
                    85: 135.3,
                    86: 131.0,
                    87: 128.2,
                    88: 126.1,
                    89: 124.1,
                    90: 121.6,
                    91: 118.2,
                    92: 113.4,
                    93: 107.4,
                    94: 100.8,
                    95: 94.1,
                },
                BDEWDAY.Sunday: {
                    0: 87.5,
                    1: 81.1,
                    2: 75.0,
                    3: 69.1,
                    4: 63.4,
                    5: 58.2,
                    6: 53.6,
                    7: 49.9,
                    8: 47.3,
                    9: 45.5,
                    10: 44.2,
                    11: 43.3,
                    12: 42.4,
                    13: 41.5,
                    14: 40.7,
                    15: 40.0,
                    16: 39.3,
                    17: 38.8,
                    18: 38.5,
                    19: 38.3,
                    20: 38.3,
                    21: 38.4,
                    22: 38.7,
                    23: 39.1,
                    24: 39.7,
                    25: 40.4,
                    26: 41.3,
                    27: 42.4,
                    28: 44.0,
                    29: 46.6,
                    30: 51.1,
                    31: 58.3,
                    32: 68.6,
                    33: 81.3,
                    34: 95.2,
                    35: 109.0,
                    36: 121.9,
                    37: 133.7,
                    38: 144.4,
                    39: 154.0,
                    40: 162.6,
                    41: 170.5,
                    42: 178.0,
                    43: 185.6,
                    44: 193.3,
                    45: 200.6,
                    46: 206.6,
                    47: 210.6,
                    48: 211.8,
                    49: 210.2,
                    50: 205.9,
                    51: 198.9,
                    52: 189.6,
                    53: 178.7,
                    54: 167.3,
                    55: 156.5,
                    56: 147.0,
                    57: 138.9,
                    58: 132.1,
                    59: 126.5,
                    60: 122.0,
                    61: 118.1,
                    62: 114.8,
                    63: 111.5,
                    64: 108.3,
                    65: 105.9,
                    66: 105.2,
                    67: 107.4,
                    68: 112.9,
                    69: 120.9,
                    70: 130.0,
                    71: 139.0,
                    72: 146.8,
                    73: 153.5,
                    74: 159.7,
                    75: 165.6,
                    76: 171.5,
                    77: 176.4,
                    78: 179.1,
                    79: 178.1,
                    80: 172.9,
                    81: 164.7,
                    82: 155.6,
                    83: 147.3,
                    84: 141.4,
                    85: 137.2,
                    86: 133.7,
                    87: 129.8,
                    88: 124.8,
                    89: 118.6,
                    90: 111.6,
                    91: 104.0,
                    92: 96.2,
                    93: 88.4,
                    94: 80.7,
                    95: 73.2,
                },
                BDEWDAY.Workday: {
                    0: 67.6,
                    1: 60.8,
                    2: 54.9,
                    3: 49.9,
                    4: 46.2,
                    5: 43.6,
                    6: 41.9,
                    7: 40.8,
                    8: 40.1,
                    9: 39.6,
                    10: 39.4,
                    11: 39.1,
                    12: 38.8,
                    13: 38.6,
                    14: 38.3,
                    15: 38.3,
                    16: 38.4,
                    17: 38.8,
                    18: 39.3,
                    19: 40.0,
                    20: 40.9,
                    21: 43.1,
                    22: 47.7,
                    23: 55.8,
                    24: 68.0,
                    25: 82.8,
                    26: 98.0,
                    27: 111.5,
                    28: 121.6,
                    29: 128.5,
                    30: 132.7,
                    31: 134.8,
                    32: 135.4,
                    33: 134.8,
                    34: 133.1,
                    35: 130.7,
                    36: 127.7,
                    37: 124.6,
                    38: 121.5,
                    39: 119.0,
                    40: 117.3,
                    41: 116.2,
                    42: 115.7,
                    43: 115.7,
                    44: 116.1,
                    45: 117.0,
                    46: 118.7,
                    47: 121.5,
                    48: 125.4,
                    49: 129.6,
                    50: 133.0,
                    51: 134.8,
                    52: 134.2,
                    53: 131.7,
                    54: 128.0,
                    55: 124.0,
                    56: 120.2,
                    57: 116.8,
                    58: 113.7,
                    59: 110.7,
                    60: 107.9,
                    61: 105.5,
                    62: 103.5,
                    63: 102.4,
                    64: 102.2,
                    65: 103.2,
                    66: 105.6,
                    67: 109.9,
                    68: 116.0,
                    69: 123.7,
                    70: 132.6,
                    71: 142.3,
                    72: 152.4,
                    73: 162.2,
                    74: 171.2,
                    75: 178.9,
                    76: 184.7,
                    77: 188.2,
                    78: 188.9,
                    79: 186.4,
                    80: 180.7,
                    81: 172.7,
                    82: 163.9,
                    83: 155.6,
                    84: 148.9,
                    85: 143.4,
                    86: 138.4,
                    87: 133.2,
                    88: 127.2,
                    89: 120.5,
                    90: 113.3,
                    91: 105.7,
                    92: 98.0,
                    93: 90.2,
                    94: 82.5,
                    95: 74.9,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 89.8,
                    1: 84.9,
                    2: 80.7,
                    3: 76.6,
                    4: 71.7,
                    5: 66.6,
                    6: 61.6,
                    7: 57.4,
                    8: 54.5,
                    9: 52.6,
                    10: 51.4,
                    11: 50.8,
                    12: 50.3,
                    13: 50.0,
                    14: 49.9,
                    15: 49.9,
                    16: 50.1,
                    17: 50.4,
                    18: 50.7,
                    19: 50.8,
                    20: 50.8,
                    21: 50.9,
                    22: 51.6,
                    23: 53.3,
                    24: 56.2,
                    25: 60.4,
                    26: 65.8,
                    27: 72.4,
                    28: 80.0,
                    29: 88.5,
                    30: 97.4,
                    31: 106.5,
                    32: 115.6,
                    33: 124.4,
                    34: 132.8,
                    35: 140.7,
                    36: 147.8,
                    37: 154.0,
                    38: 158.9,
                    39: 162.3,
                    40: 164.1,
                    41: 164.7,
                    42: 165.0,
                    43: 165.6,
                    44: 167.1,
                    45: 169.4,
                    46: 172.4,
                    47: 175.6,
                    48: 179.0,
                    49: 181.9,
                    50: 183.7,
                    51: 183.9,
                    52: 182.1,
                    53: 178.7,
                    54: 174.1,
                    55: 169.0,
                    56: 163.7,
                    57: 158.9,
                    58: 154.6,
                    59: 151.5,
                    60: 149.6,
                    61: 148.6,
                    62: 148.0,
                    63: 147.3,
                    64: 146.2,
                    65: 145.0,
                    66: 144.1,
                    67: 144.0,
                    68: 144.9,
                    69: 146.9,
                    70: 150.0,
                    71: 154.0,
                    72: 158.8,
                    73: 164.0,
                    74: 169.2,
                    75: 174.0,
                    76: 177.8,
                    77: 180.5,
                    78: 181.8,
                    79: 181.4,
                    80: 179.3,
                    81: 175.7,
                    82: 171.0,
                    83: 165.6,
                    84: 160.1,
                    85: 155.1,
                    86: 151.1,
                    87: 149.0,
                    88: 148.9,
                    89: 149.6,
                    90: 149.4,
                    91: 146.5,
                    92: 139.8,
                    93: 130.3,
                    94: 119.5,
                    95: 109.0,
                },
                BDEWDAY.Sunday: {
                    0: 100.1,
                    1: 92.5,
                    2: 85.9,
                    3: 79.9,
                    4: 74.1,
                    5: 68.7,
                    6: 63.9,
                    7: 59.9,
                    8: 57.0,
                    9: 55.0,
                    10: 53.5,
                    11: 52.4,
                    12: 51.5,
                    13: 50.8,
                    14: 50.2,
                    15: 49.9,
                    16: 49.9,
                    17: 50.0,
                    18: 50.1,
                    19: 49.9,
                    20: 49.5,
                    21: 48.9,
                    22: 48.4,
                    23: 48.3,
                    24: 48.7,
                    25: 49.8,
                    26: 51.9,
                    27: 54.9,
                    28: 59.2,
                    29: 64.9,
                    30: 72.3,
                    31: 81.6,
                    32: 92.9,
                    33: 105.6,
                    34: 119.0,
                    35: 132.3,
                    36: 144.8,
                    37: 156.2,
                    38: 166.0,
                    39: 174.0,
                    40: 180.0,
                    41: 184.6,
                    42: 188.7,
                    43: 193.1,
                    44: 198.3,
                    45: 203.7,
                    46: 208.7,
                    47: 212.2,
                    48: 213.7,
                    49: 212.8,
                    50: 209.0,
                    51: 202.3,
                    52: 192.4,
                    53: 180.9,
                    54: 169.2,
                    55: 159.0,
                    56: 151.4,
                    57: 146.0,
                    58: 141.6,
                    59: 137.3,
                    60: 132.4,
                    61: 127.0,
                    62: 121.6,
                    63: 116.5,
                    64: 112.2,
                    65: 108.9,
                    66: 106.7,
                    67: 105.7,
                    68: 106.1,
                    69: 107.7,
                    70: 110.4,
                    71: 114.0,
                    72: 118.3,
                    73: 123.4,
                    74: 129.2,
                    75: 135.7,
                    76: 142.8,
                    77: 149.8,
                    78: 155.7,
                    79: 159.8,
                    80: 161.4,
                    81: 160.8,
                    82: 159.0,
                    83: 156.5,
                    84: 153.9,
                    85: 151.5,
                    86: 149.3,
                    87: 147.3,
                    88: 145.4,
                    89: 143.0,
                    90: 139.2,
                    91: 133.2,
                    92: 124.4,
                    93: 113.8,
                    94: 102.5,
                    95: 91.6,
                },
                BDEWDAY.Workday: {
                    0: 86.3,
                    1: 76.9,
                    2: 68.8,
                    3: 62.4,
                    4: 58.0,
                    5: 55.3,
                    6: 53.6,
                    7: 52.4,
                    8: 51.3,
                    9: 50.3,
                    10: 49.2,
                    11: 48.3,
                    12: 47.5,
                    13: 46.9,
                    14: 46.5,
                    15: 46.6,
                    16: 47.1,
                    17: 48.0,
                    18: 49.3,
                    19: 50.8,
                    20: 52.7,
                    21: 55.6,
                    22: 60.5,
                    23: 68.2,
                    24: 79.2,
                    25: 92.0,
                    26: 104.7,
                    27: 115.7,
                    28: 123.5,
                    29: 128.6,
                    30: 132.0,
                    31: 134.8,
                    32: 137.8,
                    33: 140.7,
                    34: 143.2,
                    35: 144.8,
                    36: 145.3,
                    37: 144.9,
                    38: 143.8,
                    39: 142.3,
                    40: 140.8,
                    41: 139.5,
                    42: 138.5,
                    43: 138.2,
                    44: 138.6,
                    45: 140.1,
                    46: 142.6,
                    47: 146.5,
                    48: 151.5,
                    49: 156.7,
                    50: 160.7,
                    51: 162.3,
                    52: 160.5,
                    53: 156.1,
                    54: 150.2,
                    55: 144.0,
                    56: 138.4,
                    57: 133.6,
                    58: 129.4,
                    59: 125.7,
                    60: 122.4,
                    61: 119.6,
                    62: 117.4,
                    63: 115.7,
                    64: 114.6,
                    65: 114.2,
                    66: 114.6,
                    67: 115.7,
                    68: 117.6,
                    69: 120.3,
                    70: 123.9,
                    71: 128.2,
                    72: 133.2,
                    73: 138.9,
                    74: 145.1,
                    75: 151.5,
                    76: 157.9,
                    77: 163.8,
                    78: 168.3,
                    79: 170.6,
                    80: 170.4,
                    81: 168.3,
                    82: 165.3,
                    83: 162.3,
                    84: 160.1,
                    85: 158.4,
                    86: 156.8,
                    87: 154.8,
                    88: 151.9,
                    89: 147.9,
                    90: 142.5,
                    91: 135.7,
                    92: 127.2,
                    93: 117.5,
                    94: 107.1,
                    95: 96.5,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 80.2,
                    1: 75.1,
                    2: 70.7,
                    3: 66.6,
                    4: 62.3,
                    5: 58.0,
                    6: 54.1,
                    7: 50.8,
                    8: 48.4,
                    9: 46.8,
                    10: 45.7,
                    11: 44.9,
                    12: 44.4,
                    13: 43.9,
                    14: 43.5,
                    15: 43.3,
                    16: 43.1,
                    17: 43.1,
                    18: 43.1,
                    19: 43.3,
                    20: 43.6,
                    21: 44.2,
                    22: 45.4,
                    23: 47.4,
                    24: 50.5,
                    25: 54.9,
                    26: 60.7,
                    27: 68.2,
                    28: 77.5,
                    29: 87.9,
                    30: 98.6,
                    31: 109.0,
                    32: 118.4,
                    33: 126.7,
                    34: 133.8,
                    35: 139.8,
                    36: 144.7,
                    37: 148.8,
                    38: 152.4,
                    39: 155.6,
                    40: 158.9,
                    41: 162.0,
                    42: 164.9,
                    43: 167.3,
                    44: 169.2,
                    45: 170.8,
                    46: 172.5,
                    47: 174.8,
                    48: 177.7,
                    49: 180.8,
                    50: 183.1,
                    51: 183.9,
                    52: 182.7,
                    53: 179.8,
                    54: 175.8,
                    55: 171.5,
                    56: 167.2,
                    57: 163.1,
                    58: 159.2,
                    59: 155.6,
                    60: 152.3,
                    61: 149.5,
                    62: 147.2,
                    63: 145.7,
                    64: 145.0,
                    65: 145.4,
                    66: 146.7,
                    67: 149.0,
                    68: 152.3,
                    69: 156.4,
                    70: 161.5,
                    71: 167.3,
                    72: 173.7,
                    73: 180.4,
                    74: 186.7,
                    75: 192.3,
                    76: 196.5,
                    77: 199.0,
                    78: 199.4,
                    79: 197.3,
                    80: 192.4,
                    81: 185.2,
                    82: 176.6,
                    83: 167.3,
                    84: 157.9,
                    85: 149.5,
                    86: 142.9,
                    87: 139.0,
                    88: 138.3,
                    89: 139.2,
                    90: 139.5,
                    91: 137.3,
                    92: 131.1,
                    93: 121.9,
                    94: 111.5,
                    95: 101.5,
                },
                BDEWDAY.Sunday: {
                    0: 93.4,
                    1: 86.8,
                    2: 81.2,
                    3: 75.7,
                    4: 70.1,
                    5: 64.5,
                    6: 59.3,
                    7: 54.9,
                    8: 51.7,
                    9: 49.4,
                    10: 47.8,
                    11: 46.6,
                    12: 45.5,
                    13: 44.5,
                    14: 43.8,
                    15: 43.3,
                    16: 43.1,
                    17: 43.1,
                    18: 43.2,
                    19: 43.3,
                    20: 43.3,
                    21: 43.3,
                    22: 43.2,
                    23: 43.3,
                    24: 43.5,
                    25: 44.3,
                    26: 46.0,
                    27: 49.1,
                    28: 53.9,
                    29: 60.4,
                    30: 68.8,
                    31: 79.1,
                    32: 91.1,
                    33: 104.3,
                    34: 118.0,
                    35: 131.5,
                    36: 144.2,
                    37: 155.5,
                    38: 165.3,
                    39: 173.1,
                    40: 178.8,
                    41: 183.1,
                    42: 187.0,
                    43: 191.4,
                    44: 197.0,
                    45: 203.0,
                    46: 208.5,
                    47: 212.2,
                    48: 213.5,
                    49: 211.8,
                    50: 207.0,
                    51: 198.9,
                    52: 187.6,
                    53: 174.6,
                    54: 161.7,
                    55: 150.6,
                    56: 142.8,
                    57: 137.6,
                    58: 133.9,
                    59: 130.7,
                    60: 127.1,
                    61: 123.1,
                    62: 119.0,
                    63: 114.9,
                    64: 111.0,
                    65: 107.7,
                    66: 105.6,
                    67: 104.9,
                    68: 106.0,
                    69: 108.8,
                    70: 113.2,
                    71: 119.0,
                    72: 126.0,
                    73: 133.7,
                    74: 141.5,
                    75: 149.0,
                    76: 155.5,
                    77: 160.6,
                    78: 163.6,
                    79: 164.0,
                    80: 161.5,
                    81: 157.1,
                    82: 152.2,
                    83: 148.2,
                    84: 145.9,
                    85: 144.7,
                    86: 143.6,
                    87: 141.5,
                    88: 137.5,
                    89: 131.8,
                    90: 124.7,
                    91: 116.5,
                    92: 107.6,
                    93: 98.4,
                    94: 89.2,
                    95: 80.7,
                },
                BDEWDAY.Workday: {
                    0: 77.8,
                    1: 69.6,
                    2: 62.4,
                    3: 56.6,
                    4: 52.5,
                    5: 49.7,
                    6: 47.9,
                    7: 46.6,
                    8: 45.5,
                    9: 44.5,
                    10: 43.8,
                    11: 43.3,
                    12: 43.0,
                    13: 43.0,
                    14: 43.1,
                    15: 43.3,
                    16: 43.4,
                    17: 43.7,
                    18: 44.2,
                    19: 44.9,
                    20: 46.3,
                    21: 48.9,
                    22: 53.7,
                    23: 61.6,
                    24: 72.9,
                    25: 86.3,
                    26: 100.1,
                    27: 112.4,
                    28: 121.8,
                    29: 128.5,
                    30: 132.9,
                    31: 135.7,
                    32: 137.2,
                    33: 137.7,
                    34: 137.7,
                    35: 137.3,
                    36: 136.9,
                    37: 136.4,
                    38: 135.7,
                    39: 134.8,
                    40: 133.7,
                    41: 132.4,
                    42: 131.4,
                    43: 130.7,
                    44: 130.6,
                    45: 131.5,
                    46: 133.6,
                    47: 137.3,
                    48: 142.6,
                    49: 148.2,
                    50: 152.8,
                    51: 154.8,
                    52: 153.2,
                    53: 148.9,
                    54: 143.2,
                    55: 137.3,
                    56: 132.4,
                    57: 128.4,
                    58: 124.8,
                    59: 121.5,
                    60: 118.1,
                    61: 114.8,
                    62: 111.7,
                    63: 109.0,
                    64: 106.9,
                    65: 105.7,
                    66: 105.5,
                    67: 106.5,
                    68: 109.1,
                    69: 113.1,
                    70: 118.3,
                    71: 124.8,
                    72: 132.4,
                    73: 140.6,
                    74: 149.1,
                    75: 157.3,
                    76: 164.9,
                    77: 171.1,
                    78: 175.2,
                    79: 176.5,
                    80: 174.5,
                    81: 170.5,
                    82: 165.7,
                    83: 161.5,
                    84: 158.9,
                    85: 157.2,
                    86: 155.4,
                    87: 152.3,
                    88: 147.2,
                    89: 140.3,
                    90: 132.1,
                    91: 123.2,
                    92: 114.0,
                    93: 104.8,
                    94: 95.6,
                    95: 86.6,
                },
            },
        }
        self.G0: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 70.0,
                    1: 73.0,
                    2: 75.9,
                    3: 77.6,
                    4: 77.1,
                    5: 75.0,
                    6: 72.1,
                    7: 69.1,
                    8: 66.8,
                    9: 65.1,
                    10: 64.1,
                    11: 63.5,
                    12: 63.4,
                    13: 63.6,
                    14: 64.0,
                    15: 64.5,
                    16: 65.0,
                    17: 65.6,
                    18: 66.3,
                    19: 67.3,
                    20: 68.5,
                    21: 69.9,
                    22: 71.4,
                    23: 72.9,
                    24: 74.4,
                    25: 76.8,
                    26: 81.0,
                    27: 87.8,
                    28: 98.0,
                    29: 110.7,
                    30: 124.8,
                    31: 139.2,
                    32: 153.0,
                    33: 165.4,
                    34: 175.9,
                    35: 184.1,
                    36: 189.5,
                    37: 192.8,
                    38: 195.1,
                    39: 197.1,
                    40: 199.8,
                    41: 202.7,
                    42: 205.4,
                    43: 207.4,
                    44: 208.4,
                    45: 208.3,
                    46: 207.4,
                    47: 205.6,
                    48: 203.0,
                    49: 199.7,
                    50: 195.6,
                    51: 190.6,
                    52: 184.6,
                    53: 177.5,
                    54: 168.9,
                    55: 158.8,
                    56: 147.2,
                    57: 134.8,
                    58: 122.7,
                    59: 112.1,
                    60: 103.8,
                    61: 97.4,
                    62: 92.6,
                    63: 88.8,
                    64: 85.6,
                    65: 83.3,
                    66: 82.4,
                    67: 83.2,
                    68: 85.8,
                    69: 89.5,
                    70: 93.4,
                    71: 96.2,
                    72: 97.4,
                    73: 97.4,
                    74: 96.8,
                    75: 96.2,
                    76: 96.3,
                    77: 96.8,
                    78: 97.2,
                    79: 97.2,
                    80: 96.3,
                    81: 94.8,
                    82: 92.8,
                    83: 90.6,
                    84: 88.5,
                    85: 86.4,
                    86: 84.3,
                    87: 82.2,
                    88: 80.1,
                    89: 78.0,
                    90: 75.9,
                    91: 73.8,
                    92: 71.7,
                    93: 69.7,
                    94: 67.6,
                    95: 65.4,
                },
                BDEWDAY.Sunday: {
                    0: 63.2,
                    1: 61.0,
                    2: 58.9,
                    3: 57.0,
                    4: 55.3,
                    5: 53.7,
                    6: 52.1,
                    7: 50.5,
                    8: 48.7,
                    9: 46.9,
                    10: 45.2,
                    11: 43.9,
                    12: 43.0,
                    13: 42.5,
                    14: 42.2,
                    15: 42.0,
                    16: 41.9,
                    17: 41.8,
                    18: 41.8,
                    19: 42.0,
                    20: 42.6,
                    21: 43.4,
                    22: 44.4,
                    23: 45.8,
                    24: 47.4,
                    25: 49.0,
                    26: 50.4,
                    27: 51.4,
                    28: 51.8,
                    29: 51.7,
                    30: 51.2,
                    31: 50.5,
                    32: 49.6,
                    33: 49.0,
                    34: 48.8,
                    35: 49.5,
                    36: 51.3,
                    37: 53.8,
                    38: 56.8,
                    39: 59.8,
                    40: 62.6,
                    41: 65.1,
                    42: 67.2,
                    43: 69.1,
                    44: 70.8,
                    45: 72.2,
                    46: 73.5,
                    47: 74.7,
                    48: 76.0,
                    49: 77.3,
                    50: 78.4,
                    51: 79.4,
                    52: 80.1,
                    53: 80.5,
                    54: 80.3,
                    55: 79.4,
                    56: 77.8,
                    57: 75.7,
                    58: 73.4,
                    59: 71.0,
                    60: 68.9,
                    61: 67.0,
                    62: 65.2,
                    63: 63.5,
                    64: 62.0,
                    65: 61.2,
                    66: 61.8,
                    67: 64.5,
                    68: 69.5,
                    69: 76.0,
                    70: 82.6,
                    71: 87.8,
                    72: 90.8,
                    73: 92.1,
                    74: 92.3,
                    75: 92.5,
                    76: 93.1,
                    77: 94.0,
                    78: 94.6,
                    79: 94.4,
                    80: 93.0,
                    81: 90.8,
                    82: 88.0,
                    83: 85.0,
                    84: 82.1,
                    85: 79.4,
                    86: 76.9,
                    87: 74.7,
                    88: 72.8,
                    89: 71.1,
                    90: 69.3,
                    91: 67.3,
                    92: 65.0,
                    93: 62.6,
                    94: 60.4,
                    95: 58.9,
                },
                BDEWDAY.Workday: {
                    0: 65.5,
                    1: 62.6,
                    2: 59.6,
                    3: 57.0,
                    4: 54.8,
                    5: 53.1,
                    6: 51.7,
                    7: 50.5,
                    8: 49.4,
                    9: 48.5,
                    10: 47.9,
                    11: 47.7,
                    12: 47.9,
                    13: 48.7,
                    14: 50.2,
                    15: 52.3,
                    16: 55.1,
                    17: 58.2,
                    18: 61.2,
                    19: 63.5,
                    20: 65.0,
                    21: 66.0,
                    22: 67.1,
                    23: 69.1,
                    24: 72.5,
                    25: 77.1,
                    26: 82.9,
                    27: 89.7,
                    28: 97.6,
                    29: 107.3,
                    30: 119.9,
                    31: 136.4,
                    32: 157.1,
                    33: 179.5,
                    34: 200.5,
                    35: 216.8,
                    36: 226.2,
                    37: 230.0,
                    38: 230.4,
                    39: 229.9,
                    40: 230.0,
                    41: 231.2,
                    42: 233.0,
                    43: 235.5,
                    44: 238.1,
                    45: 240.0,
                    46: 240.4,
                    47: 238.3,
                    48: 233.0,
                    49: 225.1,
                    50: 215.7,
                    51: 205.6,
                    52: 195.7,
                    53: 186.7,
                    54: 179.2,
                    55: 173.8,
                    56: 171.0,
                    57: 170.7,
                    58: 172.7,
                    59: 176.6,
                    60: 182.1,
                    61: 188.2,
                    62: 193.9,
                    63: 198.1,
                    64: 200.1,
                    65: 200.7,
                    66: 200.9,
                    67: 201.8,
                    68: 204.0,
                    69: 205.8,
                    70: 205.5,
                    71: 200.9,
                    72: 190.7,
                    73: 176.6,
                    74: 160.5,
                    75: 144.8,
                    76: 131.3,
                    77: 120.1,
                    78: 111.3,
                    79: 104.6,
                    80: 100.0,
                    81: 96.7,
                    82: 94.1,
                    83: 91.6,
                    84: 88.5,
                    85: 85.2,
                    86: 82.1,
                    87: 79.4,
                    88: 77.6,
                    89: 76.4,
                    90: 75.6,
                    91: 74.7,
                    92: 73.7,
                    93: 72.3,
                    94: 70.5,
                    95: 68.2,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 74.6,
                    1: 76.2,
                    2: 77.7,
                    3: 78.5,
                    4: 77.9,
                    5: 76.3,
                    6: 74.1,
                    7: 71.9,
                    8: 70.2,
                    9: 68.9,
                    10: 67.9,
                    11: 67.3,
                    12: 66.9,
                    13: 66.7,
                    14: 66.8,
                    15: 67.3,
                    16: 68.0,
                    17: 69.0,
                    18: 70.0,
                    19: 71.0,
                    20: 71.8,
                    21: 72.4,
                    22: 72.8,
                    23: 72.9,
                    24: 73.0,
                    25: 73.9,
                    26: 77.0,
                    27: 83.2,
                    28: 93.3,
                    29: 106.2,
                    30: 120.5,
                    31: 134.5,
                    32: 147.2,
                    33: 157.8,
                    34: 166.2,
                    35: 171.9,
                    36: 175.0,
                    37: 176.1,
                    38: 176.3,
                    39: 176.6,
                    40: 177.7,
                    41: 179.4,
                    42: 181.3,
                    43: 183.1,
                    44: 184.4,
                    45: 185.2,
                    46: 185.3,
                    47: 185.0,
                    48: 184.1,
                    49: 182.4,
                    50: 179.7,
                    51: 175.7,
                    52: 170.1,
                    53: 163.1,
                    54: 154.6,
                    55: 144.8,
                    56: 133.9,
                    57: 122.7,
                    58: 112.0,
                    59: 102.8,
                    60: 95.7,
                    61: 90.4,
                    62: 86.4,
                    63: 83.2,
                    64: 80.3,
                    65: 77.8,
                    66: 75.9,
                    67: 74.7,
                    68: 74.4,
                    69: 74.8,
                    70: 75.6,
                    71: 76.6,
                    72: 77.6,
                    73: 78.5,
                    74: 79.1,
                    75: 79.4,
                    76: 79.4,
                    77: 79.4,
                    78: 79.6,
                    79: 80.4,
                    80: 81.9,
                    81: 83.9,
                    82: 85.7,
                    83: 86.9,
                    84: 87.0,
                    85: 86.3,
                    86: 84.9,
                    87: 83.2,
                    88: 81.3,
                    89: 79.3,
                    90: 77.4,
                    91: 75.7,
                    92: 74.1,
                    93: 72.7,
                    94: 71.3,
                    95: 70.1,
                },
                BDEWDAY.Sunday: {
                    0: 68.8,
                    1: 67.4,
                    2: 65.7,
                    3: 63.5,
                    4: 60.9,
                    5: 58.0,
                    6: 55.4,
                    7: 53.3,
                    8: 52.0,
                    9: 51.4,
                    10: 51.0,
                    11: 50.5,
                    12: 49.6,
                    13: 48.5,
                    14: 47.5,
                    15: 46.7,
                    16: 46.4,
                    17: 46.5,
                    18: 46.6,
                    19: 46.7,
                    20: 46.6,
                    21: 46.3,
                    22: 46.0,
                    23: 45.8,
                    24: 45.9,
                    25: 46.3,
                    26: 47.2,
                    27: 48.6,
                    28: 50.5,
                    29: 52.6,
                    30: 54.3,
                    31: 55.1,
                    32: 54.8,
                    33: 53.9,
                    34: 53.2,
                    35: 53.3,
                    36: 54.7,
                    37: 57.2,
                    38: 60.0,
                    39: 62.6,
                    40: 64.5,
                    41: 65.9,
                    42: 67.0,
                    43: 68.2,
                    44: 69.7,
                    45: 71.4,
                    46: 73.2,
                    47: 74.7,
                    48: 76.0,
                    49: 77.0,
                    50: 77.8,
                    51: 78.5,
                    52: 79.1,
                    53: 79.5,
                    54: 79.3,
                    55: 78.5,
                    56: 76.8,
                    57: 74.4,
                    58: 71.8,
                    59: 69.1,
                    60: 66.8,
                    61: 64.8,
                    62: 63.1,
                    63: 61.7,
                    64: 60.4,
                    65: 59.7,
                    66: 59.7,
                    67: 60.7,
                    68: 63.0,
                    69: 66.0,
                    70: 69.2,
                    71: 71.9,
                    72: 73.9,
                    73: 75.1,
                    74: 76.0,
                    75: 76.6,
                    76: 77.3,
                    77: 78.2,
                    78: 79.2,
                    79: 80.4,
                    80: 81.6,
                    81: 82.9,
                    82: 83.8,
                    83: 84.1,
                    84: 83.7,
                    85: 82.7,
                    86: 81.2,
                    87: 79.4,
                    88: 77.5,
                    89: 75.5,
                    90: 73.3,
                    91: 71.0,
                    92: 68.6,
                    93: 66.4,
                    94: 64.6,
                    95: 63.5,
                },
                BDEWDAY.Workday: {
                    0: 71.5,
                    1: 69.0,
                    2: 66.3,
                    3: 63.5,
                    4: 60.9,
                    5: 58.6,
                    6: 56.6,
                    7: 55.1,
                    8: 54.2,
                    9: 53.7,
                    10: 53.4,
                    11: 53.3,
                    12: 53.1,
                    13: 53.2,
                    14: 54.1,
                    15: 56.1,
                    16: 59.4,
                    17: 63.3,
                    18: 67.2,
                    19: 70.1,
                    20: 71.4,
                    21: 71.6,
                    22: 71.2,
                    23: 71.0,
                    24: 71.5,
                    25: 73.1,
                    26: 75.9,
                    27: 80.4,
                    28: 86.6,
                    29: 95.1,
                    30: 106.3,
                    31: 120.5,
                    32: 137.8,
                    33: 156.3,
                    34: 173.4,
                    35: 186.9,
                    36: 195.0,
                    37: 198.7,
                    38: 199.8,
                    39: 200.0,
                    40: 200.6,
                    41: 201.9,
                    42: 203.6,
                    43: 205.6,
                    44: 207.6,
                    45: 209.1,
                    46: 209.6,
                    47: 208.4,
                    48: 205.1,
                    49: 200.0,
                    50: 193.8,
                    51: 186.9,
                    52: 179.9,
                    53: 173.4,
                    54: 168.1,
                    55: 164.4,
                    56: 163.0,
                    57: 163.5,
                    58: 165.4,
                    59: 168.2,
                    60: 171.5,
                    61: 174.6,
                    62: 177.2,
                    63: 178.5,
                    64: 178.2,
                    65: 176.8,
                    66: 175.1,
                    67: 173.8,
                    68: 173.2,
                    69: 172.4,
                    70: 170.2,
                    71: 165.4,
                    72: 157.1,
                    73: 146.1,
                    74: 133.8,
                    75: 121.5,
                    76: 110.1,
                    77: 100.5,
                    78: 93.2,
                    79: 88.8,
                    80: 87.4,
                    81: 88.1,
                    82: 89.6,
                    83: 90.6,
                    84: 90.2,
                    85: 88.5,
                    86: 86.3,
                    87: 84.1,
                    88: 82.4,
                    89: 81.2,
                    90: 80.3,
                    91: 79.4,
                    92: 78.4,
                    93: 77.2,
                    94: 75.7,
                    95: 73.8,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 75.8,
                    1: 76.7,
                    2: 77.7,
                    3: 78.5,
                    4: 78.5,
                    5: 77.8,
                    6: 76.6,
                    7: 74.7,
                    8: 72.6,
                    9: 70.4,
                    10: 68.5,
                    11: 67.3,
                    12: 67.0,
                    13: 67.5,
                    14: 68.3,
                    15: 69.1,
                    16: 69.7,
                    17: 70.1,
                    18: 70.5,
                    19: 71.0,
                    20: 71.8,
                    21: 72.5,
                    22: 73.0,
                    23: 72.9,
                    24: 72.2,
                    25: 72.2,
                    26: 74.4,
                    27: 80.4,
                    28: 91.0,
                    29: 105.2,
                    30: 121.2,
                    31: 137.4,
                    32: 152.1,
                    33: 164.9,
                    34: 175.1,
                    35: 182.2,
                    36: 186.1,
                    37: 187.5,
                    38: 187.7,
                    39: 187.8,
                    40: 188.7,
                    41: 190.1,
                    42: 191.9,
                    43: 193.4,
                    44: 194.5,
                    45: 195.1,
                    46: 195.3,
                    47: 195.3,
                    48: 194.9,
                    49: 193.9,
                    50: 191.7,
                    51: 187.8,
                    52: 181.9,
                    53: 174.1,
                    54: 164.8,
                    55: 154.2,
                    56: 142.6,
                    57: 130.9,
                    58: 119.8,
                    59: 110.3,
                    60: 102.7,
                    61: 96.9,
                    62: 92.1,
                    63: 87.8,
                    64: 83.6,
                    65: 79.7,
                    66: 76.9,
                    67: 75.7,
                    68: 76.5,
                    69: 78.6,
                    70: 81.1,
                    71: 83.2,
                    72: 84.1,
                    73: 84.3,
                    74: 84.1,
                    75: 84.1,
                    76: 84.7,
                    77: 85.8,
                    78: 87.3,
                    79: 88.8,
                    80: 90.1,
                    81: 91.2,
                    82: 91.7,
                    83: 91.6,
                    84: 90.6,
                    85: 89.0,
                    86: 87.1,
                    87: 85.0,
                    88: 83.1,
                    89: 81.2,
                    90: 79.4,
                    91: 77.6,
                    92: 75.7,
                    93: 73.8,
                    94: 71.9,
                    95: 70.1,
                },
                BDEWDAY.Sunday: {
                    0: 68.3,
                    1: 66.5,
                    2: 64.6,
                    3: 62.6,
                    4: 60.3,
                    5: 57.9,
                    6: 55.5,
                    7: 53.3,
                    8: 51.2,
                    9: 49.5,
                    10: 48.0,
                    11: 46.7,
                    12: 45.7,
                    13: 44.9,
                    14: 44.3,
                    15: 43.9,
                    16: 43.6,
                    17: 43.5,
                    18: 43.6,
                    19: 43.9,
                    20: 44.5,
                    21: 45.1,
                    22: 45.6,
                    23: 45.8,
                    24: 45.6,
                    25: 45.3,
                    26: 45.2,
                    27: 45.8,
                    28: 47.2,
                    29: 49.1,
                    30: 51.0,
                    31: 52.3,
                    32: 52.8,
                    33: 52.9,
                    34: 53.1,
                    35: 54.2,
                    36: 56.4,
                    37: 59.5,
                    38: 62.7,
                    39: 65.4,
                    40: 67.2,
                    41: 68.5,
                    42: 69.6,
                    43: 71.0,
                    44: 73.1,
                    45: 75.6,
                    46: 78.2,
                    47: 80.4,
                    48: 81.9,
                    49: 82.8,
                    50: 83.2,
                    51: 83.2,
                    52: 82.8,
                    53: 82.1,
                    54: 80.9,
                    55: 79.4,
                    56: 77.5,
                    57: 75.3,
                    58: 73.1,
                    59: 71.0,
                    60: 69.2,
                    61: 67.6,
                    62: 66.1,
                    63: 64.5,
                    64: 62.8,
                    65: 61.5,
                    66: 61.2,
                    67: 62.6,
                    68: 65.9,
                    69: 70.4,
                    70: 75.0,
                    71: 78.5,
                    72: 80.1,
                    73: 80.4,
                    74: 80.2,
                    75: 80.4,
                    76: 81.4,
                    77: 83.1,
                    78: 85.1,
                    79: 86.9,
                    80: 88.1,
                    81: 88.7,
                    82: 88.6,
                    83: 87.8,
                    84: 86.4,
                    85: 84.4,
                    86: 82.0,
                    87: 79.4,
                    88: 76.7,
                    89: 74.1,
                    90: 71.5,
                    91: 69.1,
                    92: 67.0,
                    93: 65.3,
                    94: 64.1,
                    95: 63.5,
                },
                BDEWDAY.Workday: {
                    0: 73.0,
                    1: 70.1,
                    2: 67.1,
                    3: 64.5,
                    4: 62.3,
                    5: 60.6,
                    6: 59.2,
                    7: 57.9,
                    8: 56.7,
                    9: 55.6,
                    10: 54.7,
                    11: 54.2,
                    12: 54.1,
                    13: 54.6,
                    14: 55.8,
                    15: 57.9,
                    16: 60.9,
                    17: 64.4,
                    18: 68.0,
                    19: 71.0,
                    20: 73.2,
                    21: 74.7,
                    22: 75.7,
                    23: 76.6,
                    24: 77.7,
                    25: 79.3,
                    26: 81.9,
                    27: 86.0,
                    28: 91.9,
                    29: 100.4,
                    30: 111.9,
                    31: 127.1,
                    32: 145.9,
                    33: 166.2,
                    34: 185.2,
                    35: 200.0,
                    36: 208.5,
                    37: 212.1,
                    38: 212.6,
                    39: 212.1,
                    40: 212.2,
                    41: 213.1,
                    42: 214.6,
                    43: 216.8,
                    44: 219.2,
                    45: 221.2,
                    46: 222.0,
                    47: 220.5,
                    48: 216.3,
                    49: 209.8,
                    50: 201.9,
                    51: 193.4,
                    52: 185.0,
                    53: 177.4,
                    54: 170.9,
                    55: 166.3,
                    56: 163.9,
                    57: 163.6,
                    58: 165.1,
                    59: 168.2,
                    60: 172.5,
                    61: 177.3,
                    62: 181.4,
                    63: 184.1,
                    64: 184.5,
                    65: 183.6,
                    66: 182.1,
                    67: 181.3,
                    68: 181.5,
                    69: 181.7,
                    70: 180.0,
                    71: 174.7,
                    72: 164.8,
                    73: 151.5,
                    74: 137.0,
                    75: 123.3,
                    76: 112.1,
                    77: 103.4,
                    78: 97.3,
                    79: 93.4,
                    80: 91.6,
                    81: 91.1,
                    82: 91.1,
                    83: 90.6,
                    84: 89.2,
                    85: 87.2,
                    86: 85.0,
                    87: 83.2,
                    88: 82.1,
                    89: 81.7,
                    90: 81.6,
                    91: 81.3,
                    92: 80.6,
                    93: 79.5,
                    94: 77.9,
                    95: 75.7,
                },
            },
        }
        self.G1: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 25.8,
                    1: 25.2,
                    2: 24.7,
                    3: 24.6,
                    4: 25.0,
                    5: 25.6,
                    6: 26.2,
                    7: 26.5,
                    8: 26.3,
                    9: 25.8,
                    10: 25.1,
                    11: 24.6,
                    12: 24.4,
                    13: 24.5,
                    14: 24.6,
                    15: 24.6,
                    16: 24.5,
                    17: 24.3,
                    18: 24.3,
                    19: 24.6,
                    20: 25.4,
                    21: 26.5,
                    22: 27.6,
                    23: 28.4,
                    24: 28.7,
                    25: 28.7,
                    26: 28.5,
                    27: 28.4,
                    28: 28.5,
                    29: 29.1,
                    30: 30.2,
                    31: 32.2,
                    32: 35.0,
                    33: 38.4,
                    34: 42.0,
                    35: 45.4,
                    36: 48.4,
                    37: 50.9,
                    38: 53.0,
                    39: 54.9,
                    40: 56.6,
                    41: 57.9,
                    42: 58.7,
                    43: 58.7,
                    44: 57.8,
                    45: 56.3,
                    46: 54.6,
                    47: 53.0,
                    48: 51.7,
                    49: 50.6,
                    50: 49.3,
                    51: 47.3,
                    52: 44.6,
                    53: 41.4,
                    54: 38.4,
                    55: 36.0,
                    56: 34.5,
                    57: 33.9,
                    58: 33.9,
                    59: 34.1,
                    60: 34.3,
                    61: 34.4,
                    62: 34.4,
                    63: 34.1,
                    64: 33.5,
                    65: 32.9,
                    66: 32.4,
                    67: 32.2,
                    68: 32.4,
                    69: 33.0,
                    70: 33.6,
                    71: 34.1,
                    72: 34.3,
                    73: 34.2,
                    74: 34.1,
                    75: 34.1,
                    76: 34.1,
                    77: 34.3,
                    78: 34.3,
                    79: 34.1,
                    80: 33.5,
                    81: 32.6,
                    82: 31.5,
                    83: 30.3,
                    84: 29.0,
                    85: 27.8,
                    86: 26.9,
                    87: 26.5,
                    88: 26.7,
                    89: 27.3,
                    90: 28.0,
                    91: 28.4,
                    92: 28.4,
                    93: 28.0,
                    94: 27.3,
                    95: 26.5,
                },
                BDEWDAY.Sunday: {
                    0: 25.7,
                    1: 25.0,
                    2: 24.6,
                    3: 24.6,
                    4: 25.0,
                    5: 25.6,
                    6: 26.2,
                    7: 26.5,
                    8: 26.3,
                    9: 25.7,
                    10: 25.1,
                    11: 24.6,
                    12: 24.4,
                    13: 24.5,
                    14: 24.6,
                    15: 24.6,
                    16: 24.5,
                    17: 24.3,
                    18: 24.3,
                    19: 24.6,
                    20: 25.4,
                    21: 26.5,
                    22: 27.6,
                    23: 28.4,
                    24: 28.8,
                    25: 28.8,
                    26: 28.6,
                    27: 28.4,
                    28: 28.2,
                    29: 28.1,
                    30: 28.2,
                    31: 28.4,
                    32: 28.8,
                    33: 29.3,
                    34: 29.9,
                    35: 30.3,
                    36: 30.5,
                    37: 30.5,
                    38: 30.4,
                    39: 30.3,
                    40: 30.1,
                    41: 30.0,
                    42: 30.0,
                    43: 30.3,
                    44: 30.8,
                    45: 31.4,
                    46: 31.9,
                    47: 32.2,
                    48: 32.1,
                    49: 31.6,
                    50: 31.0,
                    51: 30.3,
                    52: 29.6,
                    53: 29.0,
                    54: 28.5,
                    55: 28.4,
                    56: 28.6,
                    57: 29.0,
                    58: 29.6,
                    59: 30.3,
                    60: 30.9,
                    61: 31.4,
                    62: 31.9,
                    63: 32.2,
                    64: 32.4,
                    65: 32.4,
                    66: 32.4,
                    67: 32.2,
                    68: 31.9,
                    69: 31.7,
                    70: 31.7,
                    71: 32.2,
                    72: 33.2,
                    73: 34.5,
                    74: 35.5,
                    75: 36.0,
                    76: 35.5,
                    77: 34.3,
                    78: 33.1,
                    79: 32.2,
                    80: 31.9,
                    81: 32.1,
                    82: 32.3,
                    83: 32.2,
                    84: 31.5,
                    85: 30.4,
                    86: 29.2,
                    87: 28.4,
                    88: 28.1,
                    89: 28.2,
                    90: 28.4,
                    91: 28.4,
                    92: 28.1,
                    93: 27.6,
                    94: 27.0,
                    95: 26.5,
                },
                BDEWDAY.Workday: {
                    0: 26.4,
                    1: 26.4,
                    2: 26.4,
                    3: 26.5,
                    4: 26.5,
                    5: 26.5,
                    6: 26.5,
                    7: 26.5,
                    8: 26.6,
                    9: 26.6,
                    10: 26.6,
                    11: 26.5,
                    12: 26.2,
                    13: 25.8,
                    14: 25.3,
                    15: 24.6,
                    16: 23.9,
                    17: 23.6,
                    18: 24.3,
                    19: 26.5,
                    20: 27.0,
                    21: 27.4,
                    22: 27.9,
                    23: 28.4,
                    24: 31.5,
                    25: 32.5,
                    26: 35.3,
                    27: 36.0,
                    28: 90.3,
                    29: 164.8,
                    30: 246.8,
                    31: 323.7,
                    32: 385.2,
                    33: 430.7,
                    34: 462.0,
                    35: 480.8,
                    36: 489.0,
                    37: 489.9,
                    38: 486.7,
                    39: 482.6,
                    40: 480.5,
                    41: 479.8,
                    42: 479.6,
                    43: 478.9,
                    44: 476.5,
                    45: 472.0,
                    46: 464.8,
                    47: 454.3,
                    48: 440.0,
                    49: 422.0,
                    50: 400.2,
                    51: 374.8,
                    52: 346.4,
                    53: 319.4,
                    54: 298.8,
                    55: 289.6,
                    56: 294.8,
                    57: 309.8,
                    58: 328.0,
                    59: 342.6,
                    60: 348.5,
                    61: 345.8,
                    62: 336.4,
                    63: 321.8,
                    64: 303.4,
                    65: 281.9,
                    66: 257.6,
                    67: 230.9,
                    68: 202.5,
                    69: 174.0,
                    70: 147.5,
                    71: 124.9,
                    72: 107.6,
                    73: 94.7,
                    74: 84.6,
                    75: 75.7,
                    76: 66.9,
                    77: 58.5,
                    78: 51.1,
                    79: 45.4,
                    80: 41.8,
                    81: 39.8,
                    82: 38.7,
                    83: 37.9,
                    84: 36.7,
                    85: 35.2,
                    86: 33.6,
                    87: 32.2,
                    88: 30.9,
                    89: 29.9,
                    90: 29.1,
                    91: 28.4,
                    92: 27.8,
                    93: 27.2,
                    94: 26.8,
                    95: 26.5,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 23.6,
                    1: 22.5,
                    2: 21.5,
                    3: 20.8,
                    4: 20.5,
                    5: 20.5,
                    6: 20.7,
                    7: 20.8,
                    8: 20.9,
                    9: 20.9,
                    10: 20.9,
                    11: 20.8,
                    12: 20.8,
                    13: 20.8,
                    14: 20.8,
                    15: 20.8,
                    16: 20.7,
                    17: 20.7,
                    18: 20.7,
                    19: 20.8,
                    20: 21.1,
                    21: 21.6,
                    22: 22.1,
                    23: 22.7,
                    24: 23.3,
                    25: 23.8,
                    26: 24.2,
                    27: 24.6,
                    28: 24.9,
                    29: 25.2,
                    30: 25.7,
                    31: 26.5,
                    32: 27.7,
                    33: 29.4,
                    34: 31.5,
                    35: 34.1,
                    36: 37.0,
                    37: 40.1,
                    38: 43.0,
                    39: 45.4,
                    40: 47.2,
                    41: 48.4,
                    42: 49.0,
                    43: 49.2,
                    44: 49.0,
                    45: 48.4,
                    46: 47.3,
                    47: 45.4,
                    48: 42.9,
                    49: 39.9,
                    50: 36.8,
                    51: 34.1,
                    52: 31.9,
                    53: 30.3,
                    54: 29.2,
                    55: 28.4,
                    56: 27.8,
                    57: 27.4,
                    58: 27.0,
                    59: 26.5,
                    60: 25.9,
                    61: 25.4,
                    62: 24.9,
                    63: 24.6,
                    64: 24.6,
                    65: 24.7,
                    66: 24.8,
                    67: 24.6,
                    68: 24.1,
                    69: 23.5,
                    70: 22.9,
                    71: 22.7,
                    72: 23.0,
                    73: 23.6,
                    74: 24.3,
                    75: 24.6,
                    76: 24.5,
                    77: 24.0,
                    78: 23.3,
                    79: 22.7,
                    80: 22.3,
                    81: 22.2,
                    82: 22.3,
                    83: 22.7,
                    84: 23.3,
                    85: 23.9,
                    86: 24.4,
                    87: 24.6,
                    88: 24.3,
                    89: 23.8,
                    90: 23.2,
                    91: 22.7,
                    92: 22.6,
                    93: 22.7,
                    94: 22.8,
                    95: 22.7,
                },
                BDEWDAY.Sunday: {
                    0: 22.4,
                    1: 21.8,
                    2: 21.3,
                    3: 20.8,
                    4: 20.6,
                    5: 20.6,
                    6: 20.7,
                    7: 20.8,
                    8: 20.9,
                    9: 20.9,
                    10: 20.8,
                    11: 20.8,
                    12: 20.8,
                    13: 20.8,
                    14: 20.9,
                    15: 20.8,
                    16: 20.7,
                    17: 20.7,
                    18: 20.7,
                    19: 20.8,
                    20: 21.2,
                    21: 21.7,
                    22: 22.2,
                    23: 22.7,
                    24: 23.1,
                    25: 23.3,
                    26: 23.2,
                    27: 22.7,
                    28: 21.9,
                    29: 20.8,
                    30: 19.8,
                    31: 18.9,
                    32: 18.5,
                    33: 18.4,
                    34: 18.5,
                    35: 18.9,
                    36: 19.4,
                    37: 20.0,
                    38: 20.5,
                    39: 20.8,
                    40: 20.9,
                    41: 20.9,
                    42: 20.8,
                    43: 20.8,
                    44: 21.1,
                    45: 21.5,
                    46: 22.0,
                    47: 22.7,
                    48: 23.4,
                    49: 24.1,
                    50: 24.5,
                    51: 24.6,
                    52: 24.3,
                    53: 23.8,
                    54: 23.2,
                    55: 22.7,
                    56: 22.5,
                    57: 22.5,
                    58: 22.6,
                    59: 22.7,
                    60: 22.8,
                    61: 22.8,
                    62: 22.8,
                    63: 22.7,
                    64: 22.6,
                    65: 22.4,
                    66: 22.5,
                    67: 22.7,
                    68: 23.3,
                    69: 23.9,
                    70: 24.5,
                    71: 24.6,
                    72: 24.2,
                    73: 23.6,
                    74: 23.0,
                    75: 22.7,
                    76: 23.0,
                    77: 23.7,
                    78: 24.3,
                    79: 24.6,
                    80: 24.3,
                    81: 23.7,
                    82: 23.0,
                    83: 22.7,
                    84: 23.0,
                    85: 23.6,
                    86: 24.3,
                    87: 24.6,
                    88: 24.4,
                    89: 23.9,
                    90: 23.2,
                    91: 22.7,
                    92: 22.6,
                    93: 22.6,
                    94: 22.8,
                    95: 22.7,
                },
                BDEWDAY.Workday: {
                    0: 23.6,
                    1: 22.5,
                    2: 21.5,
                    3: 20.8,
                    4: 20.5,
                    5: 20.5,
                    6: 20.6,
                    7: 20.8,
                    8: 21.0,
                    9: 21.0,
                    10: 21.0,
                    11: 20.8,
                    12: 20.6,
                    13: 20.4,
                    14: 20.5,
                    15: 20.8,
                    16: 21.6,
                    17: 22.4,
                    18: 22.9,
                    19: 22.7,
                    20: 21.6,
                    21: 20.7,
                    22: 21.2,
                    23: 24.6,
                    24: 31.9,
                    25: 43.9,
                    26: 60.8,
                    27: 83.3,
                    28: 111.4,
                    29: 143.9,
                    30: 179.2,
                    31: 215.8,
                    32: 251.9,
                    33: 285.0,
                    34: 312.3,
                    35: 331.2,
                    36: 340.0,
                    37: 341.2,
                    38: 338.3,
                    39: 335.0,
                    40: 334.1,
                    41: 334.9,
                    42: 336.3,
                    43: 336.9,
                    44: 335.6,
                    45: 332.0,
                    46: 326.2,
                    47: 318.0,
                    48: 307.4,
                    49: 294.7,
                    50: 280.4,
                    51: 265.0,
                    52: 249.2,
                    53: 235.5,
                    54: 226.5,
                    55: 225.2,
                    56: 232.9,
                    57: 245.5,
                    58: 257.4,
                    59: 263.1,
                    60: 258.6,
                    61: 245.9,
                    62: 228.5,
                    63: 210.1,
                    64: 193.3,
                    65: 177.7,
                    66: 162.3,
                    67: 145.7,
                    68: 127.4,
                    69: 108.5,
                    70: 90.7,
                    71: 75.7,
                    72: 64.7,
                    73: 57.0,
                    74: 51.6,
                    75: 47.3,
                    76: 43.3,
                    77: 39.7,
                    78: 36.5,
                    79: 34.1,
                    80: 32.5,
                    81: 31.6,
                    82: 31.0,
                    83: 30.3,
                    84: 29.3,
                    85: 28.2,
                    86: 27.2,
                    87: 26.5,
                    88: 26.2,
                    89: 26.2,
                    90: 26.4,
                    91: 26.5,
                    92: 26.4,
                    93: 26.0,
                    94: 25.4,
                    95: 24.6,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 20.7,
                    1: 20.8,
                    2: 20.9,
                    3: 20.8,
                    4: 20.5,
                    5: 20.0,
                    6: 19.4,
                    7: 18.9,
                    8: 18.6,
                    9: 18.5,
                    10: 18.6,
                    11: 18.9,
                    12: 19.5,
                    13: 20.2,
                    14: 20.7,
                    15: 20.8,
                    16: 20.4,
                    17: 19.6,
                    18: 19.0,
                    19: 18.9,
                    20: 19.6,
                    21: 20.7,
                    22: 21.9,
                    23: 22.7,
                    24: 22.9,
                    25: 22.7,
                    26: 22.5,
                    27: 22.7,
                    28: 23.8,
                    29: 25.9,
                    30: 29.3,
                    31: 34.1,
                    32: 40.3,
                    33: 47.2,
                    34: 53.6,
                    35: 58.7,
                    36: 61.6,
                    37: 62.7,
                    38: 62.8,
                    39: 62.5,
                    40: 62.2,
                    41: 62.2,
                    42: 62.3,
                    43: 62.5,
                    44: 62.6,
                    45: 62.6,
                    46: 62.0,
                    47: 60.6,
                    48: 58.2,
                    49: 55.0,
                    50: 51.3,
                    51: 47.3,
                    52: 43.4,
                    53: 39.8,
                    54: 36.6,
                    55: 34.1,
                    56: 32.4,
                    57: 31.3,
                    58: 30.7,
                    59: 30.3,
                    60: 29.8,
                    61: 29.4,
                    62: 28.9,
                    63: 28.4,
                    64: 27.9,
                    65: 27.5,
                    66: 27.0,
                    67: 26.5,
                    68: 26.0,
                    69: 25.4,
                    70: 24.9,
                    71: 24.6,
                    72: 24.4,
                    73: 24.4,
                    74: 24.5,
                    75: 24.6,
                    76: 24.7,
                    77: 24.8,
                    78: 24.7,
                    79: 24.6,
                    80: 24.3,
                    81: 24.1,
                    82: 24.1,
                    83: 24.6,
                    84: 25.6,
                    85: 26.8,
                    86: 27.9,
                    87: 28.4,
                    88: 28.0,
                    89: 27.0,
                    90: 25.8,
                    91: 24.6,
                    92: 23.8,
                    93: 23.3,
                    94: 23.0,
                    95: 22.7,
                },
                BDEWDAY.Sunday: {
                    0: 22.4,
                    1: 21.9,
                    2: 21.4,
                    3: 20.8,
                    4: 20.2,
                    5: 19.5,
                    6: 19.1,
                    7: 18.9,
                    8: 19.2,
                    9: 19.7,
                    10: 20.3,
                    11: 20.8,
                    12: 21.2,
                    13: 21.3,
                    14: 21.2,
                    15: 20.8,
                    16: 20.3,
                    17: 19.6,
                    18: 19.1,
                    19: 18.9,
                    20: 19.1,
                    21: 19.6,
                    22: 20.3,
                    23: 20.8,
                    24: 21.1,
                    25: 21.2,
                    26: 21.1,
                    27: 20.8,
                    28: 20.4,
                    29: 19.8,
                    30: 19.3,
                    31: 18.9,
                    32: 18.8,
                    33: 18.7,
                    34: 18.8,
                    35: 18.9,
                    36: 19.0,
                    37: 19.0,
                    38: 19.0,
                    39: 18.9,
                    40: 18.8,
                    41: 18.7,
                    42: 18.8,
                    43: 18.9,
                    44: 19.3,
                    45: 19.8,
                    46: 20.4,
                    47: 20.8,
                    48: 21.1,
                    49: 21.2,
                    50: 21.2,
                    51: 20.8,
                    52: 20.3,
                    53: 19.6,
                    54: 19.1,
                    55: 18.9,
                    56: 19.1,
                    57: 19.7,
                    58: 20.3,
                    59: 20.8,
                    60: 21.1,
                    61: 21.2,
                    62: 21.1,
                    63: 20.8,
                    64: 20.4,
                    65: 19.9,
                    66: 19.4,
                    67: 18.9,
                    68: 18.6,
                    69: 18.4,
                    70: 18.5,
                    71: 18.9,
                    72: 19.8,
                    73: 20.9,
                    74: 21.9,
                    75: 22.7,
                    76: 23.0,
                    77: 23.0,
                    78: 22.9,
                    79: 22.7,
                    80: 22.7,
                    81: 22.8,
                    82: 22.8,
                    83: 22.7,
                    84: 22.3,
                    85: 21.8,
                    86: 21.3,
                    87: 20.8,
                    88: 20.6,
                    89: 20.6,
                    90: 20.7,
                    91: 20.8,
                    92: 21.0,
                    93: 21.1,
                    94: 21.0,
                    95: 20.8,
                },
                BDEWDAY.Workday: {
                    0: 20.2,
                    1: 19.7,
                    2: 19.2,
                    3: 18.9,
                    4: 18.8,
                    5: 18.8,
                    6: 18.9,
                    7: 18.9,
                    8: 18.9,
                    9: 18.9,
                    10: 18.9,
                    11: 18.9,
                    12: 19.0,
                    13: 19.1,
                    14: 19.1,
                    15: 18.9,
                    16: 18.5,
                    17: 18.3,
                    18: 18.9,
                    19: 20.8,
                    20: 24.1,
                    21: 27.2,
                    22: 28.1,
                    23: 24.6,
                    24: 27.9,
                    25: 28.6,
                    26: 30.8,
                    27: 32.2,
                    28: 74.1,
                    29: 131.7,
                    30: 195.3,
                    31: 255.5,
                    32: 304.6,
                    33: 341.8,
                    34: 368.0,
                    35: 384.2,
                    36: 391.7,
                    37: 393.1,
                    38: 391.5,
                    39: 389.9,
                    40: 390.6,
                    41: 392.9,
                    42: 395.7,
                    43: 397.5,
                    44: 397.3,
                    45: 395.0,
                    46: 390.6,
                    47: 384.2,
                    48: 375.8,
                    49: 364.5,
                    50: 349.3,
                    51: 329.3,
                    52: 304.7,
                    53: 279.8,
                    54: 260.3,
                    55: 251.7,
                    56: 257.5,
                    57: 272.9,
                    58: 290.9,
                    59: 304.7,
                    60: 309.0,
                    61: 304.7,
                    62: 294.3,
                    63: 280.1,
                    64: 264.3,
                    65: 246.5,
                    66: 226.2,
                    67: 202.5,
                    68: 175.4,
                    69: 146.9,
                    70: 119.7,
                    71: 96.5,
                    72: 79.3,
                    73: 67.2,
                    74: 59.0,
                    75: 53.0,
                    76: 48.1,
                    77: 44.0,
                    78: 40.7,
                    79: 37.9,
                    80: 35.6,
                    81: 33.6,
                    82: 31.9,
                    83: 30.3,
                    84: 28.7,
                    85: 27.1,
                    86: 25.7,
                    87: 24.6,
                    88: 23.8,
                    89: 23.4,
                    90: 23.0,
                    91: 22.7,
                    92: 22.3,
                    93: 21.9,
                    94: 21.4,
                    95: 20.8,
                },
            },
        }
        self.G2: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 80.6,
                    1: 74.6,
                    2: 69.2,
                    3: 63.6,
                    4: 57.1,
                    5: 50.4,
                    6: 44.1,
                    7: 39.1,
                    8: 36.0,
                    9: 34.4,
                    10: 33.7,
                    11: 33.3,
                    12: 32.7,
                    13: 32.0,
                    14: 31.5,
                    15: 31.3,
                    16: 31.5,
                    17: 31.7,
                    18: 31.5,
                    19: 30.3,
                    20: 28.1,
                    21: 26.4,
                    22: 27.1,
                    23: 32.3,
                    24: 42.9,
                    25: 56.2,
                    26: 68.5,
                    27: 76.3,
                    28: 77.0,
                    29: 72.9,
                    30: 67.3,
                    31: 63.6,
                    32: 64.5,
                    33: 69.5,
                    34: 77.4,
                    35: 87.1,
                    36: 97.4,
                    37: 108.4,
                    38: 119.9,
                    39: 132.1,
                    40: 144.7,
                    41: 156.7,
                    42: 166.9,
                    43: 174.1,
                    44: 177.4,
                    45: 177.7,
                    46: 176.2,
                    47: 174.1,
                    48: 172.6,
                    49: 172.0,
                    50: 172.4,
                    51: 174.1,
                    52: 177.1,
                    53: 180.4,
                    54: 183.0,
                    55: 183.9,
                    56: 182.4,
                    57: 179.5,
                    58: 176.6,
                    59: 175.1,
                    60: 176.0,
                    61: 178.9,
                    62: 182.8,
                    63: 186.8,
                    64: 190.3,
                    65: 193.8,
                    66: 197.9,
                    67: 203.5,
                    68: 210.8,
                    69: 218.8,
                    70: 226.3,
                    71: 231.8,
                    72: 234.4,
                    73: 234.5,
                    74: 233.0,
                    75: 230.9,
                    76: 228.7,
                    77: 226.9,
                    78: 225.3,
                    79: 224.0,
                    80: 223.0,
                    81: 221.5,
                    82: 218.9,
                    83: 214.2,
                    84: 207.0,
                    85: 197.0,
                    86: 184.4,
                    87: 169.2,
                    88: 151.8,
                    89: 133.7,
                    90: 116.7,
                    91: 102.7,
                    92: 93.0,
                    93: 86.6,
                    94: 82.2,
                    95: 78.3,
                },
                BDEWDAY.Sunday: {
                    0: 73.7,
                    1: 68.7,
                    2: 63.6,
                    3: 58.7,
                    4: 54.4,
                    5: 50.6,
                    6: 47.2,
                    7: 44.0,
                    8: 41.0,
                    9: 38.2,
                    10: 35.9,
                    11: 34.2,
                    12: 33.3,
                    13: 33.0,
                    14: 33.1,
                    15: 33.3,
                    16: 33.3,
                    17: 33.1,
                    18: 32.5,
                    19: 31.3,
                    20: 29.7,
                    21: 28.5,
                    22: 29.0,
                    23: 32.3,
                    24: 38.9,
                    25: 47.3,
                    26: 54.9,
                    27: 59.7,
                    28: 59.9,
                    29: 56.6,
                    30: 51.7,
                    31: 47.0,
                    32: 44.0,
                    33: 43.7,
                    34: 46.7,
                    35: 53.8,
                    36: 65.2,
                    37: 79.5,
                    38: 94.6,
                    39: 108.6,
                    40: 120.0,
                    41: 128.8,
                    42: 135.6,
                    43: 140.9,
                    44: 144.9,
                    45: 147.8,
                    46: 149.4,
                    47: 149.7,
                    48: 148.5,
                    49: 146.8,
                    50: 145.2,
                    51: 144.8,
                    52: 146.0,
                    53: 148.3,
                    54: 151.1,
                    55: 153.6,
                    56: 155.1,
                    57: 155.5,
                    58: 155.0,
                    59: 153.6,
                    60: 151.4,
                    61: 149.0,
                    62: 147.2,
                    63: 146.7,
                    64: 148.1,
                    65: 151.2,
                    66: 155.7,
                    67: 161.4,
                    68: 167.8,
                    69: 174.5,
                    70: 180.7,
                    71: 185.9,
                    72: 189.5,
                    73: 192.1,
                    74: 193.9,
                    75: 195.6,
                    76: 197.5,
                    77: 199.4,
                    78: 200.9,
                    79: 201.5,
                    80: 201.0,
                    81: 199.2,
                    82: 196.2,
                    83: 191.7,
                    84: 185.8,
                    85: 178.1,
                    86: 168.1,
                    87: 155.5,
                    88: 140.2,
                    89: 123.7,
                    90: 107.7,
                    91: 93.9,
                    92: 83.8,
                    93: 76.7,
                    94: 71.6,
                    95: 67.5,
                },
                BDEWDAY.Workday: {
                    0: 77.4,
                    1: 67.4,
                    2: 58.4,
                    3: 50.9,
                    4: 44.9,
                    5: 40.5,
                    6: 37.4,
                    7: 35.2,
                    8: 33.9,
                    9: 33.1,
                    10: 32.6,
                    11: 32.3,
                    12: 31.9,
                    13: 31.5,
                    14: 31.3,
                    15: 31.3,
                    16: 31.6,
                    17: 31.9,
                    18: 31.6,
                    19: 30.3,
                    20: 28.0,
                    21: 26.3,
                    22: 27.1,
                    23: 32.3,
                    24: 43.0,
                    25: 56.9,
                    26: 70.4,
                    27: 80.2,
                    28: 84.0,
                    29: 83.3,
                    30: 80.8,
                    31: 79.2,
                    32: 80.5,
                    33: 84.6,
                    34: 90.6,
                    35: 97.8,
                    36: 105.6,
                    37: 114.1,
                    38: 123.5,
                    39: 134.0,
                    40: 145.5,
                    41: 156.8,
                    42: 166.2,
                    43: 172.2,
                    44: 173.6,
                    45: 171.6,
                    46: 167.7,
                    47: 163.4,
                    48: 159.9,
                    49: 157.5,
                    50: 155.8,
                    51: 154.6,
                    52: 153.7,
                    53: 153.2,
                    54: 153.1,
                    55: 153.6,
                    56: 154.7,
                    57: 156.8,
                    58: 160.2,
                    59: 165.3,
                    60: 172.2,
                    61: 180.0,
                    62: 187.6,
                    63: 193.7,
                    64: 197.6,
                    65: 200.5,
                    66: 203.9,
                    67: 209.3,
                    68: 217.7,
                    69: 227.8,
                    70: 237.7,
                    71: 245.5,
                    72: 249.8,
                    73: 251.2,
                    74: 250.7,
                    75: 249.4,
                    76: 248.2,
                    77: 247.2,
                    78: 246.3,
                    79: 245.5,
                    80: 244.7,
                    81: 243.3,
                    82: 240.6,
                    83: 235.7,
                    84: 228.3,
                    85: 218.5,
                    86: 206.9,
                    87: 193.7,
                    88: 179.5,
                    89: 164.8,
                    90: 150.1,
                    91: 136.0,
                    92: 122.8,
                    93: 110.6,
                    94: 99.1,
                    95: 88.0,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 63.1,
                    1: 58.0,
                    2: 53.5,
                    3: 48.9,
                    4: 43.6,
                    5: 38.1,
                    6: 33.2,
                    7: 29.3,
                    8: 27.2,
                    9: 26.4,
                    10: 26.3,
                    11: 26.4,
                    12: 26.3,
                    13: 25.8,
                    14: 25.2,
                    15: 24.5,
                    16: 23.8,
                    17: 23.3,
                    18: 23.5,
                    19: 24.5,
                    20: 26.5,
                    21: 29.5,
                    22: 33.5,
                    23: 38.1,
                    24: 43.3,
                    25: 48.1,
                    26: 51.6,
                    27: 52.8,
                    28: 51.2,
                    29: 48.2,
                    30: 45.5,
                    31: 45.0,
                    32: 48.0,
                    33: 54.2,
                    34: 62.6,
                    35: 72.4,
                    36: 82.8,
                    37: 93.1,
                    38: 102.9,
                    39: 111.5,
                    40: 118.6,
                    41: 124.2,
                    42: 128.3,
                    43: 131.1,
                    44: 132.7,
                    45: 133.4,
                    46: 133.4,
                    47: 133.0,
                    48: 132.5,
                    49: 131.8,
                    50: 131.3,
                    51: 131.1,
                    52: 131.1,
                    53: 131.4,
                    54: 131.8,
                    55: 132.1,
                    56: 132.1,
                    57: 132.2,
                    58: 132.4,
                    59: 133.0,
                    60: 134.2,
                    61: 135.9,
                    62: 137.8,
                    63: 139.9,
                    64: 141.9,
                    65: 144.0,
                    66: 146.6,
                    67: 149.7,
                    68: 153.5,
                    69: 157.4,
                    70: 160.9,
                    71: 163.4,
                    72: 164.2,
                    73: 163.7,
                    74: 162.3,
                    75: 160.4,
                    76: 158.4,
                    77: 156.5,
                    78: 154.8,
                    79: 153.6,
                    80: 152.8,
                    81: 152.1,
                    82: 150.9,
                    83: 148.7,
                    84: 144.9,
                    85: 139.3,
                    86: 131.9,
                    87: 122.3,
                    88: 110.7,
                    89: 98.1,
                    90: 85.9,
                    91: 75.3,
                    92: 67.3,
                    93: 61.5,
                    94: 57.3,
                    95: 53.8,
                },
                BDEWDAY.Sunday: {
                    0: 50.6,
                    1: 47.4,
                    2: 44.3,
                    3: 41.1,
                    4: 37.9,
                    5: 34.7,
                    6: 31.8,
                    7: 29.3,
                    8: 27.4,
                    9: 26.0,
                    10: 25.0,
                    11: 24.5,
                    12: 24.2,
                    13: 24.0,
                    14: 23.9,
                    15: 23.5,
                    16: 22.8,
                    17: 22.3,
                    18: 22.3,
                    19: 23.5,
                    20: 26.1,
                    21: 29.8,
                    22: 34.3,
                    23: 39.1,
                    24: 43.7,
                    25: 47.4,
                    26: 49.4,
                    27: 48.9,
                    28: 45.6,
                    29: 40.6,
                    30: 35.6,
                    31: 32.3,
                    32: 31.9,
                    33: 34.4,
                    34: 39.6,
                    35: 47.0,
                    36: 56.2,
                    37: 66.4,
                    38: 76.6,
                    39: 86.1,
                    40: 93.9,
                    41: 100.2,
                    42: 105.0,
                    43: 108.6,
                    44: 111.1,
                    45: 112.7,
                    46: 113.8,
                    47: 114.4,
                    48: 115.0,
                    49: 115.4,
                    50: 115.9,
                    51: 116.4,
                    52: 116.9,
                    53: 117.2,
                    54: 116.8,
                    55: 115.4,
                    56: 112.9,
                    57: 109.8,
                    58: 107.1,
                    59: 105.6,
                    60: 106.0,
                    61: 107.7,
                    62: 110.1,
                    63: 112.5,
                    64: 114.4,
                    65: 116.2,
                    66: 118.3,
                    67: 121.3,
                    68: 125.5,
                    69: 130.3,
                    70: 135.1,
                    71: 138.9,
                    72: 141.3,
                    73: 142.6,
                    74: 143.2,
                    75: 143.8,
                    76: 144.6,
                    77: 145.5,
                    78: 146.0,
                    79: 145.7,
                    80: 144.4,
                    81: 142.0,
                    82: 138.8,
                    83: 135.0,
                    84: 130.6,
                    85: 125.3,
                    86: 118.8,
                    87: 110.5,
                    88: 100.5,
                    89: 89.4,
                    90: 78.4,
                    91: 68.5,
                    92: 60.5,
                    93: 54.4,
                    94: 50.0,
                    95: 47.0,
                },
                BDEWDAY.Workday: {
                    0: 60.8,
                    1: 53.0,
                    2: 46.0,
                    3: 40.1,
                    4: 35.4,
                    5: 31.7,
                    6: 29.1,
                    7: 27.4,
                    8: 26.5,
                    9: 26.2,
                    10: 26.2,
                    11: 26.4,
                    12: 26.5,
                    13: 26.6,
                    14: 26.5,
                    15: 26.4,
                    16: 26.3,
                    17: 26.3,
                    18: 26.6,
                    19: 27.4,
                    20: 28.9,
                    21: 31.2,
                    22: 34.6,
                    23: 39.1,
                    24: 44.8,
                    25: 50.9,
                    26: 56.1,
                    27: 59.7,
                    28: 60.8,
                    29: 60.4,
                    30: 59.9,
                    31: 60.6,
                    32: 63.6,
                    33: 68.8,
                    34: 75.7,
                    35: 84.1,
                    36: 93.5,
                    37: 103.2,
                    38: 112.4,
                    39: 120.3,
                    40: 126.5,
                    41: 131.0,
                    42: 134.4,
                    43: 136.9,
                    44: 139.0,
                    45: 140.3,
                    46: 140.7,
                    47: 139.9,
                    48: 137.8,
                    49: 134.6,
                    50: 131.0,
                    51: 127.2,
                    52: 123.7,
                    53: 120.9,
                    54: 119.0,
                    55: 118.4,
                    56: 119.2,
                    57: 121.2,
                    58: 124.0,
                    59: 127.2,
                    60: 130.4,
                    61: 133.4,
                    62: 136.0,
                    63: 137.9,
                    64: 139.2,
                    65: 140.4,
                    66: 142.3,
                    67: 145.7,
                    68: 151.2,
                    69: 157.9,
                    70: 164.6,
                    71: 170.2,
                    72: 173.9,
                    73: 176.0,
                    74: 177.2,
                    75: 178.0,
                    76: 179.1,
                    77: 180.2,
                    78: 181.2,
                    79: 181.9,
                    80: 182.1,
                    81: 181.6,
                    82: 180.3,
                    83: 178.0,
                    84: 174.6,
                    85: 169.9,
                    86: 163.6,
                    87: 155.5,
                    88: 145.6,
                    89: 134.3,
                    90: 122.4,
                    91: 110.5,
                    92: 99.2,
                    93: 88.7,
                    94: 78.7,
                    95: 69.5,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 73.1,
                    1: 67.6,
                    2: 62.8,
                    3: 57.7,
                    4: 51.6,
                    5: 45.0,
                    6: 38.9,
                    7: 34.2,
                    8: 31.6,
                    9: 30.6,
                    10: 30.4,
                    11: 30.3,
                    12: 29.8,
                    13: 29.0,
                    14: 28.1,
                    15: 27.4,
                    16: 27.0,
                    17: 26.7,
                    18: 26.3,
                    19: 25.4,
                    20: 24.1,
                    21: 23.4,
                    22: 24.7,
                    23: 29.3,
                    24: 38.0,
                    25: 48.5,
                    26: 58.3,
                    27: 64.6,
                    28: 65.4,
                    29: 62.5,
                    30: 58.1,
                    31: 54.8,
                    32: 54.5,
                    33: 57.3,
                    34: 63.1,
                    35: 71.4,
                    36: 81.9,
                    37: 93.7,
                    38: 105.9,
                    39: 117.4,
                    40: 127.4,
                    41: 135.7,
                    42: 142.2,
                    43: 146.7,
                    44: 149.3,
                    45: 150.3,
                    46: 150.2,
                    47: 149.7,
                    48: 149.0,
                    49: 148.7,
                    50: 148.8,
                    51: 149.7,
                    52: 151.4,
                    53: 153.6,
                    54: 155.5,
                    55: 156.5,
                    56: 156.3,
                    57: 155.1,
                    58: 153.7,
                    59: 152.6,
                    60: 152.3,
                    61: 152.9,
                    62: 154.4,
                    63: 156.5,
                    64: 159.3,
                    65: 162.9,
                    66: 167.1,
                    67: 172.2,
                    68: 177.8,
                    69: 183.6,
                    70: 188.8,
                    71: 192.7,
                    72: 194.9,
                    73: 195.6,
                    74: 195.4,
                    75: 194.7,
                    76: 193.9,
                    77: 193.2,
                    78: 192.5,
                    79: 191.7,
                    80: 190.9,
                    81: 189.7,
                    82: 187.8,
                    83: 184.9,
                    84: 180.5,
                    85: 174.2,
                    86: 165.4,
                    87: 153.6,
                    88: 138.6,
                    89: 122.0,
                    90: 105.8,
                    91: 91.9,
                    92: 82.0,
                    93: 75.4,
                    94: 70.9,
                    95: 67.5,
                },
                BDEWDAY.Sunday: {
                    0: 64.2,
                    1: 60.7,
                    2: 56.9,
                    3: 52.8,
                    4: 48.3,
                    5: 43.8,
                    6: 39.6,
                    7: 36.2,
                    8: 33.8,
                    9: 32.2,
                    10: 31.1,
                    11: 30.3,
                    12: 29.5,
                    13: 28.7,
                    14: 27.9,
                    15: 27.4,
                    16: 27.1,
                    17: 26.8,
                    18: 26.4,
                    19: 25.4,
                    20: 24.1,
                    21: 23.2,
                    22: 24.3,
                    23: 28.4,
                    24: 36.2,
                    25: 45.7,
                    26: 54.1,
                    27: 58.7,
                    28: 57.7,
                    29: 52.5,
                    30: 45.5,
                    31: 39.1,
                    32: 35.3,
                    33: 34.7,
                    34: 37.5,
                    35: 44.0,
                    36: 54.2,
                    37: 66.8,
                    38: 80.5,
                    39: 93.9,
                    40: 105.7,
                    41: 115.5,
                    42: 123.0,
                    43: 128.1,
                    44: 130.8,
                    45: 131.5,
                    46: 131.4,
                    47: 131.1,
                    48: 131.3,
                    49: 131.6,
                    50: 131.4,
                    51: 130.1,
                    52: 127.3,
                    53: 123.6,
                    54: 120.0,
                    55: 117.4,
                    56: 116.5,
                    57: 116.8,
                    58: 117.6,
                    59: 118.4,
                    60: 118.4,
                    61: 118.0,
                    62: 117.6,
                    63: 117.4,
                    64: 117.9,
                    65: 119.3,
                    66: 122.0,
                    67: 126.2,
                    68: 132.0,
                    69: 138.7,
                    70: 145.2,
                    71: 150.6,
                    72: 154.2,
                    73: 156.4,
                    74: 157.9,
                    75: 159.4,
                    76: 161.5,
                    77: 163.8,
                    78: 165.9,
                    79: 167.3,
                    80: 167.6,
                    81: 166.9,
                    82: 165.1,
                    83: 162.4,
                    84: 158.7,
                    85: 153.5,
                    86: 146.1,
                    87: 136.0,
                    88: 122.8,
                    89: 108.1,
                    90: 93.6,
                    91: 81.2,
                    92: 72.3,
                    93: 66.4,
                    94: 62.5,
                    95: 59.7,
                },
                BDEWDAY.Workday: {
                    0: 70.5,
                    1: 61.9,
                    2: 54.4,
                    3: 47.9,
                    4: 42.5,
                    5: 38.1,
                    6: 34.7,
                    7: 32.3,
                    8: 30.8,
                    9: 29.9,
                    10: 29.5,
                    11: 29.3,
                    12: 29.2,
                    13: 29.1,
                    14: 29.1,
                    15: 29.3,
                    16: 29.9,
                    17: 30.3,
                    18: 30.3,
                    19: 29.3,
                    20: 27.5,
                    21: 26.1,
                    22: 26.8,
                    23: 31.3,
                    24: 40.6,
                    25: 52.3,
                    26: 63.3,
                    27: 70.4,
                    28: 71.5,
                    29: 68.5,
                    30: 64.2,
                    31: 61.6,
                    32: 62.9,
                    33: 67.7,
                    34: 75.1,
                    35: 84.1,
                    36: 93.8,
                    37: 103.7,
                    38: 113.3,
                    39: 122.3,
                    40: 130.2,
                    41: 137.0,
                    42: 142.5,
                    43: 146.7,
                    44: 149.6,
                    45: 151.2,
                    46: 151.5,
                    47: 150.6,
                    48: 148.8,
                    49: 146.4,
                    50: 143.9,
                    51: 141.8,
                    52: 140.6,
                    53: 140.1,
                    54: 140.0,
                    55: 139.9,
                    56: 139.7,
                    57: 139.9,
                    58: 141.1,
                    59: 143.8,
                    60: 148.4,
                    61: 153.9,
                    62: 159.3,
                    63: 163.4,
                    64: 165.3,
                    65: 166.2,
                    66: 167.4,
                    67: 170.2,
                    68: 175.7,
                    69: 183.0,
                    70: 190.7,
                    71: 197.6,
                    72: 202.6,
                    73: 206.0,
                    74: 208.0,
                    75: 209.3,
                    76: 210.2,
                    77: 210.9,
                    78: 211.6,
                    79: 212.3,
                    80: 213.1,
                    81: 213.5,
                    82: 213.1,
                    83: 211.3,
                    84: 207.6,
                    85: 201.8,
                    86: 194.0,
                    87: 183.9,
                    88: 171.7,
                    89: 157.9,
                    90: 143.5,
                    91: 129.1,
                    92: 115.5,
                    93: 102.7,
                    94: 91.0,
                    95: 80.2,
                },
            },
        }
        self.G3: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 95.3,
                    1: 95.5,
                    2: 96.2,
                    3: 97.4,
                    4: 98.9,
                    5: 100.3,
                    6: 101.0,
                    7: 100.4,
                    8: 98.2,
                    9: 95.1,
                    10: 91.9,
                    11: 89.5,
                    12: 88.6,
                    13: 88.6,
                    14: 88.7,
                    15: 88.3,
                    16: 86.8,
                    17: 85.1,
                    18: 84.2,
                    19: 85.3,
                    20: 89.0,
                    21: 94.1,
                    22: 99.3,
                    23: 102.8,
                    24: 103.7,
                    25: 102.6,
                    26: 100.7,
                    27: 99.2,
                    28: 99.1,
                    29: 100.8,
                    30: 104.4,
                    31: 110.1,
                    32: 117.7,
                    33: 126.1,
                    34: 133.9,
                    35: 139.7,
                    36: 142.4,
                    37: 142.9,
                    38: 142.4,
                    39: 142.1,
                    40: 142.9,
                    41: 144.5,
                    42: 146.3,
                    43: 147.6,
                    44: 147.9,
                    45: 147.5,
                    46: 146.8,
                    47: 146.4,
                    48: 146.3,
                    49: 146.5,
                    50: 146.2,
                    51: 145.1,
                    52: 142.8,
                    53: 139.3,
                    54: 134.6,
                    55: 128.8,
                    56: 122.3,
                    57: 115.5,
                    58: 109.4,
                    59: 104.6,
                    60: 101.8,
                    61: 100.5,
                    62: 100.2,
                    63: 100.4,
                    64: 100.6,
                    65: 101.0,
                    66: 101.9,
                    67: 103.4,
                    68: 105.8,
                    69: 108.7,
                    70: 111.5,
                    71: 113.7,
                    72: 115.0,
                    73: 115.7,
                    74: 116.3,
                    75: 117.3,
                    76: 119.0,
                    77: 120.6,
                    78: 121.4,
                    79: 120.4,
                    80: 117.0,
                    81: 112.1,
                    82: 106.8,
                    83: 102.2,
                    84: 99.2,
                    85: 97.4,
                    86: 96.4,
                    87: 95.6,
                    88: 94.5,
                    89: 93.3,
                    90: 92.0,
                    91: 90.7,
                    92: 89.6,
                    93: 88.6,
                    94: 88.0,
                    95: 87.7,
                },
                BDEWDAY.Sunday: {
                    0: 87.8,
                    1: 88.3,
                    2: 89.0,
                    3: 90.1,
                    4: 91.3,
                    5: 92.4,
                    6: 92.9,
                    7: 92.5,
                    8: 91.0,
                    9: 88.7,
                    10: 86.4,
                    11: 84.7,
                    12: 84.0,
                    13: 84.0,
                    14: 84.0,
                    15: 83.5,
                    16: 82.1,
                    17: 80.6,
                    18: 80.1,
                    19: 81.6,
                    20: 85.9,
                    21: 91.6,
                    22: 97.0,
                    23: 100.4,
                    24: 100.7,
                    25: 98.8,
                    26: 96.2,
                    27: 94.3,
                    28: 94.4,
                    29: 95.7,
                    30: 97.6,
                    31: 99.2,
                    32: 99.7,
                    33: 99.6,
                    34: 99.2,
                    35: 99.2,
                    36: 99.8,
                    37: 100.9,
                    38: 102.1,
                    39: 102.8,
                    40: 102.9,
                    41: 102.5,
                    42: 101.8,
                    43: 101.0,
                    44: 100.4,
                    45: 100.0,
                    46: 99.8,
                    47: 99.8,
                    48: 100.0,
                    49: 100.5,
                    50: 101.0,
                    51: 101.6,
                    52: 102.2,
                    53: 102.4,
                    54: 102.1,
                    55: 101.0,
                    56: 98.9,
                    57: 96.3,
                    58: 93.8,
                    59: 91.9,
                    60: 91.1,
                    61: 91.2,
                    62: 91.8,
                    63: 92.5,
                    64: 93.1,
                    65: 93.4,
                    66: 93.6,
                    67: 93.7,
                    68: 93.9,
                    69: 94.3,
                    70: 95.2,
                    71: 96.8,
                    72: 99.1,
                    73: 102.2,
                    74: 105.7,
                    75: 109.5,
                    76: 113.2,
                    77: 116.3,
                    78: 117.9,
                    79: 117.3,
                    80: 114.2,
                    81: 109.4,
                    82: 104.2,
                    83: 99.8,
                    84: 97.1,
                    85: 95.9,
                    86: 95.4,
                    87: 95.0,
                    88: 94.1,
                    89: 92.8,
                    90: 91.2,
                    91: 89.5,
                    92: 87.8,
                    93: 86.4,
                    94: 85.7,
                    95: 85.9,
                },
                BDEWDAY.Workday: {
                    0: 94.7,
                    1: 94.1,
                    2: 94.1,
                    3: 95.0,
                    4: 96.6,
                    5: 98.4,
                    6: 99.8,
                    7: 99.8,
                    8: 98.0,
                    9: 95.1,
                    10: 91.9,
                    11: 89.5,
                    12: 88.4,
                    13: 88.3,
                    14: 88.3,
                    15: 87.7,
                    16: 86.1,
                    17: 84.3,
                    18: 83.5,
                    19: 84.7,
                    20: 88.5,
                    21: 94.0,
                    22: 99.5,
                    23: 103.4,
                    24: 104.7,
                    25: 104.0,
                    26: 102.4,
                    27: 101.0,
                    28: 100.8,
                    29: 102.1,
                    30: 105.3,
                    31: 110.7,
                    32: 118.2,
                    33: 126.7,
                    34: 134.7,
                    35: 140.9,
                    36: 144.2,
                    37: 145.4,
                    38: 145.5,
                    39: 145.8,
                    40: 147.0,
                    41: 149.0,
                    42: 151.2,
                    43: 153.0,
                    44: 154.0,
                    45: 154.3,
                    46: 154.3,
                    47: 154.2,
                    48: 154.3,
                    49: 154.5,
                    50: 154.3,
                    51: 153.6,
                    52: 152.2,
                    53: 149.9,
                    54: 147.0,
                    55: 143.3,
                    56: 139.2,
                    57: 135.2,
                    58: 132.1,
                    59: 130.6,
                    60: 131.3,
                    61: 133.5,
                    62: 136.2,
                    63: 138.5,
                    64: 139.8,
                    65: 140.3,
                    66: 140.5,
                    67: 140.9,
                    68: 142.0,
                    69: 143.7,
                    70: 145.8,
                    71: 148.2,
                    72: 150.6,
                    73: 152.5,
                    74: 153.3,
                    75: 152.4,
                    76: 149.3,
                    77: 144.4,
                    78: 138.4,
                    79: 131.8,
                    80: 125.3,
                    81: 119.3,
                    82: 114.3,
                    83: 110.7,
                    84: 108.8,
                    85: 108.1,
                    86: 108.0,
                    87: 107.7,
                    88: 106.6,
                    89: 104.9,
                    90: 103.0,
                    91: 101.0,
                    92: 99.3,
                    93: 97.8,
                    94: 96.6,
                    95: 95.6,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 99.0,
                    1: 100.0,
                    2: 100.9,
                    3: 101.0,
                    4: 99.8,
                    5: 97.9,
                    6: 95.8,
                    7: 94.3,
                    8: 94.0,
                    9: 94.3,
                    10: 94.8,
                    11: 95.0,
                    12: 94.3,
                    13: 93.1,
                    14: 91.7,
                    15: 90.7,
                    16: 90.3,
                    17: 90.2,
                    18: 90.1,
                    19: 89.5,
                    20: 88.2,
                    21: 87.0,
                    22: 86.7,
                    23: 88.3,
                    24: 92.2,
                    25: 97.3,
                    26: 102.2,
                    27: 105.2,
                    28: 105.5,
                    29: 104.6,
                    30: 104.6,
                    31: 107.7,
                    32: 115.0,
                    33: 125.0,
                    34: 134.9,
                    35: 142.1,
                    36: 144.9,
                    37: 144.1,
                    38: 141.8,
                    39: 139.7,
                    40: 139.2,
                    41: 140.0,
                    42: 141.4,
                    43: 142.7,
                    44: 143.4,
                    45: 143.7,
                    46: 143.7,
                    47: 143.9,
                    48: 144.5,
                    49: 145.0,
                    50: 145.0,
                    51: 143.9,
                    52: 141.5,
                    53: 137.8,
                    54: 133.3,
                    55: 128.2,
                    56: 123.0,
                    57: 118.2,
                    58: 114.1,
                    59: 111.3,
                    60: 110.0,
                    61: 110.0,
                    62: 110.6,
                    63: 111.3,
                    64: 111.7,
                    65: 111.9,
                    66: 112.1,
                    67: 112.5,
                    68: 113.2,
                    69: 113.9,
                    70: 114.2,
                    71: 113.7,
                    72: 112.1,
                    73: 110.2,
                    74: 109.0,
                    75: 109.5,
                    76: 112.2,
                    77: 116.2,
                    78: 120.2,
                    79: 122.8,
                    80: 123.0,
                    81: 121.2,
                    82: 118.3,
                    83: 114.9,
                    84: 111.7,
                    85: 108.9,
                    86: 106.5,
                    87: 104.6,
                    88: 103.2,
                    89: 102.1,
                    90: 101.1,
                    91: 99.8,
                    92: 98.2,
                    93: 96.4,
                    94: 95.0,
                    95: 94.3,
                },
                BDEWDAY.Sunday: {
                    0: 94.6,
                    1: 95.3,
                    2: 96.0,
                    3: 96.2,
                    4: 95.3,
                    5: 93.9,
                    6: 92.4,
                    7: 91.3,
                    8: 91.1,
                    9: 91.5,
                    10: 92.1,
                    11: 92.5,
                    12: 92.4,
                    13: 91.9,
                    14: 91.2,
                    15: 90.7,
                    16: 90.5,
                    17: 90.4,
                    18: 90.1,
                    19: 89.5,
                    20: 88.5,
                    21: 87.7,
                    22: 88.2,
                    23: 90.7,
                    24: 95.8,
                    25: 102.0,
                    26: 107.6,
                    27: 110.7,
                    28: 110.0,
                    29: 106.9,
                    30: 103.1,
                    31: 100.4,
                    32: 100.2,
                    33: 101.8,
                    34: 104.0,
                    35: 105.8,
                    36: 106.3,
                    37: 105.8,
                    38: 104.8,
                    39: 104.0,
                    40: 103.8,
                    41: 104.1,
                    42: 104.5,
                    43: 104.6,
                    44: 104.4,
                    45: 104.0,
                    46: 103.9,
                    47: 104.6,
                    48: 106.3,
                    49: 108.3,
                    50: 110.1,
                    51: 110.7,
                    52: 109.7,
                    53: 107.5,
                    54: 105.0,
                    55: 102.8,
                    56: 101.5,
                    57: 101.0,
                    58: 100.9,
                    59: 101.0,
                    60: 100.9,
                    61: 100.8,
                    62: 100.6,
                    63: 100.4,
                    64: 100.3,
                    65: 100.2,
                    66: 100.3,
                    67: 100.4,
                    68: 100.5,
                    69: 100.7,
                    70: 100.6,
                    71: 100.4,
                    72: 99.9,
                    73: 99.7,
                    74: 100.2,
                    75: 102.2,
                    76: 105.9,
                    77: 110.3,
                    78: 114.5,
                    79: 117.3,
                    80: 117.9,
                    81: 116.5,
                    82: 113.9,
                    83: 110.7,
                    84: 107.4,
                    85: 104.4,
                    86: 101.8,
                    87: 99.8,
                    88: 98.5,
                    89: 97.6,
                    90: 96.8,
                    91: 95.6,
                    92: 93.8,
                    93: 91.9,
                    94: 90.7,
                    95: 90.7,
                },
                BDEWDAY.Workday: {
                    0: 98.5,
                    1: 99.0,
                    2: 99.4,
                    3: 99.2,
                    4: 98.1,
                    5: 96.4,
                    6: 94.8,
                    7: 93.7,
                    8: 93.6,
                    9: 94.1,
                    10: 94.7,
                    11: 95.0,
                    12: 94.4,
                    13: 93.3,
                    14: 92.2,
                    15: 91.3,
                    16: 91.0,
                    17: 91.1,
                    18: 91.1,
                    19: 90.7,
                    20: 89.8,
                    21: 89.0,
                    22: 89.2,
                    23: 91.3,
                    24: 95.9,
                    25: 101.6,
                    26: 106.9,
                    27: 110.1,
                    28: 110.1,
                    29: 108.4,
                    30: 107.1,
                    31: 108.3,
                    32: 113.3,
                    33: 120.8,
                    34: 128.9,
                    35: 135.5,
                    36: 139.1,
                    37: 140.3,
                    38: 140.3,
                    39: 140.3,
                    40: 141.1,
                    41: 142.5,
                    42: 144.0,
                    43: 145.1,
                    44: 145.7,
                    45: 145.8,
                    46: 145.9,
                    47: 146.4,
                    48: 147.4,
                    49: 148.6,
                    50: 149.1,
                    51: 148.2,
                    52: 145.4,
                    53: 141.4,
                    54: 137.2,
                    55: 133.7,
                    56: 131.5,
                    57: 130.7,
                    58: 130.9,
                    59: 131.8,
                    60: 133.3,
                    61: 135.0,
                    62: 136.6,
                    63: 137.9,
                    64: 138.6,
                    65: 139.0,
                    66: 139.2,
                    67: 139.7,
                    68: 140.6,
                    69: 141.6,
                    70: 142.4,
                    71: 142.7,
                    72: 142.3,
                    73: 141.3,
                    74: 139.9,
                    75: 138.5,
                    76: 137.2,
                    77: 135.9,
                    78: 134.3,
                    79: 132.4,
                    80: 130.0,
                    81: 127.2,
                    82: 124.1,
                    83: 121.0,
                    84: 117.8,
                    85: 114.9,
                    86: 112.2,
                    87: 110.1,
                    88: 108.5,
                    89: 107.2,
                    90: 106.0,
                    91: 104.6,
                    92: 102.9,
                    93: 101.1,
                    94: 99.5,
                    95: 98.6,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 92.5,
                    1: 93.0,
                    2: 93.7,
                    3: 94.3,
                    4: 94.5,
                    5: 94.5,
                    6: 94.3,
                    7: 94.3,
                    8: 94.7,
                    9: 95.0,
                    10: 95.0,
                    11: 94.3,
                    12: 92.7,
                    13: 90.6,
                    14: 88.3,
                    15: 86.5,
                    16: 85.4,
                    17: 85.1,
                    18: 85.1,
                    19: 85.3,
                    20: 85.4,
                    21: 85.8,
                    22: 86.9,
                    23: 88.9,
                    24: 92.1,
                    25: 95.7,
                    26: 99.0,
                    27: 101.0,
                    28: 101.3,
                    29: 101.1,
                    30: 102.3,
                    31: 106.4,
                    32: 114.6,
                    33: 124.9,
                    34: 134.7,
                    35: 141.5,
                    36: 143.4,
                    37: 141.8,
                    38: 138.6,
                    39: 136.1,
                    40: 135.7,
                    41: 137.1,
                    42: 139.3,
                    43: 141.5,
                    44: 143.0,
                    45: 143.6,
                    46: 143.7,
                    47: 143.3,
                    48: 142.7,
                    49: 141.8,
                    50: 140.8,
                    51: 139.7,
                    52: 138.4,
                    53: 136.8,
                    54: 134.5,
                    55: 131.2,
                    56: 126.9,
                    57: 121.9,
                    58: 117.1,
                    59: 113.1,
                    60: 110.4,
                    61: 108.6,
                    62: 107.5,
                    63: 106.4,
                    64: 105.2,
                    65: 104.1,
                    66: 103.5,
                    67: 104.0,
                    68: 105.8,
                    69: 108.1,
                    70: 110.2,
                    71: 111.3,
                    72: 110.7,
                    73: 109.0,
                    74: 107.1,
                    75: 105.8,
                    76: 105.9,
                    77: 107.0,
                    78: 108.7,
                    79: 110.7,
                    80: 112.4,
                    81: 113.5,
                    82: 113.9,
                    83: 113.1,
                    84: 111.1,
                    85: 108.3,
                    86: 105.1,
                    87: 102.2,
                    88: 99.9,
                    89: 98.1,
                    90: 96.5,
                    91: 95.0,
                    92: 93.1,
                    93: 91.3,
                    94: 89.6,
                    95: 88.3,
                },
                BDEWDAY.Sunday: {
                    0: 87.6,
                    1: 87.3,
                    2: 87.4,
                    3: 87.7,
                    4: 88.0,
                    5: 88.4,
                    6: 88.9,
                    7: 89.5,
                    8: 90.3,
                    9: 91.0,
                    10: 91.2,
                    11: 90.7,
                    12: 89.2,
                    13: 87.2,
                    14: 85.1,
                    15: 83.5,
                    16: 82.7,
                    17: 82.7,
                    18: 83.1,
                    19: 83.5,
                    20: 83.7,
                    21: 84.0,
                    22: 84.8,
                    23: 86.5,
                    24: 89.2,
                    25: 92.4,
                    26: 95.4,
                    27: 97.4,
                    28: 97.9,
                    29: 97.6,
                    30: 97.3,
                    31: 98.0,
                    32: 100.1,
                    33: 102.9,
                    34: 105.4,
                    35: 106.4,
                    36: 105.4,
                    37: 102.9,
                    38: 99.9,
                    39: 97.4,
                    40: 96.1,
                    41: 95.9,
                    42: 96.3,
                    43: 96.8,
                    44: 96.9,
                    45: 96.8,
                    46: 96.6,
                    47: 96.2,
                    48: 95.7,
                    49: 95.4,
                    50: 95.1,
                    51: 95.0,
                    52: 95.0,
                    53: 95.3,
                    54: 95.6,
                    55: 96.2,
                    56: 96.7,
                    57: 97.3,
                    58: 97.5,
                    59: 97.4,
                    60: 96.7,
                    61: 95.8,
                    62: 94.9,
                    63: 94.3,
                    64: 94.4,
                    65: 95.0,
                    66: 95.9,
                    67: 96.8,
                    68: 97.6,
                    69: 98.2,
                    70: 98.8,
                    71: 99.2,
                    72: 99.5,
                    73: 99.9,
                    74: 100.5,
                    75: 101.6,
                    76: 103.2,
                    77: 105.2,
                    78: 107.4,
                    79: 109.5,
                    80: 111.2,
                    81: 112.4,
                    82: 112.5,
                    83: 111.3,
                    84: 108.5,
                    85: 104.8,
                    86: 100.8,
                    87: 97.4,
                    88: 95.0,
                    89: 93.5,
                    90: 92.4,
                    91: 91.3,
                    92: 89.9,
                    93: 88.4,
                    94: 87.2,
                    95: 86.5,
                },
                BDEWDAY.Workday: {
                    0: 91.2,
                    1: 90.2,
                    2: 89.4,
                    3: 88.9,
                    4: 88.7,
                    5: 88.8,
                    6: 89.1,
                    7: 89.5,
                    8: 90.0,
                    9: 90.3,
                    10: 90.2,
                    11: 89.5,
                    12: 88.0,
                    13: 86.1,
                    14: 84.0,
                    15: 82.3,
                    16: 81.1,
                    17: 80.5,
                    18: 80.4,
                    19: 80.4,
                    20: 80.7,
                    21: 81.3,
                    22: 82.5,
                    23: 84.7,
                    24: 87.9,
                    25: 91.6,
                    26: 95.2,
                    27: 98.0,
                    28: 99.6,
                    29: 100.9,
                    30: 102.8,
                    31: 106.4,
                    32: 112.4,
                    33: 119.5,
                    34: 126.3,
                    35: 131.2,
                    36: 133.3,
                    37: 133.2,
                    38: 132.1,
                    39: 131.2,
                    40: 131.5,
                    41: 132.8,
                    42: 134.7,
                    43: 136.7,
                    44: 138.4,
                    45: 139.7,
                    46: 140.6,
                    47: 140.9,
                    48: 140.7,
                    49: 140.0,
                    50: 139.0,
                    51: 137.9,
                    52: 136.8,
                    53: 135.9,
                    54: 135.0,
                    55: 134.3,
                    56: 133.7,
                    57: 133.3,
                    58: 133.1,
                    59: 133.1,
                    60: 133.2,
                    61: 133.4,
                    62: 133.6,
                    63: 133.7,
                    64: 133.4,
                    65: 133.1,
                    66: 132.9,
                    67: 133.1,
                    68: 133.6,
                    69: 134.5,
                    70: 135.6,
                    71: 136.7,
                    72: 137.6,
                    73: 138.0,
                    74: 137.6,
                    75: 136.1,
                    76: 133.2,
                    77: 129.6,
                    78: 126.1,
                    79: 123.4,
                    80: 122.1,
                    81: 121.6,
                    82: 121.1,
                    83: 119.7,
                    84: 117.0,
                    85: 113.3,
                    86: 109.4,
                    87: 105.8,
                    88: 103.2,
                    89: 101.3,
                    90: 99.9,
                    91: 98.6,
                    92: 97.1,
                    93: 95.6,
                    94: 94.0,
                    95: 92.5,
                },
            },
        }
        self.G4: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 62.2,
                    1: 61.2,
                    2: 60.1,
                    3: 59.4,
                    4: 59.1,
                    5: 59.2,
                    6: 59.4,
                    7: 59.4,
                    8: 59.1,
                    9: 58.6,
                    10: 58.0,
                    11: 57.6,
                    12: 57.5,
                    13: 57.5,
                    14: 57.6,
                    15: 57.6,
                    16: 57.4,
                    17: 57.2,
                    18: 57.1,
                    19: 57.6,
                    20: 58.7,
                    21: 60.2,
                    22: 62.0,
                    23: 63.9,
                    24: 65.9,
                    25: 69.3,
                    26: 75.6,
                    27: 86.4,
                    28: 102.5,
                    29: 121.9,
                    30: 142.0,
                    31: 160.2,
                    32: 174.4,
                    33: 185.0,
                    34: 193.2,
                    35: 199.8,
                    36: 205.7,
                    37: 210.9,
                    38: 215.3,
                    39: 218.7,
                    40: 220.8,
                    41: 222.0,
                    42: 222.4,
                    43: 222.3,
                    44: 221.9,
                    45: 221.4,
                    46: 220.9,
                    47: 220.5,
                    48: 220.1,
                    49: 219.4,
                    50: 217.6,
                    51: 214.2,
                    52: 208.4,
                    53: 200.2,
                    54: 189.3,
                    55: 175.5,
                    56: 158.9,
                    57: 141.2,
                    58: 124.2,
                    59: 109.8,
                    60: 99.4,
                    61: 92.5,
                    62: 88.2,
                    63: 85.5,
                    64: 83.6,
                    65: 82.5,
                    66: 82.4,
                    67: 83.7,
                    68: 86.2,
                    69: 89.3,
                    70: 92.1,
                    71: 93.6,
                    72: 93.2,
                    73: 91.8,
                    74: 90.4,
                    75: 90.0,
                    76: 91.4,
                    77: 93.7,
                    78: 95.8,
                    79: 96.3,
                    80: 94.4,
                    81: 90.8,
                    82: 86.3,
                    83: 81.9,
                    84: 78.3,
                    85: 75.5,
                    86: 72.9,
                    87: 70.2,
                    88: 67.1,
                    89: 64.0,
                    90: 61.3,
                    91: 59.4,
                    92: 58.6,
                    93: 58.5,
                    94: 58.7,
                    95: 58.5,
                },
                BDEWDAY.Sunday: {
                    0: 57.7,
                    1: 56.4,
                    2: 55.0,
                    3: 54.0,
                    4: 53.6,
                    5: 53.6,
                    6: 53.8,
                    7: 54.0,
                    8: 54.0,
                    9: 53.7,
                    10: 53.4,
                    11: 53.1,
                    12: 52.9,
                    13: 52.7,
                    14: 52.5,
                    15: 52.2,
                    16: 51.8,
                    17: 51.6,
                    18: 51.6,
                    19: 52.2,
                    20: 53.4,
                    21: 55.2,
                    22: 57.2,
                    23: 59.4,
                    24: 61.5,
                    25: 63.3,
                    26: 64.8,
                    27: 65.7,
                    28: 66.0,
                    29: 65.7,
                    30: 65.0,
                    31: 63.9,
                    32: 62.5,
                    33: 61.1,
                    34: 59.7,
                    35: 58.5,
                    36: 57.7,
                    37: 57.3,
                    38: 57.3,
                    39: 57.6,
                    40: 58.2,
                    41: 59.2,
                    42: 60.5,
                    43: 62.1,
                    44: 63.9,
                    45: 65.7,
                    46: 67.0,
                    47: 67.5,
                    48: 66.9,
                    49: 65.4,
                    50: 63.7,
                    51: 62.1,
                    52: 61.0,
                    53: 60.3,
                    54: 60.1,
                    55: 60.3,
                    56: 60.7,
                    57: 61.4,
                    58: 62.1,
                    59: 63.0,
                    60: 63.8,
                    61: 64.6,
                    62: 65.2,
                    63: 65.7,
                    64: 66.0,
                    65: 66.5,
                    66: 67.7,
                    67: 70.2,
                    68: 74.1,
                    69: 78.8,
                    70: 83.2,
                    71: 86.4,
                    72: 87.6,
                    73: 87.5,
                    74: 87.1,
                    75: 87.3,
                    76: 88.8,
                    77: 90.9,
                    78: 92.6,
                    79: 92.7,
                    80: 90.6,
                    81: 86.8,
                    82: 82.4,
                    83: 78.3,
                    84: 75.1,
                    85: 72.7,
                    86: 70.6,
                    87: 68.4,
                    88: 65.8,
                    89: 63.0,
                    90: 60.4,
                    91: 58.5,
                    92: 57.4,
                    93: 57.1,
                    94: 57.2,
                    95: 57.6,
                },
                BDEWDAY.Workday: {
                    0: 62.1,
                    1: 60.8,
                    2: 59.5,
                    3: 58.5,
                    4: 58.0,
                    5: 57.8,
                    6: 57.7,
                    7: 57.6,
                    8: 57.2,
                    9: 56.6,
                    10: 56.1,
                    11: 55.8,
                    12: 55.9,
                    13: 56.2,
                    14: 56.6,
                    15: 56.7,
                    16: 56.5,
                    17: 56.2,
                    18: 56.2,
                    19: 56.7,
                    20: 58.0,
                    21: 59.8,
                    22: 61.9,
                    23: 63.9,
                    24: 65.6,
                    25: 67.8,
                    26: 71.4,
                    27: 77.4,
                    28: 86.4,
                    29: 98.4,
                    30: 113.2,
                    31: 130.5,
                    32: 149.7,
                    33: 169.1,
                    34: 186.8,
                    35: 200.7,
                    36: 209.3,
                    37: 213.7,
                    38: 215.4,
                    39: 216.0,
                    40: 216.6,
                    41: 217.4,
                    42: 218.2,
                    43: 218.7,
                    44: 218.7,
                    45: 218.2,
                    46: 217.0,
                    47: 215.1,
                    48: 212.1,
                    49: 207.8,
                    50: 201.4,
                    51: 192.6,
                    52: 181.1,
                    53: 168.7,
                    54: 157.7,
                    55: 150.3,
                    56: 148.1,
                    57: 151.0,
                    58: 157.9,
                    59: 168.3,
                    60: 180.9,
                    61: 194.1,
                    62: 205.9,
                    63: 214.2,
                    64: 217.7,
                    65: 218.2,
                    66: 217.7,
                    67: 218.7,
                    68: 222.5,
                    69: 227.3,
                    70: 230.5,
                    71: 229.5,
                    72: 222.2,
                    73: 209.9,
                    74: 194.6,
                    75: 178.2,
                    76: 162.3,
                    77: 147.6,
                    78: 134.5,
                    79: 123.3,
                    80: 114.2,
                    81: 107.0,
                    82: 101.2,
                    83: 96.3,
                    84: 92.0,
                    85: 88.0,
                    86: 84.1,
                    87: 80.1,
                    88: 75.9,
                    89: 71.8,
                    90: 68.3,
                    91: 65.7,
                    92: 64.3,
                    93: 63.7,
                    94: 63.4,
                    95: 63.0,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 75.3,
                    1: 75.5,
                    2: 75.7,
                    3: 75.6,
                    4: 74.8,
                    5: 73.6,
                    6: 72.3,
                    7: 71.1,
                    8: 70.3,
                    9: 69.8,
                    10: 69.5,
                    11: 69.3,
                    12: 69.0,
                    13: 68.8,
                    14: 68.6,
                    15: 68.4,
                    16: 68.3,
                    17: 68.3,
                    18: 68.3,
                    19: 68.4,
                    20: 68.4,
                    21: 68.3,
                    22: 68.1,
                    23: 67.5,
                    24: 66.9,
                    25: 67.7,
                    26: 71.8,
                    27: 81.0,
                    28: 96.3,
                    29: 115.4,
                    30: 135.3,
                    31: 153.0,
                    32: 165.9,
                    33: 174.7,
                    34: 180.5,
                    35: 184.5,
                    36: 187.6,
                    37: 190.3,
                    38: 192.5,
                    39: 194.4,
                    40: 196.0,
                    41: 197.5,
                    42: 198.7,
                    43: 199.8,
                    44: 200.6,
                    45: 201.4,
                    46: 202.3,
                    47: 203.4,
                    48: 204.7,
                    49: 205.5,
                    50: 205.1,
                    51: 202.5,
                    52: 197.0,
                    53: 188.7,
                    54: 177.5,
                    55: 163.8,
                    56: 147.7,
                    57: 131.0,
                    58: 115.3,
                    59: 102.6,
                    60: 94.1,
                    61: 89.2,
                    62: 86.7,
                    63: 85.5,
                    64: 84.5,
                    65: 83.5,
                    66: 82.3,
                    67: 81.0,
                    68: 79.4,
                    69: 77.8,
                    70: 76.7,
                    71: 76.5,
                    72: 77.3,
                    73: 78.7,
                    74: 80.1,
                    75: 81.0,
                    76: 80.9,
                    77: 80.3,
                    78: 80.1,
                    79: 81.0,
                    80: 83.4,
                    81: 86.7,
                    82: 89.5,
                    83: 90.9,
                    84: 90.0,
                    85: 87.5,
                    86: 84.1,
                    87: 81.0,
                    88: 78.7,
                    89: 77.1,
                    90: 75.9,
                    91: 74.7,
                    92: 73.3,
                    93: 71.8,
                    94: 70.4,
                    95: 69.3,
                },
                BDEWDAY.Sunday: {
                    0: 68.7,
                    1: 68.3,
                    2: 68.0,
                    3: 67.5,
                    4: 66.6,
                    5: 65.6,
                    6: 64.6,
                    7: 63.9,
                    8: 63.7,
                    9: 63.7,
                    10: 63.9,
                    11: 63.9,
                    12: 63.6,
                    13: 63.0,
                    14: 62.5,
                    15: 62.1,
                    16: 62.0,
                    17: 62.0,
                    18: 62.1,
                    19: 62.1,
                    20: 61.8,
                    21: 61.5,
                    22: 61.2,
                    23: 61.2,
                    24: 61.6,
                    25: 62.5,
                    26: 63.8,
                    27: 65.7,
                    28: 68.0,
                    29: 70.4,
                    30: 72.2,
                    31: 72.9,
                    32: 72.2,
                    33: 70.5,
                    34: 68.4,
                    35: 66.6,
                    36: 65.5,
                    37: 65.1,
                    38: 65.2,
                    39: 65.7,
                    40: 66.4,
                    41: 67.3,
                    42: 68.3,
                    43: 69.3,
                    44: 70.2,
                    45: 71.1,
                    46: 71.7,
                    47: 72.0,
                    48: 71.9,
                    49: 71.6,
                    50: 71.0,
                    51: 70.2,
                    52: 69.3,
                    53: 68.5,
                    54: 67.8,
                    55: 67.5,
                    56: 67.6,
                    57: 67.9,
                    58: 68.2,
                    59: 68.4,
                    60: 68.2,
                    61: 67.8,
                    62: 67.5,
                    63: 67.5,
                    64: 67.9,
                    65: 68.5,
                    66: 69.0,
                    67: 69.3,
                    68: 69.1,
                    69: 68.7,
                    70: 68.6,
                    71: 69.3,
                    72: 70.9,
                    73: 73.0,
                    74: 75.1,
                    75: 76.5,
                    76: 76.8,
                    77: 76.5,
                    78: 76.5,
                    79: 77.4,
                    80: 79.7,
                    81: 82.7,
                    82: 85.3,
                    83: 86.4,
                    84: 85.4,
                    85: 82.7,
                    86: 79.5,
                    87: 76.5,
                    88: 74.5,
                    89: 73.2,
                    90: 72.2,
                    91: 71.1,
                    92: 69.6,
                    93: 68.0,
                    94: 66.8,
                    95: 66.6,
                },
                BDEWDAY.Workday: {
                    0: 74.5,
                    1: 73.6,
                    2: 72.8,
                    3: 72.0,
                    4: 71.0,
                    5: 70.0,
                    6: 69.1,
                    7: 68.4,
                    8: 68.0,
                    9: 67.9,
                    10: 67.7,
                    11: 67.5,
                    12: 67.0,
                    13: 66.4,
                    14: 65.9,
                    15: 65.7,
                    16: 65.8,
                    17: 66.1,
                    18: 66.5,
                    19: 66.6,
                    20: 66.4,
                    21: 65.9,
                    22: 65.3,
                    23: 64.8,
                    24: 64.6,
                    25: 65.4,
                    26: 67.9,
                    27: 72.9,
                    28: 80.9,
                    29: 91.6,
                    30: 104.4,
                    31: 118.8,
                    32: 133.9,
                    33: 148.8,
                    34: 162.2,
                    35: 172.8,
                    36: 179.8,
                    37: 183.9,
                    38: 186.3,
                    39: 188.1,
                    40: 190.1,
                    41: 192.2,
                    42: 194.0,
                    43: 195.3,
                    44: 195.6,
                    45: 195.3,
                    46: 194.5,
                    47: 193.5,
                    48: 192.3,
                    49: 190.3,
                    50: 186.5,
                    51: 180.0,
                    52: 170.4,
                    53: 159.3,
                    54: 148.9,
                    55: 141.3,
                    56: 138.1,
                    57: 139.2,
                    58: 143.7,
                    59: 151.2,
                    60: 160.6,
                    61: 170.6,
                    62: 179.7,
                    63: 186.3,
                    64: 189.2,
                    65: 189.5,
                    66: 188.3,
                    67: 187.2,
                    68: 186.9,
                    69: 187.2,
                    70: 186.9,
                    71: 185.4,
                    72: 181.7,
                    73: 175.7,
                    74: 167.1,
                    75: 155.7,
                    76: 141.7,
                    77: 127.2,
                    78: 114.2,
                    79: 105.3,
                    80: 101.8,
                    81: 102.3,
                    82: 104.2,
                    83: 105.3,
                    84: 103.7,
                    85: 100.0,
                    86: 95.3,
                    87: 90.9,
                    88: 87.5,
                    89: 85.2,
                    90: 83.4,
                    91: 81.9,
                    92: 80.2,
                    93: 78.6,
                    94: 77.0,
                    95: 75.6,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 67.2,
                    1: 65.9,
                    2: 64.8,
                    3: 63.9,
                    4: 63.2,
                    5: 62.7,
                    6: 62.4,
                    7: 62.1,
                    8: 61.8,
                    9: 61.6,
                    10: 61.3,
                    11: 61.2,
                    12: 61.1,
                    13: 61.1,
                    14: 61.1,
                    15: 61.2,
                    16: 61.3,
                    17: 61.4,
                    18: 61.6,
                    19: 62.1,
                    20: 62.7,
                    21: 63.3,
                    22: 63.5,
                    23: 63.0,
                    24: 61.9,
                    25: 62.0,
                    26: 65.2,
                    27: 73.8,
                    28: 88.9,
                    29: 108.6,
                    30: 129.7,
                    31: 149.4,
                    32: 165.2,
                    33: 177.2,
                    34: 185.8,
                    35: 191.7,
                    36: 195.3,
                    37: 197.3,
                    38: 198.3,
                    39: 198.9,
                    40: 199.5,
                    41: 200.2,
                    42: 200.9,
                    43: 201.6,
                    44: 202.1,
                    45: 202.7,
                    46: 203.3,
                    47: 204.3,
                    48: 205.4,
                    49: 206.1,
                    50: 205.4,
                    51: 202.5,
                    52: 196.5,
                    53: 187.7,
                    54: 176.1,
                    55: 162.0,
                    56: 145.8,
                    57: 129.0,
                    58: 113.1,
                    59: 99.9,
                    60: 90.4,
                    61: 84.1,
                    62: 80.1,
                    63: 77.4,
                    64: 75.1,
                    65: 73.3,
                    66: 72.2,
                    67: 72.0,
                    68: 72.8,
                    69: 74.0,
                    70: 75.2,
                    71: 75.6,
                    72: 74.9,
                    73: 73.7,
                    74: 72.7,
                    75: 72.9,
                    76: 74.7,
                    77: 77.6,
                    78: 80.9,
                    79: 83.7,
                    80: 85.5,
                    81: 86.1,
                    82: 85.8,
                    83: 84.6,
                    84: 82.6,
                    85: 80.2,
                    86: 77.4,
                    87: 74.7,
                    88: 72.1,
                    89: 69.9,
                    90: 68.0,
                    91: 66.6,
                    92: 65.6,
                    93: 65.0,
                    94: 64.4,
                    95: 63.9,
                },
                BDEWDAY.Sunday: {
                    0: 63.1,
                    1: 62.2,
                    2: 61.3,
                    3: 60.3,
                    4: 59.4,
                    5: 58.6,
                    6: 58.0,
                    7: 57.6,
                    8: 57.4,
                    9: 57.4,
                    10: 57.5,
                    11: 57.6,
                    12: 57.7,
                    13: 57.7,
                    14: 57.7,
                    15: 57.6,
                    16: 57.4,
                    17: 57.3,
                    18: 57.3,
                    19: 57.6,
                    20: 58.2,
                    21: 58.9,
                    22: 59.4,
                    23: 59.4,
                    24: 58.7,
                    25: 57.7,
                    26: 57.2,
                    27: 57.6,
                    28: 59.4,
                    29: 62.0,
                    30: 64.6,
                    31: 66.6,
                    32: 67.3,
                    33: 67.0,
                    34: 66.0,
                    35: 64.8,
                    36: 63.7,
                    37: 62.8,
                    38: 62.3,
                    39: 62.1,
                    40: 62.3,
                    41: 62.9,
                    42: 63.8,
                    43: 64.8,
                    44: 65.8,
                    45: 66.7,
                    46: 67.3,
                    47: 67.5,
                    48: 67.1,
                    49: 66.2,
                    50: 65.1,
                    51: 63.9,
                    52: 62.8,
                    53: 62.0,
                    54: 61.4,
                    55: 61.2,
                    56: 61.4,
                    57: 61.9,
                    58: 62.5,
                    59: 63.0,
                    60: 63.3,
                    61: 63.4,
                    62: 63.3,
                    63: 63.0,
                    64: 62.6,
                    65: 62.3,
                    66: 62.4,
                    67: 63.0,
                    68: 64.3,
                    69: 65.9,
                    70: 67.5,
                    71: 68.4,
                    72: 68.4,
                    73: 68.0,
                    74: 67.8,
                    75: 68.4,
                    76: 70.2,
                    77: 72.8,
                    78: 75.7,
                    79: 78.3,
                    80: 80.2,
                    81: 81.3,
                    82: 81.5,
                    83: 81.0,
                    84: 79.6,
                    85: 77.7,
                    86: 75.4,
                    87: 72.9,
                    88: 70.4,
                    89: 68.1,
                    90: 65.9,
                    91: 63.9,
                    92: 62.2,
                    93: 61.0,
                    94: 60.3,
                    95: 60.3,
                },
                BDEWDAY.Workday: {
                    0: 67.2,
                    1: 66.1,
                    2: 64.9,
                    3: 63.9,
                    4: 63.0,
                    5: 62.2,
                    6: 61.6,
                    7: 61.2,
                    8: 61.1,
                    9: 61.1,
                    10: 61.2,
                    11: 61.2,
                    12: 61.1,
                    13: 60.9,
                    14: 60.6,
                    15: 60.3,
                    16: 60.0,
                    17: 59.8,
                    18: 59.9,
                    19: 60.3,
                    20: 61.1,
                    21: 62.1,
                    22: 62.8,
                    23: 63.0,
                    24: 62.5,
                    25: 62.2,
                    26: 63.2,
                    27: 66.6,
                    28: 73.2,
                    29: 83.3,
                    30: 96.7,
                    31: 113.4,
                    32: 132.9,
                    33: 153.2,
                    34: 171.8,
                    35: 186.3,
                    36: 194.8,
                    37: 198.7,
                    38: 199.7,
                    39: 199.8,
                    40: 200.4,
                    41: 201.5,
                    42: 202.7,
                    43: 203.4,
                    44: 203.2,
                    45: 202.3,
                    46: 200.8,
                    47: 198.9,
                    48: 196.6,
                    49: 193.3,
                    50: 188.3,
                    51: 180.9,
                    52: 170.7,
                    53: 159.4,
                    54: 149.2,
                    55: 142.2,
                    56: 139.9,
                    57: 142.2,
                    58: 148.0,
                    59: 156.6,
                    60: 166.9,
                    61: 177.6,
                    62: 186.9,
                    63: 193.5,
                    64: 196.1,
                    65: 196.0,
                    66: 194.9,
                    67: 194.4,
                    68: 195.6,
                    69: 197.4,
                    70: 197.9,
                    71: 195.3,
                    72: 188.3,
                    73: 177.7,
                    74: 164.9,
                    75: 151.2,
                    76: 137.8,
                    77: 125.5,
                    78: 115.3,
                    79: 108.0,
                    80: 103.9,
                    81: 102.1,
                    82: 101.2,
                    83: 99.9,
                    84: 97.1,
                    85: 93.2,
                    86: 88.8,
                    87: 84.6,
                    88: 81.0,
                    89: 78.1,
                    90: 75.7,
                    91: 73.8,
                    92: 72.2,
                    93: 70.8,
                    94: 69.6,
                    95: 68.4,
                },
            },
        }
        self.G5: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 66.6,
                    1: 87.3,
                    2: 111.7,
                    3: 137.0,
                    4: 160.7,
                    5: 180.8,
                    6: 195.6,
                    7: 203.5,
                    8: 203.7,
                    9: 198.9,
                    10: 192.6,
                    11: 188.4,
                    12: 189.1,
                    13: 194.0,
                    14: 201.6,
                    15: 210.6,
                    16: 219.6,
                    17: 228.2,
                    18: 236.0,
                    19: 242.8,
                    20: 248.4,
                    21: 252.5,
                    22: 255.0,
                    23: 255.9,
                    24: 255.1,
                    25: 253.2,
                    26: 250.5,
                    27: 247.9,
                    28: 245.4,
                    29: 242.0,
                    30: 236.2,
                    31: 226.7,
                    32: 212.7,
                    33: 196.2,
                    34: 180.2,
                    35: 167.3,
                    36: 159.5,
                    37: 155.5,
                    38: 153.4,
                    39: 151.1,
                    40: 147.0,
                    41: 141.5,
                    42: 135.6,
                    43: 130.0,
                    44: 125.6,
                    45: 122.7,
                    46: 121.4,
                    47: 121.9,
                    48: 124.1,
                    49: 126.4,
                    50: 127.0,
                    51: 123.9,
                    52: 116.1,
                    53: 105.0,
                    54: 93.1,
                    55: 82.6,
                    56: 75.3,
                    57: 70.8,
                    58: 68.2,
                    59: 66.5,
                    60: 64.9,
                    61: 63.5,
                    62: 62.3,
                    63: 61.5,
                    64: 61.1,
                    65: 61.5,
                    66: 62.5,
                    67: 64.5,
                    68: 67.3,
                    69: 70.5,
                    70: 73.5,
                    71: 75.6,
                    72: 76.3,
                    73: 75.9,
                    74: 74.6,
                    75: 72.5,
                    76: 70.1,
                    77: 67.5,
                    78: 64.9,
                    79: 62.5,
                    80: 60.4,
                    81: 58.6,
                    82: 57.0,
                    83: 55.4,
                    84: 53.9,
                    85: 52.2,
                    86: 50.4,
                    87: 48.4,
                    88: 46.1,
                    89: 43.8,
                    90: 41.8,
                    91: 40.3,
                    92: 39.6,
                    93: 39.4,
                    94: 39.4,
                    95: 39.3,
                },
                BDEWDAY.Sunday: {
                    0: 38.9,
                    1: 38.4,
                    2: 38.1,
                    3: 38.3,
                    4: 39.2,
                    5: 40.5,
                    6: 41.7,
                    7: 42.3,
                    8: 42.0,
                    9: 40.9,
                    10: 39.6,
                    11: 38.3,
                    12: 37.4,
                    13: 36.9,
                    14: 36.9,
                    15: 37.3,
                    16: 38.0,
                    17: 39.0,
                    18: 40.2,
                    19: 41.3,
                    20: 42.3,
                    21: 43.4,
                    22: 44.7,
                    23: 46.3,
                    24: 48.5,
                    25: 51.0,
                    26: 53.4,
                    27: 55.4,
                    28: 56.8,
                    29: 57.6,
                    30: 57.8,
                    31: 57.4,
                    32: 56.6,
                    33: 55.7,
                    34: 54.8,
                    35: 54.4,
                    36: 54.6,
                    37: 55.4,
                    38: 56.7,
                    39: 58.4,
                    40: 60.4,
                    41: 62.5,
                    42: 64.6,
                    43: 66.5,
                    44: 68.2,
                    45: 69.6,
                    46: 70.7,
                    47: 71.5,
                    48: 72.0,
                    49: 72.1,
                    50: 71.7,
                    51: 70.5,
                    52: 68.7,
                    53: 66.3,
                    54: 63.8,
                    55: 61.5,
                    56: 59.5,
                    57: 58.0,
                    58: 57.0,
                    59: 56.4,
                    60: 56.3,
                    61: 56.5,
                    62: 56.9,
                    63: 57.4,
                    64: 57.9,
                    65: 58.6,
                    66: 59.7,
                    67: 61.5,
                    68: 64.1,
                    69: 67.1,
                    70: 70.1,
                    71: 72.5,
                    72: 74.0,
                    73: 74.4,
                    74: 73.6,
                    75: 71.5,
                    76: 68.3,
                    77: 64.4,
                    78: 60.5,
                    79: 57.4,
                    80: 55.6,
                    81: 54.6,
                    82: 54.1,
                    83: 53.4,
                    84: 52.2,
                    85: 50.5,
                    86: 48.5,
                    87: 46.3,
                    88: 44.1,
                    89: 42.0,
                    90: 40.0,
                    91: 38.3,
                    92: 36.9,
                    93: 36.0,
                    94: 35.8,
                    95: 36.3,
                },
                BDEWDAY.Workday: {
                    0: 50.1,
                    1: 47.4,
                    2: 44.9,
                    3: 43.3,
                    4: 43.0,
                    5: 43.8,
                    6: 45.0,
                    7: 46.3,
                    8: 47.5,
                    9: 49.2,
                    10: 52.2,
                    11: 57.4,
                    12: 65.9,
                    13: 78.5,
                    14: 96.5,
                    15: 120.9,
                    16: 151.7,
                    17: 184.7,
                    18: 214.5,
                    19: 235.8,
                    20: 244.7,
                    21: 244.2,
                    22: 238.7,
                    23: 232.7,
                    24: 229.8,
                    25: 229.8,
                    26: 231.4,
                    27: 233.8,
                    28: 235.7,
                    29: 237.1,
                    30: 237.9,
                    31: 237.8,
                    32: 236.9,
                    33: 235.4,
                    34: 233.6,
                    35: 231.7,
                    36: 230.0,
                    37: 228.1,
                    38: 225.4,
                    39: 221.7,
                    40: 216.4,
                    41: 210.2,
                    42: 203.7,
                    43: 197.5,
                    44: 192.0,
                    45: 186.8,
                    46: 181.1,
                    47: 174.3,
                    48: 165.9,
                    49: 156.2,
                    50: 146.1,
                    51: 136.0,
                    52: 126.7,
                    53: 118.7,
                    54: 112.6,
                    55: 108.8,
                    56: 107.7,
                    57: 108.4,
                    58: 109.8,
                    59: 110.8,
                    60: 110.7,
                    61: 109.5,
                    62: 107.7,
                    63: 105.8,
                    64: 104.1,
                    65: 103.1,
                    66: 103.1,
                    67: 104.8,
                    68: 108.1,
                    69: 112.2,
                    70: 115.9,
                    71: 117.9,
                    72: 117.3,
                    73: 114.2,
                    74: 109.2,
                    75: 102.8,
                    76: 95.3,
                    77: 87.7,
                    78: 80.5,
                    79: 74.6,
                    80: 70.4,
                    81: 67.6,
                    82: 65.5,
                    83: 63.5,
                    84: 61.1,
                    85: 58.5,
                    86: 56.1,
                    87: 54.4,
                    88: 53.6,
                    89: 53.6,
                    90: 53.9,
                    91: 54.4,
                    92: 54.7,
                    93: 54.6,
                    94: 53.9,
                    95: 52.4,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 91.8,
                    1: 118.3,
                    2: 145.6,
                    3: 168.3,
                    4: 182.2,
                    5: 188.4,
                    6: 189.4,
                    7: 187.4,
                    8: 184.6,
                    9: 182.2,
                    10: 181.2,
                    11: 182.4,
                    12: 186.5,
                    13: 192.6,
                    14: 199.7,
                    15: 206.5,
                    16: 212.3,
                    17: 217.0,
                    18: 221.0,
                    19: 224.7,
                    20: 228.3,
                    21: 231.5,
                    22: 234.1,
                    23: 235.8,
                    24: 236.2,
                    25: 235.8,
                    26: 234.8,
                    27: 233.8,
                    28: 232.6,
                    29: 230.4,
                    30: 225.9,
                    31: 217.6,
                    32: 204.9,
                    33: 189.4,
                    34: 173.1,
                    35: 158.2,
                    36: 146.4,
                    37: 137.7,
                    38: 131.7,
                    39: 128.0,
                    40: 126.0,
                    41: 125.3,
                    42: 125.2,
                    43: 124.9,
                    44: 124.1,
                    45: 123.2,
                    46: 122.6,
                    47: 122.9,
                    48: 124.4,
                    49: 125.9,
                    50: 125.9,
                    51: 122.9,
                    52: 116.0,
                    53: 106.4,
                    54: 96.0,
                    55: 86.6,
                    56: 79.8,
                    57: 75.6,
                    58: 73.6,
                    59: 73.6,
                    60: 75.0,
                    61: 77.2,
                    62: 79.4,
                    63: 80.6,
                    64: 80.3,
                    65: 78.8,
                    66: 76.7,
                    67: 74.6,
                    68: 72.8,
                    69: 71.2,
                    70: 69.5,
                    71: 67.5,
                    72: 65.0,
                    73: 62.3,
                    74: 59.9,
                    75: 58.4,
                    76: 58.1,
                    77: 58.5,
                    78: 59.2,
                    79: 59.4,
                    80: 59.0,
                    81: 57.8,
                    82: 56.2,
                    83: 54.4,
                    84: 52.6,
                    85: 51.0,
                    86: 49.5,
                    87: 48.4,
                    88: 47.6,
                    89: 47.1,
                    90: 47.1,
                    91: 47.4,
                    92: 48.0,
                    93: 48.7,
                    94: 49.3,
                    95: 49.4,
                },
                BDEWDAY.Sunday: {
                    0: 48.8,
                    1: 47.8,
                    2: 46.6,
                    3: 45.3,
                    4: 44.3,
                    5: 43.4,
                    6: 42.8,
                    7: 42.3,
                    8: 42.0,
                    9: 41.9,
                    10: 42.0,
                    11: 42.3,
                    12: 42.8,
                    13: 43.3,
                    14: 43.9,
                    15: 44.3,
                    16: 44.6,
                    17: 44.8,
                    18: 45.0,
                    19: 45.3,
                    20: 46.0,
                    21: 46.8,
                    22: 48.0,
                    23: 49.4,
                    24: 51.0,
                    25: 52.7,
                    26: 54.2,
                    27: 55.4,
                    28: 56.2,
                    29: 56.5,
                    30: 56.6,
                    31: 56.4,
                    32: 56.2,
                    33: 55.9,
                    34: 55.6,
                    35: 55.4,
                    36: 55.4,
                    37: 55.7,
                    38: 56.7,
                    39: 58.4,
                    40: 61.2,
                    41: 64.5,
                    42: 68.1,
                    43: 71.5,
                    44: 74.4,
                    45: 76.7,
                    46: 78.4,
                    47: 79.6,
                    48: 80.2,
                    49: 80.1,
                    50: 79.2,
                    51: 77.6,
                    52: 75.1,
                    53: 72.1,
                    54: 69.1,
                    55: 66.5,
                    56: 64.6,
                    57: 63.5,
                    58: 63.1,
                    59: 63.5,
                    60: 64.4,
                    61: 65.7,
                    62: 66.8,
                    63: 67.5,
                    64: 67.4,
                    65: 66.8,
                    66: 66.0,
                    67: 65.5,
                    68: 65.4,
                    69: 65.5,
                    70: 65.3,
                    71: 64.5,
                    72: 62.7,
                    73: 60.3,
                    74: 57.8,
                    75: 55.4,
                    76: 53.7,
                    77: 52.5,
                    78: 51.8,
                    79: 51.4,
                    80: 51.2,
                    81: 51.1,
                    82: 50.9,
                    83: 50.4,
                    84: 49.4,
                    85: 48.2,
                    86: 47.1,
                    87: 46.3,
                    88: 46.2,
                    89: 46.4,
                    90: 46.9,
                    91: 47.4,
                    92: 47.7,
                    93: 47.9,
                    94: 48.1,
                    95: 48.4,
                },
                BDEWDAY.Workday: {
                    0: 67.4,
                    1: 61.2,
                    2: 54.6,
                    3: 49.4,
                    4: 46.7,
                    5: 46.0,
                    6: 45.9,
                    7: 45.3,
                    8: 43.9,
                    9: 44.3,
                    10: 50.0,
                    11: 64.5,
                    12: 89.7,
                    13: 121.1,
                    14: 152.6,
                    15: 178.3,
                    16: 193.7,
                    17: 200.6,
                    18: 202.4,
                    19: 202.5,
                    20: 203.8,
                    21: 206.0,
                    22: 208.6,
                    23: 210.6,
                    24: 211.5,
                    25: 211.5,
                    26: 211.1,
                    27: 210.6,
                    28: 210.3,
                    29: 210.3,
                    30: 210.4,
                    31: 210.6,
                    32: 210.8,
                    33: 210.8,
                    34: 210.4,
                    35: 209.6,
                    36: 208.1,
                    37: 205.8,
                    38: 202.6,
                    39: 198.5,
                    40: 193.4,
                    41: 187.8,
                    42: 182.3,
                    43: 177.3,
                    44: 173.3,
                    45: 169.7,
                    46: 165.6,
                    47: 160.2,
                    48: 153.0,
                    49: 144.7,
                    50: 136.0,
                    51: 128.0,
                    52: 121.3,
                    53: 116.6,
                    54: 114.0,
                    55: 113.9,
                    56: 116.3,
                    57: 120.1,
                    58: 123.8,
                    59: 125.9,
                    60: 125.5,
                    61: 123.0,
                    62: 119.5,
                    63: 115.9,
                    64: 113.0,
                    65: 110.9,
                    66: 109.5,
                    67: 108.8,
                    68: 108.5,
                    69: 108.2,
                    70: 107.1,
                    71: 104.8,
                    72: 100.7,
                    73: 95.2,
                    74: 89.0,
                    75: 82.6,
                    76: 76.6,
                    77: 71.2,
                    78: 66.7,
                    79: 63.5,
                    80: 61.6,
                    81: 60.6,
                    82: 60.1,
                    83: 59.4,
                    84: 58.3,
                    85: 57.0,
                    86: 55.8,
                    87: 55.4,
                    88: 56.0,
                    89: 57.7,
                    90: 60.2,
                    91: 63.5,
                    92: 67.3,
                    93: 70.6,
                    94: 72.4,
                    95: 71.5,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 75.6,
                    1: 97.6,
                    2: 121.4,
                    3: 143.1,
                    4: 159.4,
                    5: 170.6,
                    6: 177.6,
                    7: 181.4,
                    8: 182.9,
                    9: 183.1,
                    10: 182.9,
                    11: 183.4,
                    12: 185.2,
                    13: 188.7,
                    14: 193.7,
                    15: 200.5,
                    16: 208.8,
                    17: 217.5,
                    18: 225.2,
                    19: 230.7,
                    20: 233.1,
                    21: 232.9,
                    22: 231.4,
                    23: 229.7,
                    24: 228.7,
                    25: 228.4,
                    26: 228.8,
                    27: 229.7,
                    28: 230.9,
                    29: 230.9,
                    30: 228.0,
                    31: 220.7,
                    32: 207.9,
                    33: 191.8,
                    34: 175.3,
                    35: 161.2,
                    36: 151.7,
                    37: 145.9,
                    38: 142.2,
                    39: 139.0,
                    40: 135.1,
                    41: 130.6,
                    42: 126.0,
                    43: 121.9,
                    44: 118.8,
                    45: 116.9,
                    46: 116.5,
                    47: 117.9,
                    48: 120.8,
                    49: 123.8,
                    50: 124.8,
                    51: 121.9,
                    52: 113.9,
                    53: 102.6,
                    54: 90.3,
                    55: 79.6,
                    56: 72.3,
                    57: 68.1,
                    58: 66.1,
                    59: 65.5,
                    60: 65.5,
                    61: 65.7,
                    62: 65.8,
                    63: 65.5,
                    64: 64.6,
                    65: 63.6,
                    66: 63.0,
                    67: 63.5,
                    68: 65.4,
                    69: 68.2,
                    70: 71.2,
                    71: 73.6,
                    72: 74.8,
                    73: 74.8,
                    74: 73.7,
                    75: 71.5,
                    76: 68.6,
                    77: 65.3,
                    78: 62.0,
                    79: 59.4,
                    80: 57.8,
                    81: 56.9,
                    82: 56.3,
                    83: 55.4,
                    84: 54.1,
                    85: 52.4,
                    86: 50.7,
                    87: 49.4,
                    88: 48.6,
                    89: 48.1,
                    90: 47.8,
                    91: 47.4,
                    92: 46.5,
                    93: 45.5,
                    94: 44.3,
                    95: 43.3,
                },
                BDEWDAY.Sunday: {
                    0: 42.5,
                    1: 42.0,
                    2: 41.6,
                    3: 41.3,
                    4: 41.1,
                    5: 40.9,
                    6: 41.0,
                    7: 41.3,
                    8: 41.9,
                    9: 42.6,
                    10: 43.1,
                    11: 43.3,
                    12: 43.0,
                    13: 42.2,
                    14: 41.3,
                    15: 40.3,
                    16: 39.5,
                    17: 39.0,
                    18: 38.9,
                    19: 39.3,
                    20: 40.4,
                    21: 42.0,
                    22: 44.0,
                    23: 46.3,
                    24: 48.8,
                    25: 51.2,
                    26: 53.2,
                    27: 54.4,
                    28: 54.8,
                    29: 54.4,
                    30: 53.5,
                    31: 52.4,
                    32: 51.3,
                    33: 50.4,
                    34: 50.1,
                    35: 50.4,
                    36: 51.6,
                    37: 53.5,
                    38: 55.8,
                    39: 58.4,
                    40: 61.1,
                    41: 63.7,
                    42: 66.2,
                    43: 68.5,
                    44: 70.6,
                    45: 72.4,
                    46: 73.7,
                    47: 74.6,
                    48: 74.8,
                    49: 74.4,
                    50: 73.3,
                    51: 71.5,
                    52: 69.1,
                    53: 66.3,
                    54: 63.7,
                    55: 61.5,
                    56: 60.0,
                    57: 59.3,
                    58: 59.2,
                    59: 59.4,
                    60: 59.9,
                    61: 60.4,
                    62: 60.6,
                    63: 60.5,
                    64: 59.7,
                    65: 58.9,
                    66: 58.3,
                    67: 58.4,
                    68: 59.7,
                    69: 61.5,
                    70: 63.3,
                    71: 64.5,
                    72: 64.6,
                    73: 63.7,
                    74: 62.2,
                    75: 60.5,
                    76: 58.6,
                    77: 56.8,
                    78: 55.1,
                    79: 53.4,
                    80: 51.8,
                    81: 50.5,
                    82: 49.3,
                    83: 48.4,
                    84: 47.7,
                    85: 47.3,
                    86: 46.9,
                    87: 46.3,
                    88: 45.6,
                    89: 44.6,
                    90: 43.5,
                    91: 42.3,
                    92: 41.1,
                    93: 40.1,
                    94: 39.4,
                    95: 39.3,
                },
                BDEWDAY.Workday: {
                    0: 56.0,
                    1: 51.3,
                    2: 46.6,
                    3: 43.3,
                    4: 42.4,
                    5: 42.9,
                    6: 43.7,
                    7: 43.3,
                    8: 41.4,
                    9: 40.1,
                    10: 42.8,
                    11: 52.4,
                    12: 71.0,
                    13: 95.9,
                    14: 123.5,
                    15: 150.1,
                    16: 172.6,
                    17: 190.3,
                    18: 203.3,
                    19: 211.6,
                    20: 215.4,
                    21: 216.2,
                    22: 215.7,
                    23: 215.6,
                    24: 217.2,
                    25: 220.0,
                    26: 223.1,
                    27: 225.7,
                    28: 227.0,
                    29: 226.9,
                    30: 225.8,
                    31: 223.7,
                    32: 220.8,
                    33: 217.7,
                    34: 214.8,
                    35: 212.6,
                    36: 211.3,
                    37: 210.5,
                    38: 209.1,
                    39: 206.5,
                    40: 202.2,
                    41: 196.5,
                    42: 190.3,
                    43: 184.4,
                    44: 179.2,
                    45: 174.3,
                    46: 168.9,
                    47: 162.2,
                    48: 153.7,
                    49: 144.2,
                    50: 134.6,
                    51: 125.9,
                    52: 119.1,
                    53: 114.2,
                    54: 111.1,
                    55: 109.8,
                    56: 110.1,
                    57: 111.4,
                    58: 112.9,
                    59: 113.9,
                    60: 113.8,
                    61: 112.9,
                    62: 111.4,
                    63: 109.8,
                    64: 108.3,
                    65: 107.1,
                    66: 106.2,
                    67: 105.8,
                    68: 105.8,
                    69: 105.8,
                    70: 105.3,
                    71: 103.8,
                    72: 100.8,
                    73: 96.7,
                    74: 91.9,
                    75: 86.6,
                    76: 81.5,
                    77: 76.5,
                    78: 72.2,
                    79: 68.5,
                    80: 65.8,
                    81: 63.8,
                    82: 62.5,
                    83: 61.5,
                    84: 60.6,
                    85: 59.9,
                    86: 59.2,
                    87: 58.4,
                    88: 57.7,
                    89: 57.1,
                    90: 56.9,
                    91: 57.4,
                    92: 58.7,
                    93: 60.1,
                    94: 60.6,
                    95: 59.4,
                },
            },
        }
        self.G6: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 67.5,
                    1: 67.8,
                    2: 68.5,
                    3: 68.1,
                    4: 65.4,
                    5: 61.0,
                    6: 56.1,
                    7: 52.0,
                    8: 49.4,
                    9: 48.1,
                    10: 47.6,
                    11: 47.3,
                    12: 46.9,
                    13: 46.4,
                    14: 45.7,
                    15: 45.0,
                    16: 44.5,
                    17: 44.0,
                    18: 43.8,
                    19: 43.9,
                    20: 44.2,
                    21: 44.7,
                    22: 45.1,
                    23: 45.0,
                    24: 44.6,
                    25: 44.0,
                    26: 44.0,
                    27: 45.0,
                    28: 47.5,
                    29: 51.1,
                    30: 55.5,
                    31: 60.0,
                    32: 64.5,
                    33: 68.6,
                    34: 72.1,
                    35: 75.1,
                    36: 77.5,
                    37: 80.8,
                    38: 86.8,
                    39: 97.0,
                    40: 112.5,
                    41: 131.1,
                    42: 150.0,
                    43: 166.3,
                    44: 177.7,
                    45: 184.6,
                    46: 187.8,
                    47: 188.2,
                    48: 186.8,
                    49: 184.3,
                    50: 181.4,
                    51: 179.0,
                    52: 177.5,
                    53: 177.0,
                    54: 177.2,
                    55: 177.8,
                    56: 178.8,
                    57: 179.9,
                    58: 181.2,
                    59: 182.5,
                    60: 183.7,
                    61: 184.8,
                    62: 185.5,
                    63: 185.9,
                    64: 186.0,
                    65: 186.9,
                    66: 189.9,
                    67: 196.3,
                    68: 207.0,
                    69: 220.8,
                    70: 236.3,
                    71: 251.7,
                    72: 265.8,
                    73: 277.9,
                    74: 287.6,
                    75: 294.5,
                    76: 298.1,
                    77: 298.7,
                    78: 296.3,
                    79: 291.0,
                    80: 283.1,
                    81: 273.4,
                    82: 262.6,
                    83: 251.7,
                    84: 241.3,
                    85: 231.2,
                    86: 220.9,
                    87: 210.2,
                    88: 198.6,
                    89: 186.3,
                    90: 173.5,
                    91: 160.5,
                    92: 147.5,
                    93: 134.7,
                    94: 122.4,
                    95: 110.9,
                },
                BDEWDAY.Sunday: {
                    0: 100.3,
                    1: 91.1,
                    2: 83.4,
                    3: 77.4,
                    4: 73.2,
                    5: 70.5,
                    6: 68.6,
                    7: 67.0,
                    8: 65.1,
                    9: 63.0,
                    10: 60.9,
                    11: 58.9,
                    12: 57.1,
                    13: 55.4,
                    14: 53.8,
                    15: 52.0,
                    16: 50.0,
                    17: 48.0,
                    18: 46.3,
                    19: 45.0,
                    20: 44.4,
                    21: 44.3,
                    22: 44.2,
                    23: 43.9,
                    24: 43.2,
                    25: 42.5,
                    26: 42.6,
                    27: 43.9,
                    28: 46.9,
                    29: 51.1,
                    30: 55.7,
                    31: 60.0,
                    32: 63.8,
                    33: 68.3,
                    34: 75.4,
                    35: 86.6,
                    36: 103.2,
                    37: 123.6,
                    38: 145.8,
                    39: 167.4,
                    40: 186.9,
                    41: 203.9,
                    42: 218.5,
                    43: 231.0,
                    44: 241.2,
                    45: 249.2,
                    46: 254.7,
                    47: 257.5,
                    48: 257.7,
                    49: 256.1,
                    50: 253.8,
                    51: 251.7,
                    52: 250.6,
                    53: 249.1,
                    54: 245.5,
                    55: 237.9,
                    56: 225.3,
                    57: 209.3,
                    58: 192.3,
                    59: 176.7,
                    60: 164.2,
                    61: 154.7,
                    62: 147.5,
                    63: 142.0,
                    64: 137.9,
                    65: 136.1,
                    66: 138.2,
                    67: 145.5,
                    68: 158.9,
                    69: 176.8,
                    70: 196.9,
                    71: 217.1,
                    72: 235.2,
                    73: 249.8,
                    74: 259.6,
                    75: 263.3,
                    76: 260.3,
                    77: 252.5,
                    78: 242.6,
                    79: 233.3,
                    80: 226.5,
                    81: 221.6,
                    82: 217.3,
                    83: 212.5,
                    84: 205.9,
                    85: 197.3,
                    86: 186.5,
                    87: 173.2,
                    88: 157.6,
                    89: 140.7,
                    90: 123.9,
                    91: 108.5,
                    92: 95.6,
                    93: 84.9,
                    94: 76.0,
                    95: 68.1,
                },
                BDEWDAY.Workday: {
                    0: 62.1,
                    1: 55.6,
                    2: 50.1,
                    3: 46.2,
                    4: 44.0,
                    5: 43.0,
                    6: 42.8,
                    7: 42.7,
                    8: 42.3,
                    9: 41.7,
                    10: 40.9,
                    11: 40.4,
                    12: 40.2,
                    13: 40.2,
                    14: 40.3,
                    15: 40.4,
                    16: 40.3,
                    17: 40.2,
                    18: 40.2,
                    19: 40.4,
                    20: 40.9,
                    21: 41.6,
                    22: 42.3,
                    23: 42.7,
                    24: 42.9,
                    25: 43.0,
                    26: 43.6,
                    27: 45.0,
                    28: 47.7,
                    29: 51.7,
                    30: 57.0,
                    31: 63.5,
                    32: 71.1,
                    33: 79.2,
                    34: 86.9,
                    35: 93.5,
                    36: 98.6,
                    37: 102.6,
                    38: 106.4,
                    39: 110.9,
                    40: 116.8,
                    41: 124.4,
                    42: 133.9,
                    43: 145.5,
                    44: 159.0,
                    45: 172.7,
                    46: 184.3,
                    47: 191.7,
                    48: 193.5,
                    49: 191.1,
                    50: 186.7,
                    51: 182.5,
                    52: 179.8,
                    53: 177.6,
                    54: 174.1,
                    55: 167.4,
                    56: 156.5,
                    57: 143.2,
                    58: 130.2,
                    59: 120.1,
                    60: 114.8,
                    61: 113.5,
                    62: 114.2,
                    63: 115.5,
                    64: 116.0,
                    65: 116.6,
                    66: 118.7,
                    67: 123.6,
                    68: 132.1,
                    69: 143.0,
                    70: 154.6,
                    71: 165.1,
                    72: 173.3,
                    73: 179.3,
                    74: 183.7,
                    75: 187.1,
                    76: 189.8,
                    77: 192.1,
                    78: 193.9,
                    79: 195.2,
                    80: 195.9,
                    81: 195.8,
                    82: 194.5,
                    83: 191.7,
                    84: 187.0,
                    85: 180.2,
                    86: 171.4,
                    87: 160.5,
                    88: 147.6,
                    89: 133.5,
                    90: 119.4,
                    91: 106.2,
                    92: 95.0,
                    93: 85.4,
                    94: 76.9,
                    95: 69.3,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 60.0,
                    1: 59.4,
                    2: 59.4,
                    3: 58.9,
                    4: 57.1,
                    5: 54.3,
                    6: 51.3,
                    7: 48.5,
                    8: 46.5,
                    9: 45.2,
                    10: 44.4,
                    11: 43.9,
                    12: 43.4,
                    13: 43.0,
                    14: 42.4,
                    15: 41.6,
                    16: 40.6,
                    17: 39.5,
                    18: 38.6,
                    19: 38.1,
                    20: 38.2,
                    21: 38.7,
                    22: 39.5,
                    23: 40.4,
                    24: 41.3,
                    25: 42.3,
                    26: 43.9,
                    27: 46.2,
                    28: 49.5,
                    29: 53.4,
                    30: 57.5,
                    31: 61.2,
                    32: 64.3,
                    33: 67.2,
                    34: 70.2,
                    35: 73.9,
                    36: 78.7,
                    37: 84.7,
                    38: 91.9,
                    39: 100.5,
                    40: 110.2,
                    41: 120.3,
                    42: 129.7,
                    43: 137.4,
                    44: 142.7,
                    45: 145.9,
                    46: 147.4,
                    47: 147.8,
                    48: 147.5,
                    49: 146.8,
                    50: 145.7,
                    51: 144.3,
                    52: 143.0,
                    53: 142.1,
                    54: 142.4,
                    55: 144.3,
                    56: 148.4,
                    57: 154.0,
                    58: 160.6,
                    59: 167.4,
                    60: 173.8,
                    61: 179.2,
                    62: 183.1,
                    63: 184.8,
                    64: 184.1,
                    65: 182.1,
                    66: 179.9,
                    67: 179.0,
                    68: 180.3,
                    69: 183.8,
                    70: 189.2,
                    71: 196.3,
                    72: 204.6,
                    73: 213.4,
                    74: 221.7,
                    75: 228.6,
                    76: 233.6,
                    77: 236.4,
                    78: 237.4,
                    79: 236.7,
                    80: 234.5,
                    81: 231.0,
                    82: 226.3,
                    83: 220.6,
                    84: 213.9,
                    85: 206.1,
                    86: 197.2,
                    87: 187.1,
                    88: 175.6,
                    89: 163.1,
                    90: 150.3,
                    91: 137.4,
                    92: 125.1,
                    93: 113.5,
                    94: 102.9,
                    95: 93.5,
                },
                BDEWDAY.Sunday: {
                    0: 85.6,
                    1: 79.0,
                    2: 73.6,
                    3: 69.3,
                    4: 65.8,
                    5: 63.0,
                    6: 60.4,
                    7: 57.7,
                    8: 54.8,
                    9: 51.7,
                    10: 48.7,
                    11: 46.2,
                    12: 44.3,
                    13: 42.8,
                    14: 41.6,
                    15: 40.4,
                    16: 39.2,
                    17: 38.0,
                    18: 37.2,
                    19: 37.0,
                    20: 37.5,
                    21: 38.3,
                    22: 39.1,
                    23: 39.3,
                    24: 38.6,
                    25: 37.7,
                    26: 37.7,
                    27: 39.3,
                    28: 43.2,
                    29: 49.1,
                    30: 56.1,
                    31: 63.5,
                    32: 70.9,
                    33: 78.3,
                    34: 86.1,
                    35: 94.7,
                    36: 104.4,
                    37: 115.4,
                    38: 127.9,
                    39: 142.0,
                    40: 157.7,
                    41: 173.7,
                    42: 188.2,
                    43: 199.8,
                    44: 207.2,
                    45: 211.0,
                    46: 212.5,
                    47: 212.5,
                    48: 212.0,
                    49: 211.5,
                    50: 211.2,
                    51: 211.3,
                    52: 211.8,
                    53: 211.7,
                    54: 209.7,
                    55: 204.4,
                    56: 195.1,
                    57: 183.1,
                    58: 170.2,
                    59: 158.2,
                    60: 148.6,
                    61: 141.2,
                    62: 135.3,
                    63: 130.5,
                    64: 126.4,
                    65: 123.6,
                    66: 123.1,
                    67: 125.9,
                    68: 132.5,
                    69: 142.1,
                    70: 153.8,
                    71: 166.3,
                    72: 178.7,
                    73: 190.1,
                    74: 199.7,
                    75: 206.7,
                    76: 210.6,
                    77: 212.0,
                    78: 211.6,
                    79: 210.2,
                    80: 208.4,
                    81: 206.0,
                    82: 202.5,
                    83: 197.5,
                    84: 190.5,
                    85: 182.0,
                    86: 172.2,
                    87: 161.7,
                    88: 150.7,
                    89: 139.2,
                    90: 127.1,
                    91: 114.3,
                    92: 100.9,
                    93: 87.5,
                    94: 75.1,
                    95: 64.7,
                },
                BDEWDAY.Workday: {
                    0: 56.8,
                    1: 52.0,
                    2: 48.0,
                    3: 45.0,
                    4: 43.0,
                    5: 41.8,
                    6: 41.0,
                    7: 40.4,
                    8: 39.7,
                    9: 39.1,
                    10: 38.5,
                    11: 38.1,
                    12: 38.0,
                    13: 38.1,
                    14: 38.2,
                    15: 38.1,
                    16: 37.7,
                    17: 37.2,
                    18: 36.9,
                    19: 37.0,
                    20: 37.6,
                    21: 38.6,
                    22: 39.6,
                    23: 40.4,
                    24: 40.8,
                    25: 41.0,
                    26: 41.5,
                    27: 42.7,
                    28: 45.0,
                    29: 48.3,
                    30: 52.6,
                    31: 57.7,
                    32: 63.6,
                    33: 69.6,
                    34: 75.2,
                    35: 79.7,
                    36: 82.8,
                    37: 85.2,
                    38: 87.7,
                    39: 91.2,
                    40: 96.5,
                    41: 103.5,
                    42: 111.8,
                    43: 121.3,
                    44: 131.4,
                    45: 141.2,
                    46: 149.8,
                    47: 155.9,
                    48: 158.9,
                    49: 159.2,
                    50: 157.5,
                    51: 154.7,
                    52: 151.3,
                    53: 147.2,
                    54: 141.9,
                    55: 135.1,
                    56: 126.7,
                    57: 117.8,
                    58: 109.4,
                    59: 102.8,
                    60: 98.9,
                    61: 97.3,
                    62: 97.3,
                    63: 98.2,
                    64: 99.3,
                    65: 100.8,
                    66: 103.0,
                    67: 106.2,
                    68: 110.6,
                    69: 115.8,
                    70: 121.4,
                    71: 127.0,
                    72: 132.3,
                    73: 137.1,
                    74: 141.5,
                    75: 145.5,
                    76: 149.1,
                    77: 152.2,
                    78: 154.5,
                    79: 155.9,
                    80: 156.3,
                    81: 155.8,
                    82: 154.8,
                    83: 153.6,
                    84: 152.2,
                    85: 150.0,
                    86: 146.1,
                    87: 139.7,
                    88: 130.3,
                    89: 118.7,
                    90: 106.4,
                    91: 94.7,
                    92: 84.5,
                    93: 76.0,
                    94: 68.7,
                    95: 62.4,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 64.7,
                    1: 63.4,
                    2: 63.0,
                    3: 62.4,
                    4: 60.4,
                    5: 57.5,
                    6: 54.1,
                    7: 50.8,
                    8: 48.1,
                    9: 45.9,
                    10: 44.1,
                    11: 42.7,
                    12: 41.6,
                    13: 40.6,
                    14: 39.8,
                    15: 39.3,
                    16: 38.8,
                    17: 38.5,
                    18: 38.3,
                    19: 38.1,
                    20: 37.9,
                    21: 37.7,
                    22: 37.4,
                    23: 37.0,
                    24: 36.4,
                    25: 36.3,
                    26: 37.0,
                    27: 39.3,
                    28: 43.3,
                    29: 48.5,
                    30: 54.0,
                    31: 58.9,
                    32: 62.6,
                    33: 65.6,
                    34: 68.7,
                    35: 72.8,
                    36: 78.3,
                    37: 85.5,
                    38: 94.1,
                    39: 103.9,
                    40: 114.8,
                    41: 126.0,
                    42: 136.5,
                    43: 145.5,
                    44: 152.3,
                    45: 157.1,
                    46: 160.1,
                    47: 161.7,
                    48: 162.1,
                    49: 161.8,
                    50: 161.1,
                    51: 160.5,
                    52: 160.3,
                    53: 160.7,
                    54: 161.8,
                    55: 164.0,
                    56: 167.1,
                    57: 170.9,
                    58: 174.7,
                    59: 177.8,
                    60: 180.0,
                    61: 181.2,
                    62: 181.6,
                    63: 181.3,
                    64: 180.7,
                    65: 180.5,
                    66: 181.6,
                    67: 184.8,
                    68: 190.7,
                    69: 198.9,
                    70: 208.8,
                    71: 219.4,
                    72: 230.2,
                    73: 240.7,
                    74: 250.3,
                    75: 258.7,
                    76: 265.2,
                    77: 269.8,
                    78: 271.9,
                    79: 271.4,
                    80: 268.1,
                    81: 262.6,
                    82: 255.8,
                    83: 248.3,
                    84: 240.7,
                    85: 232.6,
                    86: 223.4,
                    87: 212.5,
                    88: 199.4,
                    89: 184.8,
                    90: 169.6,
                    91: 154.7,
                    92: 141.0,
                    93: 128.5,
                    94: 117.3,
                    95: 107.4,
                },
                BDEWDAY.Sunday: {
                    0: 98.7,
                    1: 91.2,
                    2: 84.5,
                    3: 78.5,
                    4: 73.1,
                    5: 68.1,
                    6: 63.8,
                    7: 60.0,
                    8: 57.0,
                    9: 54.3,
                    10: 52.0,
                    11: 49.7,
                    12: 47.2,
                    13: 44.7,
                    14: 42.4,
                    15: 40.4,
                    16: 38.9,
                    17: 37.8,
                    18: 37.1,
                    19: 37.0,
                    20: 37.2,
                    21: 37.5,
                    22: 37.5,
                    23: 37.0,
                    24: 35.7,
                    25: 34.5,
                    26: 34.6,
                    27: 37.0,
                    28: 42.3,
                    29: 49.8,
                    30: 58.0,
                    31: 65.8,
                    32: 72.3,
                    33: 78.7,
                    34: 86.4,
                    35: 97.0,
                    36: 111.6,
                    37: 129.1,
                    38: 147.9,
                    39: 166.3,
                    40: 183.1,
                    41: 198.4,
                    42: 213.1,
                    43: 227.5,
                    44: 242.0,
                    45: 255.2,
                    46: 265.6,
                    47: 271.4,
                    48: 271.6,
                    49: 267.8,
                    50: 262.4,
                    51: 257.5,
                    52: 254.9,
                    53: 253.3,
                    54: 250.9,
                    55: 246.0,
                    56: 237.1,
                    57: 225.2,
                    58: 211.5,
                    59: 197.5,
                    60: 184.2,
                    61: 171.9,
                    62: 160.6,
                    63: 150.1,
                    64: 140.8,
                    65: 133.8,
                    66: 130.7,
                    67: 132.8,
                    68: 141.1,
                    69: 154.4,
                    70: 170.7,
                    71: 188.2,
                    72: 205.2,
                    73: 220.5,
                    74: 232.9,
                    75: 241.3,
                    76: 245.2,
                    77: 245.3,
                    78: 242.8,
                    79: 239.0,
                    80: 234.9,
                    81: 230.1,
                    82: 224.3,
                    83: 217.1,
                    84: 208.0,
                    85: 197.2,
                    86: 184.8,
                    87: 170.9,
                    88: 155.9,
                    89: 140.2,
                    90: 124.6,
                    91: 109.7,
                    92: 96.0,
                    93: 83.9,
                    94: 73.4,
                    95: 64.7,
                },
                BDEWDAY.Workday: {
                    0: 61.0,
                    1: 54.9,
                    2: 49.9,
                    3: 46.2,
                    4: 43.7,
                    5: 42.1,
                    6: 41.1,
                    7: 40.4,
                    8: 39.7,
                    9: 39.0,
                    10: 38.5,
                    11: 38.1,
                    12: 38.0,
                    13: 38.1,
                    14: 38.2,
                    15: 38.1,
                    16: 37.8,
                    17: 37.4,
                    18: 37.0,
                    19: 37.0,
                    20: 37.3,
                    21: 37.9,
                    22: 38.6,
                    23: 39.3,
                    24: 39.8,
                    25: 40.4,
                    26: 41.2,
                    27: 42.7,
                    28: 45.0,
                    29: 48.1,
                    30: 52.0,
                    31: 56.6,
                    32: 61.8,
                    33: 67.5,
                    34: 73.1,
                    35: 78.5,
                    36: 83.4,
                    37: 88.1,
                    38: 92.9,
                    39: 98.2,
                    40: 104.3,
                    41: 111.6,
                    42: 120.6,
                    43: 131.6,
                    44: 144.7,
                    45: 158.3,
                    46: 170.4,
                    47: 179.0,
                    48: 182.7,
                    49: 182.6,
                    50: 180.1,
                    51: 176.7,
                    52: 173.6,
                    53: 170.1,
                    54: 165.3,
                    55: 158.2,
                    56: 148.2,
                    57: 136.6,
                    58: 125.1,
                    59: 115.5,
                    60: 109.0,
                    61: 105.2,
                    62: 103.4,
                    63: 102.8,
                    64: 102.7,
                    65: 103.7,
                    66: 106.2,
                    67: 110.9,
                    68: 118.1,
                    69: 127.2,
                    70: 137.4,
                    71: 147.8,
                    72: 157.6,
                    73: 166.3,
                    74: 173.6,
                    75: 179.0,
                    76: 182.4,
                    77: 184.2,
                    78: 185.1,
                    79: 185.9,
                    80: 187.0,
                    81: 188.0,
                    82: 188.2,
                    83: 187.1,
                    84: 184.0,
                    85: 178.9,
                    86: 171.4,
                    87: 161.7,
                    88: 149.6,
                    89: 136.0,
                    90: 122.0,
                    91: 108.5,
                    92: 96.4,
                    93: 85.8,
                    94: 76.4,
                    95: 68.1,
                },
            },
        }
        self.L0: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 73.9,
                    1: 73.0,
                    2: 72.6,
                    3: 72.3,
                    4: 71.5,
                    5: 70.4,
                    6: 69.1,
                    7: 67.6,
                    8: 66.2,
                    9: 64.8,
                    10: 63.4,
                    11: 62.1,
                    12: 60.7,
                    13: 59.4,
                    14: 58.3,
                    15: 57.4,
                    16: 56.9,
                    17: 56.8,
                    18: 57.0,
                    19: 57.4,
                    20: 58.2,
                    21: 59.2,
                    22: 60.5,
                    23: 62.1,
                    24: 64.1,
                    25: 67.4,
                    26: 72.9,
                    27: 81.5,
                    28: 93.9,
                    29: 109.4,
                    30: 126.9,
                    31: 145.4,
                    32: 163.8,
                    33: 181.0,
                    34: 195.6,
                    35: 206.6,
                    36: 212.9,
                    37: 214.6,
                    38: 212.1,
                    39: 205.6,
                    40: 195.9,
                    41: 185.0,
                    42: 175.4,
                    43: 169.5,
                    44: 168.9,
                    45: 171.3,
                    46: 173.5,
                    47: 172.3,
                    48: 165.4,
                    49: 154.5,
                    50: 142.0,
                    51: 130.6,
                    52: 122.1,
                    53: 116.1,
                    54: 111.6,
                    55: 107.4,
                    56: 102.9,
                    57: 98.2,
                    58: 94.0,
                    59: 90.8,
                    60: 88.9,
                    61: 88.2,
                    62: 88.0,
                    63: 88.0,
                    64: 87.9,
                    65: 88.5,
                    66: 90.9,
                    67: 96.3,
                    68: 105.5,
                    69: 117.8,
                    70: 132.7,
                    71: 149.1,
                    72: 166.4,
                    73: 183.4,
                    74: 199.0,
                    75: 212.1,
                    76: 221.5,
                    77: 226.2,
                    78: 224.9,
                    79: 216.8,
                    80: 201.3,
                    81: 181.3,
                    82: 160.3,
                    83: 141.7,
                    84: 128.3,
                    85: 119.3,
                    86: 113.2,
                    87: 108.4,
                    88: 103.7,
                    89: 98.8,
                    90: 93.9,
                    91: 88.9,
                    92: 84.0,
                    93: 79.3,
                    94: 75.0,
                    95: 71.3,
                },
                BDEWDAY.Sunday: {
                    0: 68.3,
                    1: 66.0,
                    2: 64.3,
                    3: 63.0,
                    4: 62.1,
                    5: 61.4,
                    6: 60.8,
                    7: 60.2,
                    8: 59.5,
                    9: 58.8,
                    10: 58.0,
                    11: 57.4,
                    12: 57.0,
                    13: 56.7,
                    14: 56.6,
                    15: 56.5,
                    16: 56.4,
                    17: 56.5,
                    18: 56.8,
                    19: 57.4,
                    20: 58.5,
                    21: 60.5,
                    22: 63.7,
                    23: 68.5,
                    24: 75.3,
                    25: 84.1,
                    26: 94.8,
                    27: 107.4,
                    28: 121.9,
                    29: 137.8,
                    30: 155.0,
                    31: 173.2,
                    32: 191.7,
                    33: 208.6,
                    34: 221.4,
                    35: 227.9,
                    36: 226.4,
                    37: 218.6,
                    38: 206.6,
                    39: 192.7,
                    40: 178.9,
                    41: 167.0,
                    42: 158.1,
                    43: 153.8,
                    44: 154.6,
                    45: 158.2,
                    46: 161.5,
                    47: 161.2,
                    48: 155.2,
                    49: 145.4,
                    50: 134.4,
                    51: 125.0,
                    52: 119.4,
                    53: 116.9,
                    54: 116.1,
                    55: 115.8,
                    56: 114.8,
                    57: 113.2,
                    58: 111.3,
                    59: 109.3,
                    60: 107.5,
                    61: 106.1,
                    62: 105.4,
                    63: 105.6,
                    64: 106.9,
                    65: 109.8,
                    66: 114.4,
                    67: 121.3,
                    68: 130.7,
                    69: 142.4,
                    70: 156.1,
                    71: 171.4,
                    72: 187.8,
                    73: 204.1,
                    74: 218.5,
                    75: 229.7,
                    76: 236.2,
                    77: 237.4,
                    78: 232.9,
                    79: 222.3,
                    80: 205.7,
                    81: 185.5,
                    82: 164.7,
                    83: 146.4,
                    84: 132.6,
                    85: 123.0,
                    86: 116.3,
                    87: 111.2,
                    88: 106.6,
                    89: 102.1,
                    90: 97.6,
                    91: 92.6,
                    92: 87.2,
                    93: 81.6,
                    94: 76.5,
                    95: 72.3,
                },
                BDEWDAY.Workday: {
                    0: 72.4,
                    1: 69.4,
                    2: 66.9,
                    3: 64.8,
                    4: 63.2,
                    5: 61.9,
                    6: 61.0,
                    7: 60.2,
                    8: 59.6,
                    9: 59.2,
                    10: 58.8,
                    11: 58.4,
                    12: 57.9,
                    13: 57.4,
                    14: 56.9,
                    15: 56.5,
                    16: 56.3,
                    17: 56.3,
                    18: 56.6,
                    19: 57.4,
                    20: 58.8,
                    21: 60.9,
                    22: 63.8,
                    23: 67.6,
                    24: 72.5,
                    25: 79.0,
                    26: 87.7,
                    27: 99.1,
                    28: 113.6,
                    29: 130.5,
                    30: 148.9,
                    31: 167.7,
                    32: 185.8,
                    33: 201.7,
                    34: 213.6,
                    35: 219.5,
                    36: 218.5,
                    37: 211.6,
                    38: 200.8,
                    39: 188.0,
                    40: 175.0,
                    41: 163.4,
                    42: 154.5,
                    43: 150.1,
                    44: 150.7,
                    45: 154.1,
                    46: 157.4,
                    47: 157.5,
                    48: 152.2,
                    49: 143.2,
                    50: 132.7,
                    51: 123.2,
                    52: 116.5,
                    53: 112.5,
                    54: 110.3,
                    55: 109.3,
                    56: 108.8,
                    57: 108.5,
                    58: 108.4,
                    59: 108.4,
                    60: 108.3,
                    61: 108.3,
                    62: 108.6,
                    63: 109.3,
                    64: 110.6,
                    65: 113.1,
                    66: 117.4,
                    67: 124.1,
                    68: 133.7,
                    69: 146.0,
                    70: 160.5,
                    71: 176.9,
                    72: 194.5,
                    73: 211.5,
                    74: 226.1,
                    75: 236.2,
                    76: 240.4,
                    77: 238.7,
                    78: 231.5,
                    79: 219.5,
                    80: 203.4,
                    81: 184.9,
                    82: 166.1,
                    83: 149.1,
                    84: 135.6,
                    85: 125.2,
                    86: 117.3,
                    87: 111.2,
                    88: 106.1,
                    89: 101.7,
                    90: 97.7,
                    91: 93.6,
                    92: 89.1,
                    93: 84.6,
                    94: 80.1,
                    95: 76.0,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 67.2,
                    1: 65.6,
                    2: 64.3,
                    3: 63.0,
                    4: 61.4,
                    5: 59.7,
                    6: 58.0,
                    7: 56.5,
                    8: 55.2,
                    9: 54.2,
                    10: 53.4,
                    11: 52.8,
                    12: 52.3,
                    13: 51.8,
                    14: 51.4,
                    15: 50.9,
                    16: 50.5,
                    17: 50.2,
                    18: 50.0,
                    19: 50.0,
                    20: 50.3,
                    21: 50.9,
                    22: 51.7,
                    23: 52.8,
                    24: 54.4,
                    25: 57.2,
                    26: 62.2,
                    27: 70.4,
                    28: 82.4,
                    29: 97.4,
                    30: 114.2,
                    31: 131.5,
                    32: 148.2,
                    33: 162.8,
                    34: 173.8,
                    35: 179.7,
                    36: 179.6,
                    37: 174.9,
                    38: 167.2,
                    39: 158.4,
                    40: 150.1,
                    41: 143.4,
                    42: 139.1,
                    43: 138.0,
                    44: 140.4,
                    45: 144.4,
                    46: 147.5,
                    47: 147.3,
                    48: 142.0,
                    49: 133.1,
                    50: 122.7,
                    51: 113.0,
                    52: 105.7,
                    53: 100.6,
                    54: 96.8,
                    55: 93.6,
                    56: 90.3,
                    57: 87.1,
                    58: 84.4,
                    59: 82.4,
                    60: 81.5,
                    61: 81.3,
                    62: 81.4,
                    63: 81.5,
                    64: 81.3,
                    65: 81.3,
                    66: 81.8,
                    67: 83.4,
                    68: 86.6,
                    69: 91.7,
                    70: 99.2,
                    71: 109.3,
                    72: 122.1,
                    73: 135.8,
                    74: 148.6,
                    75: 158.4,
                    76: 163.6,
                    77: 164.4,
                    78: 161.5,
                    79: 155.6,
                    80: 147.4,
                    81: 137.8,
                    82: 127.9,
                    83: 118.6,
                    84: 110.7,
                    85: 104.1,
                    86: 98.5,
                    87: 93.6,
                    88: 88.9,
                    89: 84.6,
                    90: 80.6,
                    91: 76.9,
                    92: 73.4,
                    93: 70.3,
                    94: 67.4,
                    95: 64.8,
                },
                BDEWDAY.Sunday: {
                    0: 62.6,
                    1: 60.6,
                    2: 58.9,
                    3: 57.4,
                    4: 56.2,
                    5: 55.2,
                    6: 54.4,
                    7: 53.7,
                    8: 53.2,
                    9: 52.7,
                    10: 52.3,
                    11: 51.9,
                    12: 51.4,
                    13: 50.9,
                    14: 50.5,
                    15: 50.0,
                    16: 49.6,
                    17: 49.4,
                    18: 49.5,
                    19: 50.0,
                    20: 51.2,
                    21: 53.1,
                    22: 56.0,
                    23: 60.2,
                    24: 65.8,
                    25: 73.2,
                    26: 82.6,
                    27: 94.5,
                    28: 108.8,
                    29: 124.7,
                    30: 141.0,
                    31: 156.5,
                    32: 170.1,
                    33: 180.5,
                    34: 186.6,
                    35: 187.1,
                    36: 181.6,
                    37: 171.8,
                    38: 160.1,
                    39: 149.1,
                    40: 140.8,
                    41: 135.6,
                    42: 133.7,
                    43: 135.2,
                    44: 139.9,
                    45: 145.6,
                    46: 149.8,
                    47: 150.1,
                    48: 144.6,
                    49: 135.3,
                    50: 124.5,
                    51: 114.9,
                    52: 108.4,
                    53: 104.7,
                    54: 102.8,
                    55: 101.9,
                    56: 101.1,
                    57: 100.4,
                    58: 99.7,
                    59: 99.1,
                    60: 98.6,
                    61: 98.1,
                    62: 97.7,
                    63: 97.3,
                    64: 96.9,
                    65: 96.9,
                    66: 97.5,
                    67: 99.1,
                    68: 102.1,
                    69: 106.8,
                    70: 113.7,
                    71: 123.2,
                    72: 135.4,
                    73: 148.9,
                    74: 161.8,
                    75: 172.3,
                    76: 178.8,
                    77: 181.1,
                    78: 179.2,
                    79: 173.2,
                    80: 163.4,
                    81: 151.4,
                    82: 138.9,
                    83: 127.8,
                    84: 119.5,
                    85: 113.5,
                    86: 108.8,
                    87: 104.7,
                    88: 100.2,
                    89: 95.4,
                    90: 90.4,
                    91: 85.2,
                    92: 80.0,
                    93: 75.0,
                    94: 70.5,
                    95: 66.7,
                },
                BDEWDAY.Workday: {
                    0: 66.1,
                    1: 63.1,
                    2: 60.5,
                    3: 58.4,
                    4: 56.7,
                    5: 55.4,
                    6: 54.4,
                    7: 53.7,
                    8: 53.2,
                    9: 52.7,
                    10: 52.3,
                    11: 51.9,
                    12: 51.4,
                    13: 51.0,
                    14: 50.5,
                    15: 50.0,
                    16: 49.6,
                    17: 49.4,
                    18: 49.5,
                    19: 50.0,
                    20: 51.2,
                    21: 52.9,
                    22: 55.3,
                    23: 58.4,
                    24: 62.2,
                    25: 67.4,
                    26: 74.8,
                    27: 85.2,
                    28: 98.9,
                    29: 114.9,
                    30: 131.8,
                    31: 148.2,
                    32: 162.6,
                    33: 173.9,
                    34: 180.6,
                    35: 181.6,
                    36: 176.1,
                    37: 166.1,
                    38: 154.1,
                    39: 142.6,
                    40: 133.8,
                    41: 128.2,
                    42: 125.8,
                    43: 126.9,
                    44: 131.2,
                    45: 136.6,
                    46: 140.9,
                    47: 141.7,
                    48: 137.4,
                    49: 129.4,
                    50: 119.9,
                    51: 111.2,
                    52: 104.8,
                    53: 100.8,
                    54: 98.5,
                    55: 97.3,
                    56: 96.5,
                    57: 96.2,
                    58: 96.2,
                    59: 96.3,
                    60: 96.7,
                    61: 97.0,
                    62: 97.2,
                    63: 97.3,
                    64: 97.0,
                    65: 96.8,
                    66: 97.1,
                    67: 98.2,
                    68: 100.6,
                    69: 104.8,
                    70: 111.5,
                    71: 121.3,
                    72: 134.4,
                    73: 148.9,
                    74: 162.6,
                    75: 173.2,
                    76: 178.9,
                    77: 179.8,
                    78: 176.5,
                    79: 169.5,
                    80: 159.6,
                    81: 148.1,
                    82: 136.4,
                    83: 126.0,
                    84: 117.9,
                    85: 111.9,
                    86: 107.1,
                    87: 102.8,
                    88: 98.5,
                    89: 94.1,
                    90: 89.6,
                    91: 85.2,
                    92: 81.0,
                    93: 76.9,
                    94: 73.1,
                    95: 69.5,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 71.4,
                    1: 69.4,
                    2: 68.0,
                    3: 66.7,
                    4: 65.3,
                    5: 63.9,
                    6: 62.4,
                    7: 61.1,
                    8: 60.0,
                    9: 59.1,
                    10: 58.3,
                    11: 57.4,
                    12: 56.6,
                    13: 55.7,
                    14: 55.1,
                    15: 54.7,
                    16: 54.6,
                    17: 54.7,
                    18: 55.1,
                    19: 55.6,
                    20: 56.1,
                    21: 56.6,
                    22: 57.4,
                    23: 58.4,
                    24: 59.9,
                    25: 62.9,
                    26: 68.8,
                    27: 78.7,
                    28: 93.4,
                    29: 111.6,
                    30: 131.4,
                    31: 151.0,
                    32: 168.6,
                    33: 183.2,
                    34: 193.7,
                    35: 199.2,
                    36: 198.9,
                    37: 194.1,
                    38: 186.2,
                    39: 176.9,
                    40: 167.6,
                    41: 159.6,
                    42: 154.0,
                    43: 151.9,
                    44: 153.9,
                    45: 157.9,
                    46: 161.3,
                    47: 161.2,
                    48: 155.8,
                    49: 146.7,
                    50: 135.9,
                    51: 126.0,
                    52: 118.5,
                    53: 113.1,
                    54: 108.8,
                    55: 104.7,
                    56: 100.0,
                    57: 95.3,
                    58: 91.1,
                    59: 88.0,
                    60: 86.6,
                    61: 86.3,
                    62: 86.7,
                    63: 87.1,
                    64: 87.1,
                    65: 87.3,
                    66: 88.5,
                    67: 91.7,
                    68: 97.4,
                    69: 105.7,
                    70: 116.2,
                    71: 128.8,
                    72: 142.9,
                    73: 157.3,
                    74: 170.7,
                    75: 181.6,
                    76: 188.7,
                    77: 191.7,
                    78: 190.6,
                    79: 185.3,
                    80: 175.8,
                    81: 163.7,
                    82: 150.5,
                    83: 138.0,
                    84: 127.4,
                    85: 118.8,
                    86: 111.6,
                    87: 105.6,
                    88: 100.3,
                    89: 95.5,
                    90: 90.9,
                    91: 86.1,
                    92: 81.1,
                    93: 76.1,
                    94: 71.5,
                    95: 67.6,
                },
                BDEWDAY.Sunday: {
                    0: 64.8,
                    1: 62.7,
                    2: 61.3,
                    3: 60.2,
                    4: 59.2,
                    5: 58.2,
                    6: 57.3,
                    7: 56.5,
                    8: 55.8,
                    9: 55.3,
                    10: 54.9,
                    11: 54.7,
                    12: 54.6,
                    13: 54.6,
                    14: 54.7,
                    15: 54.7,
                    16: 54.5,
                    17: 54.3,
                    18: 54.3,
                    19: 54.7,
                    20: 55.5,
                    21: 57.3,
                    22: 60.3,
                    23: 64.8,
                    24: 71.3,
                    25: 79.8,
                    26: 90.6,
                    27: 103.7,
                    28: 119.3,
                    29: 136.3,
                    30: 153.8,
                    31: 170.4,
                    32: 185.3,
                    33: 197.0,
                    34: 204.6,
                    35: 206.6,
                    36: 202.4,
                    37: 193.4,
                    38: 181.5,
                    39: 168.6,
                    40: 156.5,
                    41: 146.4,
                    42: 139.6,
                    43: 137.1,
                    44: 139.4,
                    45: 144.3,
                    46: 148.8,
                    47: 150.1,
                    48: 146.0,
                    49: 138.1,
                    50: 128.5,
                    51: 119.5,
                    52: 112.9,
                    53: 108.6,
                    54: 105.7,
                    55: 103.7,
                    56: 102.0,
                    57: 100.5,
                    58: 99.2,
                    59: 98.2,
                    60: 97.4,
                    61: 96.7,
                    62: 96.1,
                    63: 95.4,
                    64: 94.7,
                    65: 94.5,
                    66: 95.8,
                    67: 99.1,
                    68: 105.2,
                    69: 114.0,
                    70: 125.3,
                    71: 138.9,
                    72: 154.5,
                    73: 170.3,
                    74: 184.6,
                    75: 195.4,
                    76: 201.4,
                    77: 202.7,
                    78: 199.9,
                    79: 193.6,
                    80: 184.4,
                    81: 173.4,
                    82: 161.6,
                    83: 150.1,
                    84: 139.6,
                    85: 130.3,
                    86: 122.1,
                    87: 114.9,
                    88: 108.4,
                    89: 102.5,
                    90: 97.0,
                    91: 91.7,
                    92: 86.4,
                    93: 81.2,
                    94: 76.4,
                    95: 72.3,
                },
                BDEWDAY.Workday: {
                    0: 70.3,
                    1: 67.1,
                    2: 64.3,
                    3: 62.1,
                    4: 60.3,
                    5: 59.1,
                    6: 58.1,
                    7: 57.4,
                    8: 56.9,
                    9: 56.4,
                    10: 56.0,
                    11: 55.6,
                    12: 55.1,
                    13: 54.5,
                    14: 54.1,
                    15: 53.7,
                    16: 53.6,
                    17: 53.7,
                    18: 54.0,
                    19: 54.7,
                    20: 55.6,
                    21: 57.2,
                    22: 59.8,
                    23: 63.9,
                    24: 69.8,
                    25: 77.6,
                    26: 87.6,
                    27: 100.0,
                    28: 114.8,
                    29: 131.3,
                    30: 148.6,
                    31: 165.8,
                    32: 181.9,
                    33: 195.1,
                    34: 203.4,
                    35: 204.7,
                    36: 198.0,
                    37: 185.5,
                    38: 170.6,
                    39: 156.5,
                    40: 145.9,
                    41: 139.0,
                    42: 135.5,
                    43: 135.2,
                    44: 137.5,
                    45: 140.7,
                    46: 143.1,
                    47: 142.6,
                    48: 138.2,
                    49: 130.9,
                    50: 122.5,
                    51: 114.9,
                    52: 109.4,
                    53: 105.9,
                    54: 103.9,
                    55: 102.8,
                    56: 102.1,
                    57: 101.7,
                    58: 101.4,
                    59: 101.0,
                    60: 100.4,
                    61: 99.9,
                    62: 99.4,
                    63: 99.1,
                    64: 99.2,
                    65: 99.9,
                    66: 101.6,
                    67: 104.7,
                    68: 109.4,
                    69: 116.2,
                    70: 125.6,
                    71: 138.0,
                    72: 153.5,
                    73: 170.2,
                    74: 185.8,
                    75: 198.2,
                    76: 205.5,
                    77: 207.5,
                    78: 204.7,
                    79: 197.3,
                    80: 185.9,
                    81: 172.1,
                    82: 157.7,
                    83: 144.5,
                    84: 133.8,
                    85: 125.5,
                    86: 118.8,
                    87: 113.0,
                    88: 107.7,
                    89: 102.5,
                    90: 97.6,
                    91: 92.6,
                    92: 87.7,
                    93: 82.9,
                    94: 78.3,
                    95: 74.1,
                },
            },
        }
        self.L1: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 67.9,
                    1: 67.6,
                    2: 67.8,
                    3: 67.8,
                    4: 67.3,
                    5: 66.5,
                    6: 65.4,
                    7: 64.3,
                    8: 63.2,
                    9: 62.3,
                    10: 61.5,
                    11: 60.8,
                    12: 60.1,
                    13: 59.5,
                    14: 59.0,
                    15: 58.4,
                    16: 57.8,
                    17: 57.3,
                    18: 57.1,
                    19: 57.2,
                    20: 58.0,
                    21: 59.3,
                    22: 61.4,
                    23: 64.3,
                    24: 68.2,
                    25: 74.7,
                    26: 85.3,
                    27: 101.6,
                    28: 124.9,
                    29: 153.4,
                    30: 185.3,
                    31: 218.5,
                    32: 250.4,
                    33: 276.9,
                    34: 293.5,
                    35: 295.6,
                    36: 280.5,
                    37: 252.9,
                    38: 219.2,
                    39: 185.8,
                    40: 158.0,
                    41: 137.3,
                    42: 123.9,
                    43: 118.0,
                    44: 119.2,
                    45: 124.5,
                    46: 130.0,
                    47: 132.0,
                    48: 127.8,
                    49: 119.2,
                    50: 109.1,
                    51: 100.5,
                    52: 95.5,
                    53: 93.4,
                    54: 92.8,
                    55: 92.3,
                    56: 90.7,
                    57: 88.2,
                    58: 85.5,
                    59: 83.0,
                    60: 81.1,
                    61: 79.9,
                    62: 79.4,
                    63: 79.4,
                    64: 80.1,
                    65: 81.5,
                    66: 84.3,
                    67: 88.8,
                    68: 95.7,
                    69: 106.9,
                    70: 124.9,
                    71: 151.9,
                    72: 188.6,
                    73: 229.1,
                    74: 266.1,
                    75: 292.1,
                    76: 301.4,
                    77: 295.6,
                    78: 278.1,
                    79: 252.4,
                    80: 221.6,
                    81: 189.2,
                    82: 158.2,
                    83: 132.0,
                    84: 113.0,
                    85: 100.3,
                    86: 92.4,
                    87: 87.6,
                    88: 84.6,
                    89: 82.4,
                    90: 80.5,
                    91: 78.3,
                    92: 75.3,
                    93: 71.8,
                    94: 68.3,
                    95: 65.4,
                },
                BDEWDAY.Sunday: {
                    0: 63.5,
                    1: 62.2,
                    2: 61.4,
                    3: 60.8,
                    4: 59.9,
                    5: 59.0,
                    6: 58.1,
                    7: 57.2,
                    8: 56.7,
                    9: 56.3,
                    10: 56.1,
                    11: 56.1,
                    12: 56.2,
                    13: 56.3,
                    14: 56.3,
                    15: 56.1,
                    16: 55.5,
                    17: 54.9,
                    18: 54.6,
                    19: 54.9,
                    20: 56.1,
                    21: 58.6,
                    22: 62.8,
                    23: 68.9,
                    24: 77.5,
                    25: 89.2,
                    26: 104.8,
                    27: 125.0,
                    28: 150.1,
                    29: 178.5,
                    30: 208.2,
                    31: 237.2,
                    32: 263.0,
                    33: 282.1,
                    34: 290.8,
                    35: 285.1,
                    36: 263.1,
                    37: 230.4,
                    38: 194.8,
                    39: 163.6,
                    40: 142.8,
                    41: 131.8,
                    42: 128.2,
                    43: 129.7,
                    44: 134.0,
                    45: 138.9,
                    46: 142.1,
                    47: 141.4,
                    48: 135.2,
                    49: 125.4,
                    50: 114.6,
                    51: 105.1,
                    52: 99.2,
                    53: 96.4,
                    54: 95.9,
                    55: 97.0,
                    56: 98.7,
                    57: 100.7,
                    58: 102.6,
                    59: 104.0,
                    60: 104.6,
                    61: 104.8,
                    62: 104.9,
                    63: 105.1,
                    64: 106.1,
                    65: 107.9,
                    66: 111.0,
                    67: 115.7,
                    68: 122.5,
                    69: 133.2,
                    70: 149.7,
                    71: 174.1,
                    72: 206.9,
                    73: 242.9,
                    74: 275.4,
                    75: 297.9,
                    76: 305.2,
                    77: 298.6,
                    78: 280.8,
                    79: 254.7,
                    80: 223.1,
                    81: 189.7,
                    82: 158.1,
                    83: 132.0,
                    84: 114.3,
                    85: 103.5,
                    86: 97.3,
                    87: 93.5,
                    88: 90.0,
                    89: 86.6,
                    90: 83.0,
                    91: 79.4,
                    92: 75.8,
                    93: 72.3,
                    94: 69.1,
                    95: 66.6,
                },
                BDEWDAY.Workday: {
                    0: 66.7,
                    1: 64.8,
                    2: 63.2,
                    3: 61.9,
                    4: 60.8,
                    5: 59.8,
                    6: 59.0,
                    7: 58.4,
                    8: 58.0,
                    9: 57.7,
                    10: 57.5,
                    11: 57.2,
                    12: 57.0,
                    13: 56.7,
                    14: 56.4,
                    15: 56.1,
                    16: 55.7,
                    17: 55.5,
                    18: 55.6,
                    19: 56.1,
                    20: 57.2,
                    21: 59.4,
                    22: 62.7,
                    23: 67.8,
                    24: 74.8,
                    25: 84.9,
                    26: 98.9,
                    27: 118.0,
                    28: 142.5,
                    29: 170.9,
                    30: 200.8,
                    31: 230.2,
                    32: 256.4,
                    33: 276.3,
                    34: 286.3,
                    35: 282.7,
                    36: 263.8,
                    37: 234.4,
                    38: 201.1,
                    39: 170.6,
                    40: 148.1,
                    41: 133.7,
                    42: 126.0,
                    43: 123.8,
                    44: 125.7,
                    45: 129.3,
                    46: 132.2,
                    47: 132.0,
                    48: 127.0,
                    49: 118.8,
                    50: 109.6,
                    51: 101.6,
                    52: 96.8,
                    53: 94.6,
                    54: 94.2,
                    55: 94.6,
                    56: 95.1,
                    57: 95.5,
                    58: 95.7,
                    59: 95.8,
                    60: 95.8,
                    61: 95.8,
                    62: 96.1,
                    63: 97.0,
                    64: 98.5,
                    65: 101.2,
                    66: 105.2,
                    67: 111.0,
                    68: 119.1,
                    69: 131.1,
                    70: 148.8,
                    71: 174.1,
                    72: 207.3,
                    73: 243.1,
                    74: 274.4,
                    75: 294.4,
                    76: 298.0,
                    77: 287.5,
                    78: 267.1,
                    79: 240.7,
                    80: 212.2,
                    81: 183.8,
                    82: 157.6,
                    83: 135.5,
                    84: 118.9,
                    85: 107.2,
                    86: 99.1,
                    87: 93.5,
                    88: 89.3,
                    89: 86.1,
                    90: 83.3,
                    91: 80.6,
                    92: 77.7,
                    93: 74.6,
                    94: 71.6,
                    95: 68.9,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 58.2,
                    1: 57.3,
                    2: 56.7,
                    3: 56.1,
                    4: 55.2,
                    5: 54.2,
                    6: 53.3,
                    7: 52.6,
                    8: 52.2,
                    9: 52.0,
                    10: 51.8,
                    11: 51.4,
                    12: 50.7,
                    13: 49.7,
                    14: 48.7,
                    15: 47.9,
                    16: 47.4,
                    17: 47.3,
                    18: 47.5,
                    19: 47.9,
                    20: 48.5,
                    21: 49.3,
                    22: 50.3,
                    23: 51.4,
                    24: 53.1,
                    25: 57.1,
                    26: 66.0,
                    27: 81.8,
                    28: 105.9,
                    29: 135.6,
                    30: 167.0,
                    31: 196.3,
                    32: 220.0,
                    33: 235.9,
                    34: 241.9,
                    35: 236.0,
                    36: 217.4,
                    37: 190.6,
                    38: 161.4,
                    39: 135.5,
                    40: 117.5,
                    41: 107.1,
                    42: 102.7,
                    43: 102.8,
                    44: 105.9,
                    45: 109.8,
                    46: 112.6,
                    47: 112.2,
                    48: 107.1,
                    49: 98.8,
                    50: 89.7,
                    51: 81.8,
                    52: 76.8,
                    53: 74.3,
                    54: 73.2,
                    55: 72.4,
                    56: 71.2,
                    57: 69.7,
                    58: 68.0,
                    59: 66.6,
                    60: 65.6,
                    61: 65.0,
                    62: 64.6,
                    63: 64.3,
                    64: 63.9,
                    65: 63.8,
                    66: 64.2,
                    67: 65.4,
                    68: 68.1,
                    69: 74.2,
                    70: 85.8,
                    71: 105.1,
                    72: 133.1,
                    73: 164.7,
                    74: 193.7,
                    75: 213.8,
                    76: 220.4,
                    77: 215.3,
                    78: 201.8,
                    79: 183.4,
                    80: 163.1,
                    81: 142.7,
                    82: 123.7,
                    83: 107.5,
                    84: 95.2,
                    85: 86.4,
                    86: 80.2,
                    87: 75.9,
                    88: 72.7,
                    89: 70.2,
                    90: 67.9,
                    91: 65.4,
                    92: 62.6,
                    93: 59.6,
                    94: 57.0,
                    95: 54.9,
                },
                BDEWDAY.Sunday: {
                    0: 53.8,
                    1: 53.3,
                    2: 53.0,
                    3: 52.6,
                    4: 51.7,
                    5: 50.6,
                    6: 49.6,
                    7: 49.1,
                    8: 49.1,
                    9: 49.6,
                    10: 50.1,
                    11: 50.2,
                    12: 49.8,
                    13: 48.9,
                    14: 47.8,
                    15: 46.7,
                    16: 46.0,
                    17: 45.6,
                    18: 45.8,
                    19: 46.7,
                    20: 48.5,
                    21: 51.1,
                    22: 54.8,
                    23: 59.6,
                    24: 65.8,
                    25: 75.1,
                    26: 89.1,
                    27: 109.8,
                    28: 137.8,
                    29: 169.2,
                    30: 198.9,
                    31: 222.0,
                    32: 234.3,
                    33: 236.2,
                    34: 229.0,
                    35: 213.8,
                    36: 192.5,
                    37: 168.3,
                    38: 144.9,
                    39: 126.2,
                    40: 114.8,
                    41: 109.9,
                    42: 109.6,
                    43: 112.2,
                    44: 115.9,
                    45: 119.3,
                    46: 121.2,
                    47: 120.3,
                    48: 115.9,
                    49: 108.9,
                    50: 100.9,
                    51: 93.5,
                    52: 87.9,
                    53: 84.2,
                    54: 82.3,
                    55: 81.8,
                    56: 82.5,
                    57: 84.0,
                    58: 85.5,
                    59: 86.5,
                    60: 86.5,
                    61: 85.8,
                    62: 84.8,
                    63: 84.1,
                    64: 83.9,
                    65: 84.1,
                    66: 84.2,
                    67: 84.1,
                    68: 84.0,
                    69: 86.4,
                    70: 94.8,
                    71: 112.2,
                    72: 140.2,
                    73: 173.4,
                    74: 205.0,
                    75: 227.8,
                    76: 236.6,
                    77: 232.9,
                    78: 219.9,
                    79: 201.0,
                    80: 179.1,
                    81: 156.5,
                    82: 135.1,
                    83: 116.8,
                    84: 103.2,
                    85: 93.5,
                    86: 86.7,
                    87: 81.8,
                    88: 77.7,
                    89: 74.1,
                    90: 70.9,
                    91: 67.8,
                    92: 64.7,
                    93: 61.8,
                    94: 59.2,
                    95: 57.2,
                },
                BDEWDAY.Workday: {
                    0: 57.7,
                    1: 56.2,
                    2: 54.9,
                    3: 53.7,
                    4: 52.6,
                    5: 51.6,
                    6: 50.8,
                    7: 50.2,
                    8: 50.1,
                    9: 50.2,
                    10: 50.3,
                    11: 50.2,
                    12: 49.9,
                    13: 49.2,
                    14: 48.5,
                    15: 47.9,
                    16: 47.4,
                    17: 47.2,
                    18: 47.4,
                    19: 47.9,
                    20: 48.9,
                    21: 50.7,
                    22: 53.4,
                    23: 57.2,
                    24: 62.8,
                    25: 71.2,
                    26: 84.0,
                    27: 102.8,
                    28: 128.1,
                    29: 156.9,
                    30: 185.2,
                    31: 209.1,
                    32: 225.3,
                    33: 232.6,
                    34: 230.9,
                    35: 219.6,
                    36: 199.4,
                    37: 174.1,
                    38: 148.5,
                    39: 127.3,
                    40: 114.4,
                    41: 108.7,
                    42: 108.3,
                    43: 111.0,
                    44: 115.0,
                    45: 118.7,
                    46: 121.0,
                    47: 120.3,
                    48: 116.0,
                    49: 109.0,
                    50: 100.9,
                    51: 93.5,
                    52: 87.9,
                    53: 84.2,
                    54: 82.2,
                    55: 81.8,
                    56: 82.5,
                    57: 83.9,
                    58: 85.5,
                    59: 86.5,
                    60: 86.5,
                    61: 85.9,
                    62: 85.0,
                    63: 84.1,
                    64: 83.7,
                    65: 83.5,
                    66: 83.3,
                    67: 83.0,
                    68: 82.8,
                    69: 85.7,
                    70: 95.1,
                    71: 114.5,
                    72: 145.3,
                    73: 181.1,
                    74: 213.8,
                    75: 234.8,
                    76: 238.4,
                    77: 227.6,
                    78: 208.2,
                    79: 185.8,
                    80: 164.9,
                    81: 146.5,
                    82: 130.5,
                    83: 116.8,
                    84: 105.4,
                    85: 96.1,
                    86: 88.7,
                    87: 83.0,
                    88: 78.6,
                    89: 75.3,
                    90: 72.6,
                    91: 70.1,
                    92: 67.4,
                    93: 64.6,
                    94: 61.9,
                    95: 59.6,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 64.9,
                    1: 63.8,
                    2: 62.9,
                    3: 61.9,
                    4: 60.6,
                    5: 59.1,
                    6: 57.9,
                    7: 57.2,
                    8: 57.4,
                    9: 58.0,
                    10: 58.5,
                    11: 58.4,
                    12: 57.5,
                    13: 55.9,
                    14: 54.1,
                    15: 52.6,
                    16: 51.6,
                    17: 51.1,
                    18: 51.1,
                    19: 51.4,
                    20: 52.1,
                    21: 53.1,
                    22: 54.8,
                    23: 57.2,
                    24: 60.8,
                    25: 67.0,
                    26: 77.3,
                    27: 93.5,
                    28: 116.4,
                    29: 144.2,
                    30: 174.4,
                    31: 204.5,
                    32: 231.5,
                    33: 252.2,
                    34: 262.7,
                    35: 259.4,
                    36: 240.3,
                    37: 210.7,
                    38: 177.8,
                    39: 148.4,
                    40: 128.2,
                    41: 116.7,
                    42: 112.0,
                    43: 112.2,
                    44: 115.3,
                    45: 119.2,
                    46: 122.0,
                    47: 121.5,
                    48: 116.4,
                    49: 108.1,
                    50: 98.9,
                    51: 91.1,
                    52: 86.4,
                    53: 84.0,
                    54: 82.9,
                    55: 81.8,
                    56: 79.8,
                    57: 77.4,
                    58: 75.1,
                    59: 73.6,
                    60: 73.4,
                    61: 74.1,
                    62: 75.2,
                    63: 75.9,
                    64: 76.1,
                    65: 76.1,
                    66: 77.0,
                    67: 79.4,
                    68: 84.5,
                    69: 93.6,
                    70: 108.5,
                    71: 130.9,
                    72: 161.0,
                    73: 194.2,
                    74: 224.4,
                    75: 245.3,
                    76: 252.6,
                    77: 247.7,
                    78: 233.7,
                    79: 213.8,
                    80: 190.8,
                    81: 167.0,
                    82: 144.4,
                    83: 125.0,
                    84: 110.4,
                    85: 99.9,
                    86: 92.7,
                    87: 87.6,
                    88: 83.8,
                    89: 80.6,
                    90: 77.8,
                    91: 74.8,
                    92: 71.3,
                    93: 67.8,
                    94: 64.5,
                    95: 61.9,
                },
                BDEWDAY.Sunday: {
                    0: 60.4,
                    1: 59.6,
                    2: 59.1,
                    3: 58.4,
                    4: 57.3,
                    5: 56.1,
                    6: 55.1,
                    7: 54.9,
                    8: 55.7,
                    9: 57.0,
                    10: 58.1,
                    11: 58.4,
                    12: 57.4,
                    13: 55.5,
                    14: 53.3,
                    15: 51.4,
                    16: 50.4,
                    17: 50.3,
                    18: 51.0,
                    19: 52.6,
                    20: 54.9,
                    21: 58.1,
                    22: 62.4,
                    23: 67.8,
                    24: 74.7,
                    25: 84.4,
                    26: 98.3,
                    27: 118.0,
                    28: 144.0,
                    29: 173.6,
                    30: 203.1,
                    31: 229.0,
                    32: 248.0,
                    33: 258.5,
                    34: 259.2,
                    35: 248.9,
                    36: 227.3,
                    37: 198.8,
                    38: 169.1,
                    39: 143.7,
                    40: 126.8,
                    41: 117.8,
                    42: 114.7,
                    43: 115.7,
                    44: 118.7,
                    45: 122.2,
                    46: 124.5,
                    47: 123.8,
                    48: 119.2,
                    49: 111.8,
                    50: 103.4,
                    51: 95.8,
                    52: 90.5,
                    53: 87.3,
                    54: 85.8,
                    55: 85.3,
                    56: 85.4,
                    57: 85.8,
                    58: 86.2,
                    59: 86.5,
                    60: 86.3,
                    61: 85.8,
                    62: 85.0,
                    63: 84.1,
                    64: 83.2,
                    65: 82.6,
                    66: 82.8,
                    67: 84.1,
                    68: 87.4,
                    69: 94.7,
                    70: 108.4,
                    71: 130.9,
                    72: 162.9,
                    73: 198.9,
                    74: 231.9,
                    75: 254.7,
                    76: 262.0,
                    77: 256.0,
                    78: 240.6,
                    79: 219.6,
                    80: 196.8,
                    81: 173.8,
                    82: 152.2,
                    83: 133.2,
                    84: 118.0,
                    85: 106.3,
                    86: 97.5,
                    87: 91.1,
                    88: 86.5,
                    89: 83.0,
                    90: 80.0,
                    91: 77.1,
                    92: 73.8,
                    93: 70.3,
                    94: 67.0,
                    95: 64.3,
                },
                BDEWDAY.Workday: {
                    0: 64.4,
                    1: 62.6,
                    2: 61.0,
                    3: 59.6,
                    4: 58.2,
                    5: 57.0,
                    6: 56.2,
                    7: 56.1,
                    8: 56.7,
                    9: 57.6,
                    10: 58.3,
                    11: 58.4,
                    12: 57.5,
                    13: 55.9,
                    14: 54.1,
                    15: 52.6,
                    16: 51.7,
                    17: 51.5,
                    18: 51.8,
                    19: 52.6,
                    20: 53.8,
                    21: 55.9,
                    22: 59.2,
                    23: 64.3,
                    24: 71.5,
                    25: 81.9,
                    26: 96.3,
                    27: 115.7,
                    28: 140.3,
                    29: 168.1,
                    30: 196.6,
                    31: 223.1,
                    32: 245.1,
                    33: 259.7,
                    34: 264.2,
                    35: 255.9,
                    36: 233.6,
                    37: 202.5,
                    38: 169.5,
                    39: 141.4,
                    40: 123.3,
                    41: 114.3,
                    42: 111.8,
                    43: 113.3,
                    44: 116.5,
                    45: 119.6,
                    46: 121.4,
                    47: 120.3,
                    48: 115.6,
                    49: 108.4,
                    50: 100.4,
                    51: 93.5,
                    52: 88.9,
                    53: 86.4,
                    54: 85.4,
                    55: 85.3,
                    56: 85.5,
                    57: 85.9,
                    58: 86.3,
                    59: 86.5,
                    60: 86.3,
                    61: 86.0,
                    62: 85.6,
                    63: 85.3,
                    64: 85.2,
                    65: 85.4,
                    66: 86.2,
                    67: 87.6,
                    68: 90.3,
                    69: 96.6,
                    70: 109.2,
                    71: 130.9,
                    72: 162.7,
                    73: 198.8,
                    74: 232.0,
                    75: 254.7,
                    76: 261.4,
                    77: 254.4,
                    78: 237.9,
                    79: 216.1,
                    80: 192.7,
                    81: 169.6,
                    82: 148.1,
                    83: 129.7,
                    84: 115.3,
                    85: 104.6,
                    86: 96.8,
                    87: 91.1,
                    88: 86.9,
                    89: 83.7,
                    90: 80.9,
                    91: 78.3,
                    92: 75.3,
                    93: 72.3,
                    94: 69.3,
                    95: 66.6,
                },
            },
        }
        self.L2: dict[Season, dict[BDEWDAY, dict[int, float]]] = {
            Season.Winter: {
                BDEWDAY.Saturday: {
                    0: 77.1,
                    1: 76.3,
                    2: 76.1,
                    3: 75.8,
                    4: 75.0,
                    5: 73.7,
                    6: 72.0,
                    7: 70.1,
                    8: 68.1,
                    9: 66.2,
                    10: 64.3,
                    11: 62.7,
                    12: 61.2,
                    13: 60.0,
                    14: 59.1,
                    15: 58.5,
                    16: 58.3,
                    17: 58.3,
                    18: 58.7,
                    19: 59.4,
                    20: 60.3,
                    21: 61.3,
                    22: 62.4,
                    23: 63.5,
                    24: 64.5,
                    25: 66.2,
                    26: 69.1,
                    27: 74.2,
                    28: 81.9,
                    29: 91.7,
                    30: 103.1,
                    31: 115.4,
                    32: 128.1,
                    33: 141.0,
                    34: 154.1,
                    35: 167.3,
                    36: 180.5,
                    37: 192.1,
                    38: 200.6,
                    39: 204.4,
                    40: 202.7,
                    41: 197.5,
                    42: 191.6,
                    43: 188.0,
                    44: 188.4,
                    45: 191.0,
                    46: 192.6,
                    47: 190.4,
                    48: 182.3,
                    49: 170.0,
                    50: 156.2,
                    51: 143.4,
                    52: 133.8,
                    53: 126.8,
                    54: 121.3,
                    55: 116.2,
                    56: 110.8,
                    57: 105.3,
                    58: 100.3,
                    59: 96.5,
                    60: 94.1,
                    61: 92.9,
                    62: 92.5,
                    63: 92.3,
                    64: 92.2,
                    65: 92.8,
                    66: 95.3,
                    67: 100.6,
                    68: 109.4,
                    69: 120.6,
                    70: 132.7,
                    71: 144.3,
                    72: 154.1,
                    73: 162.7,
                    74: 170.7,
                    75: 178.9,
                    76: 187.5,
                    77: 194.8,
                    78: 198.7,
                    79: 197.0,
                    80: 188.4,
                    81: 175.1,
                    82: 159.9,
                    83: 145.9,
                    84: 135.4,
                    85: 127.9,
                    86: 122.1,
                    87: 117.1,
                    88: 111.7,
                    89: 105.9,
                    90: 100.0,
                    91: 94.0,
                    92: 88.1,
                    93: 82.6,
                    94: 77.6,
                    95: 73.4,
                },
                BDEWDAY.Sunday: {
                    0: 70.0,
                    1: 67.4,
                    2: 65.6,
                    3: 64.3,
                    4: 63.5,
                    5: 62.9,
                    6: 62.4,
                    7: 61.8,
                    8: 61.0,
                    9: 60.1,
                    10: 59.2,
                    11: 58.5,
                    12: 58.1,
                    13: 57.9,
                    14: 57.8,
                    15: 57.7,
                    16: 57.5,
                    17: 57.3,
                    18: 57.6,
                    19: 58.5,
                    20: 60.4,
                    21: 63.3,
                    22: 67.4,
                    23: 72.5,
                    24: 78.9,
                    25: 86.5,
                    26: 95.1,
                    27: 104.7,
                    28: 115.2,
                    29: 126.5,
                    30: 138.4,
                    31: 150.9,
                    32: 163.6,
                    33: 175.8,
                    34: 186.7,
                    35: 195.4,
                    36: 201.1,
                    37: 203.4,
                    38: 202.2,
                    39: 197.0,
                    40: 188.2,
                    41: 177.8,
                    42: 168.6,
                    43: 163.2,
                    44: 163.3,
                    45: 166.6,
                    46: 169.8,
                    47: 169.8,
                    48: 164.3,
                    49: 154.8,
                    50: 144.3,
                    51: 135.2,
                    52: 129.7,
                    53: 126.9,
                    54: 125.7,
                    55: 124.5,
                    56: 122.3,
                    57: 119.3,
                    58: 116.1,
                    59: 112.9,
                    60: 110.4,
                    61: 108.7,
                    62: 107.8,
                    63: 108.0,
                    64: 109.4,
                    65: 112.3,
                    66: 117.2,
                    67: 124.5,
                    68: 134.2,
                    69: 145.6,
                    70: 157.5,
                    71: 169.0,
                    72: 179.1,
                    73: 187.9,
                    74: 195.5,
                    75: 202.0,
                    76: 207.3,
                    77: 210.5,
                    78: 210.3,
                    79: 205.3,
                    80: 194.8,
                    81: 180.7,
                    82: 165.3,
                    83: 150.9,
                    84: 139.3,
                    85: 130.4,
                    86: 123.5,
                    87: 117.9,
                    88: 113.0,
                    89: 108.3,
                    90: 103.4,
                    91: 98.1,
                    92: 92.0,
                    93: 85.8,
                    94: 79.9,
                    95: 75.0,
                },
                BDEWDAY.Workday: {
                    0: 75.2,
                    1: 71.9,
                    2: 69.1,
                    3: 66.8,
                    4: 64.8,
                    5: 63.2,
                    6: 61.9,
                    7: 61.0,
                    8: 60.4,
                    9: 59.9,
                    10: 59.6,
                    11: 59.4,
                    12: 59.0,
                    13: 58.7,
                    14: 58.2,
                    15: 57.7,
                    16: 57.1,
                    17: 56.7,
                    18: 56.8,
                    19: 57.7,
                    20: 59.6,
                    21: 62.3,
                    22: 65.9,
                    23: 70.1,
                    24: 74.8,
                    25: 80.4,
                    26: 87.2,
                    27: 95.6,
                    28: 105.8,
                    29: 117.4,
                    30: 129.8,
                    31: 142.6,
                    32: 155.2,
                    33: 167.0,
                    34: 177.3,
                    35: 185.5,
                    36: 191.0,
                    37: 193.5,
                    38: 192.6,
                    39: 188.0,
                    40: 179.8,
                    41: 170.3,
                    42: 161.9,
                    43: 157.5,
                    44: 158.4,
                    45: 162.6,
                    46: 166.7,
                    47: 167.3,
                    48: 162.3,
                    49: 153.2,
                    50: 142.5,
                    51: 132.7,
                    52: 125.9,
                    53: 121.6,
                    54: 119.3,
                    55: 117.9,
                    56: 116.9,
                    57: 116.1,
                    58: 115.6,
                    59: 115.4,
                    60: 115.6,
                    61: 116.0,
                    62: 116.5,
                    63: 117.1,
                    64: 117.6,
                    65: 119.1,
                    66: 122.4,
                    67: 128.6,
                    68: 138.3,
                    69: 150.4,
                    70: 163.6,
                    71: 176.4,
                    72: 187.8,
                    73: 197.2,
                    74: 204.8,
                    75: 210.2,
                    76: 213.4,
                    77: 213.8,
                    78: 211.0,
                    79: 204.4,
                    80: 193.9,
                    81: 180.8,
                    82: 166.7,
                    83: 153.3,
                    84: 142.0,
                    85: 132.7,
                    86: 125.1,
                    87: 118.7,
                    88: 113.2,
                    89: 108.3,
                    90: 103.7,
                    91: 98.9,
                    92: 93.9,
                    93: 88.7,
                    94: 83.7,
                    95: 79.1,
                },
            },
            Season.Summer: {
                BDEWDAY.Saturday: {
                    0: 70.9,
                    1: 69.3,
                    2: 68.0,
                    3: 66.8,
                    4: 65.1,
                    5: 63.1,
                    6: 61.2,
                    7: 59.4,
                    8: 57.9,
                    9: 56.8,
                    10: 56.0,
                    11: 55.2,
                    12: 54.5,
                    13: 53.9,
                    14: 53.3,
                    15: 52.8,
                    16: 52.4,
                    17: 52.1,
                    18: 51.9,
                    19: 51.9,
                    20: 52.1,
                    21: 52.6,
                    22: 53.3,
                    23: 54.4,
                    24: 56.0,
                    25: 58.4,
                    26: 62.2,
                    27: 67.6,
                    28: 75.1,
                    29: 84.4,
                    30: 95.2,
                    31: 107.2,
                    32: 119.9,
                    33: 132.7,
                    34: 144.4,
                    35: 154.2,
                    36: 161.2,
                    37: 165.5,
                    38: 167.0,
                    39: 165.7,
                    40: 162.0,
                    41: 157.3,
                    42: 153.6,
                    43: 152.5,
                    44: 155.2,
                    45: 159.6,
                    46: 163.2,
                    47: 163.2,
                    48: 157.8,
                    49: 148.5,
                    50: 137.4,
                    51: 127.0,
                    52: 118.8,
                    53: 112.8,
                    54: 108.0,
                    55: 103.9,
                    56: 99.7,
                    57: 95.8,
                    58: 92.4,
                    59: 89.9,
                    60: 88.5,
                    61: 88.0,
                    62: 88.1,
                    63: 88.2,
                    64: 88.2,
                    65: 88.3,
                    66: 89.0,
                    67: 90.7,
                    68: 93.7,
                    69: 98.0,
                    70: 103.3,
                    71: 109.6,
                    72: 116.7,
                    73: 123.8,
                    74: 130.5,
                    75: 136.0,
                    76: 139.9,
                    77: 142.0,
                    78: 142.3,
                    79: 141.0,
                    80: 138.0,
                    81: 133.7,
                    82: 128.5,
                    83: 122.8,
                    84: 116.9,
                    85: 111.0,
                    86: 105.2,
                    87: 99.7,
                    88: 94.7,
                    89: 90.0,
                    90: 85.6,
                    91: 81.6,
                    92: 77.9,
                    93: 74.4,
                    94: 71.3,
                    95: 68.4,
                },
                BDEWDAY.Sunday: {
                    0: 65.9,
                    1: 63.7,
                    2: 61.8,
                    3: 60.2,
                    4: 58.8,
                    5: 57.7,
                    6: 56.7,
                    7: 56.1,
                    8: 55.6,
                    9: 55.2,
                    10: 54.9,
                    11: 54.4,
                    12: 53.8,
                    13: 53.1,
                    14: 52.5,
                    15: 51.9,
                    16: 51.6,
                    17: 51.6,
                    18: 52.0,
                    19: 52.8,
                    20: 54.1,
                    21: 56.1,
                    22: 59.1,
                    23: 63.5,
                    24: 69.3,
                    25: 76.3,
                    26: 84.4,
                    27: 93.2,
                    28: 102.5,
                    29: 112.3,
                    30: 122.6,
                    31: 133.5,
                    32: 144.9,
                    33: 155.5,
                    34: 164.0,
                    35: 169.0,
                    36: 169.6,
                    37: 166.7,
                    38: 161.4,
                    39: 155.0,
                    40: 148.7,
                    41: 143.8,
                    42: 141.3,
                    43: 142.6,
                    44: 148.1,
                    45: 155.2,
                    46: 161.1,
                    47: 162.4,
                    48: 157.1,
                    49: 147.2,
                    50: 135.6,
                    51: 125.3,
                    52: 118.6,
                    53: 114.9,
                    54: 113.1,
                    55: 112.1,
                    56: 110.9,
                    57: 109.5,
                    58: 108.2,
                    59: 107.2,
                    60: 106.6,
                    61: 106.3,
                    62: 106.0,
                    63: 105.5,
                    64: 104.6,
                    65: 104.0,
                    66: 104.3,
                    67: 106.3,
                    68: 110.6,
                    69: 116.5,
                    70: 123.3,
                    71: 130.3,
                    72: 136.6,
                    73: 142.4,
                    74: 147.6,
                    75: 152.5,
                    76: 156.9,
                    77: 160.2,
                    78: 161.5,
                    79: 159.9,
                    80: 155.1,
                    81: 148.0,
                    82: 140.1,
                    83: 132.7,
                    84: 127.0,
                    85: 122.6,
                    86: 118.7,
                    87: 114.6,
                    88: 109.6,
                    89: 103.9,
                    90: 97.8,
                    91: 91.5,
                    92: 85.3,
                    93: 79.5,
                    94: 74.3,
                    95: 70.1,
                },
                BDEWDAY.Workday: {
                    0: 69.7,
                    1: 66.6,
                    2: 63.9,
                    3: 61.8,
                    4: 60.2,
                    5: 58.9,
                    6: 57.8,
                    7: 56.9,
                    8: 56.0,
                    9: 55.1,
                    10: 54.3,
                    11: 53.6,
                    12: 53.1,
                    13: 52.7,
                    14: 52.3,
                    15: 51.9,
                    16: 51.5,
                    17: 51.3,
                    18: 51.3,
                    19: 51.9,
                    20: 53.2,
                    21: 55.2,
                    22: 57.8,
                    23: 61.0,
                    24: 64.8,
                    25: 69.4,
                    26: 75.2,
                    27: 82.4,
                    28: 91.3,
                    29: 101.6,
                    30: 112.8,
                    31: 124.5,
                    32: 136.1,
                    33: 146.7,
                    34: 155.0,
                    35: 159.9,
                    36: 160.6,
                    37: 157.8,
                    38: 152.8,
                    39: 146.7,
                    40: 140.7,
                    41: 135.9,
                    42: 133.5,
                    43: 134.4,
                    44: 139.1,
                    45: 145.6,
                    46: 151.0,
                    47: 152.5,
                    48: 148.2,
                    49: 139.8,
                    50: 129.6,
                    51: 120.4,
                    52: 113.9,
                    53: 109.9,
                    54: 107.7,
                    55: 106.3,
                    56: 105.3,
                    57: 104.5,
                    58: 104.0,
                    59: 103.9,
                    60: 104.3,
                    61: 104.9,
                    62: 105.4,
                    63: 105.5,
                    64: 105.1,
                    65: 104.7,
                    66: 104.9,
                    67: 106.3,
                    68: 109.6,
                    69: 114.3,
                    70: 120.0,
                    71: 126.1,
                    72: 132.3,
                    73: 138.3,
                    74: 144.3,
                    75: 150.0,
                    76: 155.4,
                    77: 159.5,
                    78: 161.4,
                    79: 159.9,
                    80: 154.6,
                    81: 146.6,
                    82: 137.6,
                    83: 129.4,
                    84: 123.2,
                    85: 118.6,
                    86: 114.9,
                    87: 111.3,
                    88: 107.1,
                    89: 102.5,
                    90: 97.5,
                    91: 92.3,
                    92: 87.2,
                    93: 82.3,
                    94: 77.6,
                    95: 73.4,
                },
            },
            Season.Rest: {
                BDEWDAY.Saturday: {
                    0: 74.5,
                    1: 72.3,
                    2: 70.7,
                    3: 69.2,
                    4: 67.8,
                    5: 66.2,
                    6: 64.8,
                    7: 63.5,
                    8: 62.4,
                    9: 61.4,
                    10: 60.4,
                    11: 59.4,
                    12: 58.1,
                    13: 56.9,
                    14: 55.8,
                    15: 55.2,
                    16: 55.2,
                    17: 55.6,
                    18: 56.2,
                    19: 56.9,
                    20: 57.4,
                    21: 57.9,
                    22: 58.5,
                    23: 59.4,
                    24: 60.7,
                    25: 63.2,
                    26: 67.7,
                    27: 75.0,
                    28: 85.7,
                    29: 98.7,
                    30: 112.9,
                    31: 127.0,
                    32: 139.9,
                    33: 151.3,
                    34: 161.4,
                    35: 169.8,
                    36: 176.6,
                    37: 181.3,
                    38: 183.3,
                    39: 182.2,
                    40: 177.9,
                    41: 172.1,
                    42: 167.3,
                    43: 165.7,
                    44: 168.6,
                    45: 173.9,
                    46: 178.4,
                    47: 178.9,
                    48: 173.3,
                    49: 163.2,
                    50: 151.2,
                    51: 140.1,
                    52: 131.9,
                    53: 125.9,
                    54: 121.1,
                    55: 116.2,
                    56: 110.5,
                    57: 104.5,
                    58: 98.9,
                    59: 94.8,
                    60: 92.7,
                    61: 92.0,
                    62: 92.2,
                    63: 92.3,
                    64: 92.0,
                    65: 91.9,
                    66: 92.8,
                    67: 95.6,
                    68: 100.9,
                    69: 108.2,
                    70: 116.6,
                    71: 125.3,
                    72: 133.7,
                    73: 141.6,
                    74: 149.0,
                    75: 155.8,
                    76: 161.9,
                    77: 166.6,
                    78: 169.0,
                    79: 168.2,
                    80: 163.6,
                    81: 156.2,
                    82: 147.4,
                    83: 138.5,
                    84: 130.5,
                    85: 123.4,
                    86: 117.1,
                    87: 111.3,
                    88: 105.8,
                    89: 100.4,
                    90: 95.2,
                    91: 89.9,
                    92: 84.4,
                    93: 79.2,
                    94: 74.3,
                    95: 70.1,
                },
                BDEWDAY.Sunday: {
                    0: 66.8,
                    1: 64.3,
                    2: 62.4,
                    3: 61.0,
                    4: 60.0,
                    5: 59.1,
                    6: 58.4,
                    7: 57.7,
                    8: 57.0,
                    9: 56.2,
                    10: 55.6,
                    11: 55.2,
                    12: 55.1,
                    13: 55.2,
                    14: 55.3,
                    15: 55.2,
                    16: 54.9,
                    17: 54.7,
                    18: 54.7,
                    19: 55.2,
                    20: 56.7,
                    21: 59.1,
                    22: 62.7,
                    23: 67.6,
                    24: 73.9,
                    25: 81.5,
                    26: 90.4,
                    27: 100.6,
                    28: 111.8,
                    29: 123.7,
                    30: 135.8,
                    31: 147.6,
                    32: 158.5,
                    33: 168.0,
                    34: 175.6,
                    35: 180.5,
                    36: 182.4,
                    37: 181.3,
                    38: 177.3,
                    39: 170.6,
                    40: 161.9,
                    41: 152.9,
                    42: 146.0,
                    43: 143.4,
                    44: 146.6,
                    45: 153.0,
                    46: 159.2,
                    47: 161.6,
                    48: 157.8,
                    49: 149.4,
                    50: 139.1,
                    51: 129.4,
                    52: 122.5,
                    53: 118.1,
                    54: 115.2,
                    55: 112.9,
                    56: 110.7,
                    57: 108.4,
                    58: 106.3,
                    59: 104.7,
                    60: 103.6,
                    61: 102.8,
                    62: 102.2,
                    63: 101.4,
                    64: 100.4,
                    65: 99.9,
                    66: 101.0,
                    67: 104.7,
                    68: 111.5,
                    69: 120.6,
                    70: 130.8,
                    71: 141.0,
                    72: 150.0,
                    73: 157.9,
                    74: 164.7,
                    75: 170.6,
                    76: 175.7,
                    77: 179.4,
                    78: 180.9,
                    79: 179.7,
                    80: 175.3,
                    81: 168.5,
                    82: 160.3,
                    83: 151.7,
                    84: 143.5,
                    85: 135.9,
                    86: 128.7,
                    87: 122.0,
                    88: 115.6,
                    89: 109.4,
                    90: 103.3,
                    91: 97.3,
                    92: 91.2,
                    93: 85.3,
                    94: 79.8,
                    95: 75.0,
                },
                BDEWDAY.Workday: {
                    0: 73.1,
                    1: 69.3,
                    2: 66.0,
                    3: 63.5,
                    4: 61.8,
                    5: 60.7,
                    6: 60.0,
                    7: 59.4,
                    8: 58.6,
                    9: 57.7,
                    10: 56.9,
                    11: 56.1,
                    12: 55.4,
                    13: 54.9,
                    14: 54.6,
                    15: 54.4,
                    16: 54.5,
                    17: 54.7,
                    18: 55.3,
                    19: 56.1,
                    20: 57.2,
                    21: 59.0,
                    22: 61.8,
                    23: 65.9,
                    24: 71.7,
                    25: 78.9,
                    26: 87.5,
                    27: 97.3,
                    28: 108.0,
                    29: 119.3,
                    30: 131.0,
                    31: 142.6,
                    32: 153.7,
                    33: 163.5,
                    34: 170.8,
                    35: 174.8,
                    36: 174.7,
                    37: 171.3,
                    38: 165.7,
                    39: 159.1,
                    40: 152.5,
                    41: 146.9,
                    42: 143.3,
                    43: 142.6,
                    44: 145.3,
                    45: 149.5,
                    46: 152.9,
                    47: 153.3,
                    48: 149.1,
                    49: 141.5,
                    50: 132.6,
                    51: 124.5,
                    52: 118.6,
                    53: 114.9,
                    54: 112.7,
                    55: 111.3,
                    56: 110.2,
                    57: 109.2,
                    58: 108.5,
                    59: 108.0,
                    60: 107.7,
                    61: 107.5,
                    62: 107.3,
                    63: 107.2,
                    64: 107.0,
                    65: 107.4,
                    66: 108.9,
                    67: 112.1,
                    68: 117.6,
                    69: 124.7,
                    70: 133.0,
                    71: 141.8,
                    72: 150.4,
                    73: 158.8,
                    74: 166.6,
                    75: 173.9,
                    76: 180.4,
                    77: 185.0,
                    78: 186.8,
                    79: 184.7,
                    80: 178.0,
                    81: 168.2,
                    82: 157.1,
                    83: 146.7,
                    84: 138.4,
                    85: 131.9,
                    86: 126.4,
                    87: 121.2,
                    88: 115.7,
                    89: 109.8,
                    90: 103.9,
                    91: 98.1,
                    92: 92.5,
                    93: 87.2,
                    94: 82.2,
                    95: 77.5,
                },
            },
        }
